'use strict';

var web3_js = require('@solana/web3.js');
var resolvers = require('@tensor-foundation/resolvers');

// src/generated/accounts/bidState.ts
var DEFAULT_ADDRESS = web3_js.address("11111111111111111111111111111111");
var getNullableAddressEncoder = () => web3_js.createEncoder({
  fixedSize: 32,
  write(value, bytes, offset) {
    if (value === null) {
      bytes.set(web3_js.getAddressEncoder().encode(DEFAULT_ADDRESS), offset);
    } else {
      bytes.set(web3_js.getAddressEncoder().encode(value), offset);
    }
    return offset + 32;
  }
});
var getNullableAddressDecoder = () => web3_js.createDecoder({
  fixedSize: 32,
  read(bytes, offset) {
    if (web3_js.getAddressDecoder().decode(bytes, offset) === DEFAULT_ADDRESS) {
      return [null, offset + 32];
    } else {
      return [web3_js.getAddressDecoder().decode(bytes, offset), offset + 32];
    }
  }
});
var getNullableAddressCodec = () => web3_js.combineCodec(getNullableAddressEncoder(), getNullableAddressDecoder());
async function findTreeAuthorityPda(seeds, config = {}) {
  const {
    programAddress = "BGUMAp9Gq7iTEuizy4pqaxsTyUCBK68MDfK752saRPUY"
  } = config;
  return await web3_js.getProgramDerivedAddress({
    programAddress,
    seeds: [web3_js.getAddressEncoder().encode(seeds.merkleTree)]
  });
}
async function findFeeVaultPda(seeds) {
  const bytes = web3_js.getAddressEncoder().encode(seeds.address);
  const lastByte = bytes[bytes.length - 1];
  return await web3_js.getProgramDerivedAddress({
    programAddress: web3_js.address("TFEEgwDP6nn1s8mMX2tTNPPz8j2VomkphLUmyxKm17A"),
    seeds: [
      web3_js.getUtf8Encoder().encode("fee_vault"),
      web3_js.getU8Encoder().encode(lastByte)
    ]
  });
}
function expectSome(value) {
  if (value == null) {
    throw new Error("Expected a value but received null or undefined.");
  }
  return value;
}
function expectAddress(value) {
  if (!value) {
    throw new Error("Expected a Address.");
  }
  if (typeof value === "object" && "address" in value) {
    return value.address;
  }
  if (Array.isArray(value)) {
    return value[0];
  }
  return value;
}
function expectTransactionSigner(value) {
  if (!value || !isTransactionSigner(value)) {
    throw new Error("Expected a TransactionSigner.");
  }
  return value;
}
function getAccountMetaFactory(programAddress, optionalAccountStrategy) {
  return (account) => {
    if (!account.value) {
      return Object.freeze({
        address: programAddress,
        role: web3_js.AccountRole.READONLY
      });
    }
    const writableRole = account.isWritable ? web3_js.AccountRole.WRITABLE : web3_js.AccountRole.READONLY;
    return Object.freeze({
      address: expectAddress(account.value),
      role: isTransactionSigner(account.value) ? web3_js.upgradeRoleToSigner(writableRole) : writableRole,
      ...isTransactionSigner(account.value) ? { signer: account.value } : {}
    });
  };
}
function isTransactionSigner(value) {
  return !!value && typeof value === "object" && "address" in value && web3_js.isTransactionSigner(value);
}

// src/hooked/resolvers.ts
var resolveBidIdOnCreate = async ({
  args
}) => {
  if (expectSome(args.target) === 0 /* AssetId */)
    return await Promise.resolve(expectAddress(args.targetId));
  return await web3_js.getAddressFromPublicKey((await web3_js.generateKeyPair()).publicKey);
};
var resolveFeeVaultPdaFromListState = async ({
  accounts
}) => {
  return {
    value: await findFeeVaultPda({
      address: expectAddress(accounts.listState?.value)
    })
  };
};
var resolveFeeVaultPdaFromBidState = async ({
  accounts
}) => {
  return {
    value: await findFeeVaultPda({
      address: expectAddress(accounts.bidState?.value)
    })
  };
};
var resolveTreeAuthorityPda = async ({
  accounts
}) => {
  return {
    value: await findTreeAuthorityPda(
      {
        merkleTree: expectAddress(accounts.merkleTree?.value)
      },
      { programAddress: expectAddress(accounts.bubblegumProgram?.value) }
    )
  };
};
var resolveCreatorPath = ({
  args
}) => {
  const creators = args.creators ?? [];
  return creators.map(([creator, share]) => ({
    address: creator,
    role: +(share > 0)
  }));
};
var resolveProofPath = ({
  args
}) => {
  const proof = args.proof ?? [];
  const canopyDepth = args.canopyDepth ?? 0;
  return proof.slice(0, proof.length - canopyDepth).map((proof2) => ({
    address: proof2,
    role: 0
  }));
};
var resolveRemainingSignerWithOwnerOrDelegate = ({
  accounts
}) => {
  if (!!accounts.owner.value && isTransactionSigner(accounts.owner.value)) {
    return {
      value: accounts.owner.value
    };
  }
  if (!!accounts.delegate.value && isTransactionSigner(accounts.delegate.value))
    return {
      value: accounts.delegate.value
    };
  throw new Error(
    "Either owner or delegate has to be provided as TransactionSigner."
  );
};
var resolveRemainingSignerWithSellerOrDelegate = ({
  accounts
}) => {
  if (!!accounts.seller.value && isTransactionSigner(accounts.seller.value)) {
    return {
      value: accounts.seller.value
    };
  }
  if (!!accounts.delegate.value && isTransactionSigner(accounts.delegate.value))
    return {
      value: accounts.delegate.value
    };
  throw new Error(
    "Either seller or delegate has to be provided as TransactionSigner."
  );
};
var resolveBidTa = async ({
  accounts
}) => {
  return {
    value: await findBidTaPda({
      mint: expectAddress(accounts.mint?.value)
    })
  };
};
async function findBidStatePda(seeds, config = {}) {
  const {
    programAddress = "TCMPhJdwDryooaGtiocG1u3xcYbRpiJzb283XfCZsDp"
  } = config;
  return await web3_js.getProgramDerivedAddress({
    programAddress,
    seeds: [
      web3_js.getUtf8Encoder().encode("bid_state"),
      web3_js.getAddressEncoder().encode(seeds.owner),
      web3_js.getAddressEncoder().encode(seeds.bidId)
    ]
  });
}
async function findBidTaPda(seeds, config = {}) {
  const {
    programAddress = "TCMPhJdwDryooaGtiocG1u3xcYbRpiJzb283XfCZsDp"
  } = config;
  return await web3_js.getProgramDerivedAddress({
    programAddress,
    seeds: [
      web3_js.getUtf8Encoder().encode("nft_escrow"),
      web3_js.getAddressEncoder().encode(seeds.mint)
    ]
  });
}
async function findListStatePda(seeds, config = {}) {
  const {
    programAddress = "TCMPhJdwDryooaGtiocG1u3xcYbRpiJzb283XfCZsDp"
  } = config;
  return await web3_js.getProgramDerivedAddress({
    programAddress,
    seeds: [
      web3_js.getUtf8Encoder().encode("list_state"),
      web3_js.getAddressEncoder().encode(seeds.mint)
    ]
  });
}
function getAuthorizationDataLocalEncoder() {
  return web3_js.getStructEncoder([
    ["payload", web3_js.getArrayEncoder(getTaggedPayloadEncoder())]
  ]);
}
function getAuthorizationDataLocalDecoder() {
  return web3_js.getStructDecoder([
    ["payload", web3_js.getArrayDecoder(getTaggedPayloadDecoder())]
  ]);
}
function getAuthorizationDataLocalCodec() {
  return web3_js.combineCodec(
    getAuthorizationDataLocalEncoder(),
    getAuthorizationDataLocalDecoder()
  );
}
var Field = /* @__PURE__ */ ((Field2) => {
  Field2[Field2["Name"] = 0] = "Name";
  return Field2;
})(Field || {});
function getFieldEncoder() {
  return web3_js.getEnumEncoder(Field);
}
function getFieldDecoder() {
  return web3_js.getEnumDecoder(Field);
}
function getFieldCodec() {
  return web3_js.combineCodec(getFieldEncoder(), getFieldDecoder());
}
function getMakeEventEncoder() {
  return web3_js.transformEncoder(
    web3_js.getStructEncoder([
      ["maker", web3_js.getAddressEncoder()],
      ["bidId", web3_js.getOptionEncoder(web3_js.getAddressEncoder())],
      ["target", getTargetEncoder()],
      ["targetId", web3_js.getAddressEncoder()],
      ["field", web3_js.getOptionEncoder(getFieldEncoder())],
      ["fieldId", web3_js.getOptionEncoder(web3_js.getAddressEncoder())],
      ["amount", web3_js.getU64Encoder()],
      ["quantity", web3_js.getU32Encoder()],
      ["currency", web3_js.getOptionEncoder(web3_js.getAddressEncoder())],
      ["expiry", web3_js.getI64Encoder()],
      ["privateTaker", web3_js.getOptionEncoder(web3_js.getAddressEncoder())],
      ["assetId", web3_js.getOptionEncoder(web3_js.getAddressEncoder())]
    ]),
    (value) => ({ ...value, quantity: value.quantity ?? 1 })
  );
}
function getMakeEventDecoder() {
  return web3_js.getStructDecoder([
    ["maker", web3_js.getAddressDecoder()],
    ["bidId", web3_js.getOptionDecoder(web3_js.getAddressDecoder())],
    ["target", getTargetDecoder()],
    ["targetId", web3_js.getAddressDecoder()],
    ["field", web3_js.getOptionDecoder(getFieldDecoder())],
    ["fieldId", web3_js.getOptionDecoder(web3_js.getAddressDecoder())],
    ["amount", web3_js.getU64Decoder()],
    ["quantity", web3_js.getU32Decoder()],
    ["currency", web3_js.getOptionDecoder(web3_js.getAddressDecoder())],
    ["expiry", web3_js.getI64Decoder()],
    ["privateTaker", web3_js.getOptionDecoder(web3_js.getAddressDecoder())],
    ["assetId", web3_js.getOptionDecoder(web3_js.getAddressDecoder())]
  ]);
}
function getMakeEventCodec() {
  return web3_js.combineCodec(getMakeEventEncoder(), getMakeEventDecoder());
}
function getPayloadTypeLocalEncoder() {
  return web3_js.getDiscriminatedUnionEncoder([
    [
      "Pubkey",
      web3_js.getStructEncoder([["fields", web3_js.getTupleEncoder([web3_js.getAddressEncoder()])]])
    ],
    [
      "Seeds",
      web3_js.getStructEncoder([
        ["fields", web3_js.getTupleEncoder([getSeedsVecLocalEncoder()])]
      ])
    ],
    [
      "MerkleProof",
      web3_js.getStructEncoder([
        ["fields", web3_js.getTupleEncoder([getProofInfoLocalEncoder()])]
      ])
    ],
    [
      "Number",
      web3_js.getStructEncoder([["fields", web3_js.getTupleEncoder([web3_js.getU64Encoder()])]])
    ]
  ]);
}
function getPayloadTypeLocalDecoder() {
  return web3_js.getDiscriminatedUnionDecoder([
    [
      "Pubkey",
      web3_js.getStructDecoder([["fields", web3_js.getTupleDecoder([web3_js.getAddressDecoder()])]])
    ],
    [
      "Seeds",
      web3_js.getStructDecoder([
        ["fields", web3_js.getTupleDecoder([getSeedsVecLocalDecoder()])]
      ])
    ],
    [
      "MerkleProof",
      web3_js.getStructDecoder([
        ["fields", web3_js.getTupleDecoder([getProofInfoLocalDecoder()])]
      ])
    ],
    [
      "Number",
      web3_js.getStructDecoder([["fields", web3_js.getTupleDecoder([web3_js.getU64Decoder()])]])
    ]
  ]);
}
function getPayloadTypeLocalCodec() {
  return web3_js.combineCodec(
    getPayloadTypeLocalEncoder(),
    getPayloadTypeLocalDecoder()
  );
}
function payloadTypeLocal(kind, data) {
  return Array.isArray(data) ? { __kind: kind, fields: data } : { __kind: kind, ...data ?? {} };
}
function isPayloadTypeLocal(kind, value) {
  return value.__kind === kind;
}
function getProofInfoLocalEncoder() {
  return web3_js.getStructEncoder([
    ["proof", web3_js.getArrayEncoder(web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 32))]
  ]);
}
function getProofInfoLocalDecoder() {
  return web3_js.getStructDecoder([
    ["proof", web3_js.getArrayDecoder(web3_js.fixDecoderSize(web3_js.getBytesDecoder(), 32))]
  ]);
}
function getProofInfoLocalCodec() {
  return web3_js.combineCodec(getProofInfoLocalEncoder(), getProofInfoLocalDecoder());
}
function getSeedsVecLocalEncoder() {
  return web3_js.getStructEncoder([
    [
      "seeds",
      web3_js.getArrayEncoder(web3_js.addEncoderSizePrefix(web3_js.getBytesEncoder(), web3_js.getU32Encoder()))
    ]
  ]);
}
function getSeedsVecLocalDecoder() {
  return web3_js.getStructDecoder([
    [
      "seeds",
      web3_js.getArrayDecoder(web3_js.addDecoderSizePrefix(web3_js.getBytesDecoder(), web3_js.getU32Decoder()))
    ]
  ]);
}
function getSeedsVecLocalCodec() {
  return web3_js.combineCodec(getSeedsVecLocalEncoder(), getSeedsVecLocalDecoder());
}
function getTaggedPayloadEncoder() {
  return web3_js.getStructEncoder([
    ["name", web3_js.addEncoderSizePrefix(web3_js.getUtf8Encoder(), web3_js.getU32Encoder())],
    ["payload", getPayloadTypeLocalEncoder()]
  ]);
}
function getTaggedPayloadDecoder() {
  return web3_js.getStructDecoder([
    ["name", web3_js.addDecoderSizePrefix(web3_js.getUtf8Decoder(), web3_js.getU32Decoder())],
    ["payload", getPayloadTypeLocalDecoder()]
  ]);
}
function getTaggedPayloadCodec() {
  return web3_js.combineCodec(getTaggedPayloadEncoder(), getTaggedPayloadDecoder());
}
function getTakeEventEncoder() {
  return web3_js.transformEncoder(
    web3_js.getStructEncoder([
      ["taker", web3_js.getAddressEncoder()],
      ["bidId", web3_js.getOptionEncoder(web3_js.getAddressEncoder())],
      ["target", getTargetEncoder()],
      ["targetId", web3_js.getAddressEncoder()],
      ["field", web3_js.getOptionEncoder(getFieldEncoder())],
      ["fieldId", web3_js.getOptionEncoder(web3_js.getAddressEncoder())],
      ["amount", web3_js.getU64Encoder()],
      ["quantity", web3_js.getU32Encoder()],
      ["tcompFee", web3_js.getU64Encoder()],
      ["takerBrokerFee", web3_js.getU64Encoder()],
      ["makerBrokerFee", web3_js.getU64Encoder()],
      ["creatorFee", web3_js.getU64Encoder()],
      ["currency", web3_js.getOptionEncoder(web3_js.getAddressEncoder())],
      ["assetId", web3_js.getOptionEncoder(web3_js.getAddressEncoder())]
    ]),
    (value) => ({ ...value, quantity: value.quantity ?? 1 })
  );
}
function getTakeEventDecoder() {
  return web3_js.getStructDecoder([
    ["taker", web3_js.getAddressDecoder()],
    ["bidId", web3_js.getOptionDecoder(web3_js.getAddressDecoder())],
    ["target", getTargetDecoder()],
    ["targetId", web3_js.getAddressDecoder()],
    ["field", web3_js.getOptionDecoder(getFieldDecoder())],
    ["fieldId", web3_js.getOptionDecoder(web3_js.getAddressDecoder())],
    ["amount", web3_js.getU64Decoder()],
    ["quantity", web3_js.getU32Decoder()],
    ["tcompFee", web3_js.getU64Decoder()],
    ["takerBrokerFee", web3_js.getU64Decoder()],
    ["makerBrokerFee", web3_js.getU64Decoder()],
    ["creatorFee", web3_js.getU64Decoder()],
    ["currency", web3_js.getOptionDecoder(web3_js.getAddressDecoder())],
    ["assetId", web3_js.getOptionDecoder(web3_js.getAddressDecoder())]
  ]);
}
function getTakeEventCodec() {
  return web3_js.combineCodec(getTakeEventEncoder(), getTakeEventDecoder());
}
var Target = /* @__PURE__ */ ((Target2) => {
  Target2[Target2["AssetId"] = 0] = "AssetId";
  Target2[Target2["Whitelist"] = 1] = "Whitelist";
  return Target2;
})(Target || {});
function getTargetEncoder() {
  return web3_js.getEnumEncoder(Target);
}
function getTargetDecoder() {
  return web3_js.getEnumDecoder(Target);
}
function getTargetCodec() {
  return web3_js.combineCodec(getTargetEncoder(), getTargetDecoder());
}
function getTCollectionEncoder() {
  return web3_js.getStructEncoder([
    ["verified", web3_js.getBooleanEncoder()],
    ["key", web3_js.getAddressEncoder()]
  ]);
}
function getTCollectionDecoder() {
  return web3_js.getStructDecoder([
    ["verified", web3_js.getBooleanDecoder()],
    ["key", web3_js.getAddressDecoder()]
  ]);
}
function getTCollectionCodec() {
  return web3_js.combineCodec(getTCollectionEncoder(), getTCollectionDecoder());
}
function getTcompEventEncoder() {
  return web3_js.getDiscriminatedUnionEncoder([
    [
      "Maker",
      web3_js.getStructEncoder([["fields", web3_js.getTupleEncoder([getMakeEventEncoder()])]])
    ],
    [
      "Taker",
      web3_js.getStructEncoder([["fields", web3_js.getTupleEncoder([getTakeEventEncoder()])]])
    ]
  ]);
}
function getTcompEventDecoder() {
  return web3_js.getDiscriminatedUnionDecoder([
    [
      "Maker",
      web3_js.getStructDecoder([["fields", web3_js.getTupleDecoder([getMakeEventDecoder()])]])
    ],
    [
      "Taker",
      web3_js.getStructDecoder([["fields", web3_js.getTupleDecoder([getTakeEventDecoder()])]])
    ]
  ]);
}
function getTcompEventCodec() {
  return web3_js.combineCodec(getTcompEventEncoder(), getTcompEventDecoder());
}
function tcompEvent(kind, data) {
  return Array.isArray(data) ? { __kind: kind, fields: data } : { __kind: kind, ...data ?? {} };
}
function isTcompEvent(kind, value) {
  return value.__kind === kind;
}
var TTokenProgramVersion = /* @__PURE__ */ ((TTokenProgramVersion2) => {
  TTokenProgramVersion2[TTokenProgramVersion2["Original"] = 0] = "Original";
  TTokenProgramVersion2[TTokenProgramVersion2["Token2022"] = 1] = "Token2022";
  return TTokenProgramVersion2;
})(TTokenProgramVersion || {});
function getTTokenProgramVersionEncoder() {
  return web3_js.getEnumEncoder(TTokenProgramVersion);
}
function getTTokenProgramVersionDecoder() {
  return web3_js.getEnumDecoder(TTokenProgramVersion);
}
function getTTokenProgramVersionCodec() {
  return web3_js.combineCodec(
    getTTokenProgramVersionEncoder(),
    getTTokenProgramVersionDecoder()
  );
}
var TTokenStandard = /* @__PURE__ */ ((TTokenStandard2) => {
  TTokenStandard2[TTokenStandard2["NonFungible"] = 0] = "NonFungible";
  TTokenStandard2[TTokenStandard2["FungibleAsset"] = 1] = "FungibleAsset";
  TTokenStandard2[TTokenStandard2["Fungible"] = 2] = "Fungible";
  TTokenStandard2[TTokenStandard2["NonFungibleEdition"] = 3] = "NonFungibleEdition";
  return TTokenStandard2;
})(TTokenStandard || {});
function getTTokenStandardEncoder() {
  return web3_js.getEnumEncoder(TTokenStandard);
}
function getTTokenStandardDecoder() {
  return web3_js.getEnumDecoder(TTokenStandard);
}
function getTTokenStandardCodec() {
  return web3_js.combineCodec(getTTokenStandardEncoder(), getTTokenStandardDecoder());
}
var TUseMethod = /* @__PURE__ */ ((TUseMethod2) => {
  TUseMethod2[TUseMethod2["Burn"] = 0] = "Burn";
  TUseMethod2[TUseMethod2["Multiple"] = 1] = "Multiple";
  TUseMethod2[TUseMethod2["Single"] = 2] = "Single";
  return TUseMethod2;
})(TUseMethod || {});
function getTUseMethodEncoder() {
  return web3_js.getEnumEncoder(TUseMethod);
}
function getTUseMethodDecoder() {
  return web3_js.getEnumDecoder(TUseMethod);
}
function getTUseMethodCodec() {
  return web3_js.combineCodec(getTUseMethodEncoder(), getTUseMethodDecoder());
}
function getTUsesEncoder() {
  return web3_js.getStructEncoder([
    ["useMethod", getTUseMethodEncoder()],
    ["remaining", web3_js.getU64Encoder()],
    ["total", web3_js.getU64Encoder()]
  ]);
}
function getTUsesDecoder() {
  return web3_js.getStructDecoder([
    ["useMethod", getTUseMethodDecoder()],
    ["remaining", web3_js.getU64Decoder()],
    ["total", web3_js.getU64Decoder()]
  ]);
}
function getTUsesCodec() {
  return web3_js.combineCodec(getTUsesEncoder(), getTUsesDecoder());
}

// src/generated/accounts/bidState.ts
function getBidStateEncoder() {
  return web3_js.transformEncoder(
    web3_js.getStructEncoder([
      ["discriminator", web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 8)],
      ["version", web3_js.getU8Encoder()],
      ["bump", web3_js.getArrayEncoder(web3_js.getU8Encoder(), { size: 1 })],
      ["owner", web3_js.getAddressEncoder()],
      ["bidId", web3_js.getAddressEncoder()],
      ["target", getTargetEncoder()],
      ["targetId", web3_js.getAddressEncoder()],
      ["field", web3_js.getOptionEncoder(getFieldEncoder())],
      ["fieldId", web3_js.getOptionEncoder(web3_js.getAddressEncoder())],
      ["quantity", web3_js.getU32Encoder()],
      ["filledQuantity", web3_js.getU32Encoder()],
      ["amount", web3_js.getU64Encoder()],
      ["currency", web3_js.getOptionEncoder(web3_js.getAddressEncoder())],
      ["expiry", web3_js.getI64Encoder()],
      ["privateTaker", web3_js.getOptionEncoder(web3_js.getAddressEncoder())],
      ["makerBroker", web3_js.getOptionEncoder(web3_js.getAddressEncoder())],
      ["margin", web3_js.getOptionEncoder(web3_js.getAddressEncoder())],
      ["updatedAt", web3_js.getI64Encoder()],
      ["cosigner", getNullableAddressEncoder()],
      ["rentPayer", getNullableAddressEncoder()],
      ["reserved", web3_js.getArrayEncoder(web3_js.getU8Encoder(), { size: 8 })],
      ["reserved1", web3_js.getArrayEncoder(web3_js.getU8Encoder(), { size: 16 })],
      ["reserved2", web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 32)]
    ]),
    (value) => ({
      ...value,
      discriminator: new Uint8Array([155, 197, 5, 97, 189, 60, 8, 183]),
      quantity: value.quantity ?? 1
    })
  );
}
function getBidStateDecoder() {
  return web3_js.getStructDecoder([
    ["discriminator", web3_js.fixDecoderSize(web3_js.getBytesDecoder(), 8)],
    ["version", web3_js.getU8Decoder()],
    ["bump", web3_js.getArrayDecoder(web3_js.getU8Decoder(), { size: 1 })],
    ["owner", web3_js.getAddressDecoder()],
    ["bidId", web3_js.getAddressDecoder()],
    ["target", getTargetDecoder()],
    ["targetId", web3_js.getAddressDecoder()],
    ["field", web3_js.getOptionDecoder(getFieldDecoder())],
    ["fieldId", web3_js.getOptionDecoder(web3_js.getAddressDecoder())],
    ["quantity", web3_js.getU32Decoder()],
    ["filledQuantity", web3_js.getU32Decoder()],
    ["amount", web3_js.getU64Decoder()],
    ["currency", web3_js.getOptionDecoder(web3_js.getAddressDecoder())],
    ["expiry", web3_js.getI64Decoder()],
    ["privateTaker", web3_js.getOptionDecoder(web3_js.getAddressDecoder())],
    ["makerBroker", web3_js.getOptionDecoder(web3_js.getAddressDecoder())],
    ["margin", web3_js.getOptionDecoder(web3_js.getAddressDecoder())],
    ["updatedAt", web3_js.getI64Decoder()],
    ["cosigner", getNullableAddressDecoder()],
    ["rentPayer", getNullableAddressDecoder()],
    ["reserved", web3_js.getArrayDecoder(web3_js.getU8Decoder(), { size: 8 })],
    ["reserved1", web3_js.getArrayDecoder(web3_js.getU8Decoder(), { size: 16 })],
    ["reserved2", web3_js.fixDecoderSize(web3_js.getBytesDecoder(), 32)]
  ]);
}
function getBidStateCodec() {
  return web3_js.combineCodec(getBidStateEncoder(), getBidStateDecoder());
}
function decodeBidState(encodedAccount) {
  return web3_js.decodeAccount(
    encodedAccount,
    getBidStateDecoder()
  );
}
async function fetchBidState(rpc, address3, config) {
  const maybeAccount = await fetchMaybeBidState(rpc, address3, config);
  web3_js.assertAccountExists(maybeAccount);
  return maybeAccount;
}
async function fetchMaybeBidState(rpc, address3, config) {
  const maybeAccount = await web3_js.fetchEncodedAccount(rpc, address3, config);
  return decodeBidState(maybeAccount);
}
async function fetchAllBidState(rpc, addresses, config) {
  const maybeAccounts = await fetchAllMaybeBidState(rpc, addresses, config);
  web3_js.assertAccountsExist(maybeAccounts);
  return maybeAccounts;
}
async function fetchAllMaybeBidState(rpc, addresses, config) {
  const maybeAccounts = await web3_js.fetchEncodedAccounts(rpc, addresses, config);
  return maybeAccounts.map((maybeAccount) => decodeBidState(maybeAccount));
}
async function fetchBidStateFromSeeds(rpc, seeds, config = {}) {
  const maybeAccount = await fetchMaybeBidStateFromSeeds(rpc, seeds, config);
  web3_js.assertAccountExists(maybeAccount);
  return maybeAccount;
}
async function fetchMaybeBidStateFromSeeds(rpc, seeds, config = {}) {
  const { programAddress, ...fetchConfig } = config;
  const [address3] = await findBidStatePda(seeds, { programAddress });
  return await fetchMaybeBidState(rpc, address3, fetchConfig);
}
function getBidTaEncoder() {
  return web3_js.transformEncoder(
    web3_js.getStructEncoder([["discriminator", web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 8)]]),
    (value) => ({
      ...value,
      discriminator: new Uint8Array([186, 230, 110, 26, 235, 24, 211, 156])
    })
  );
}
function getBidTaDecoder() {
  return web3_js.getStructDecoder([
    ["discriminator", web3_js.fixDecoderSize(web3_js.getBytesDecoder(), 8)]
  ]);
}
function getBidTaCodec() {
  return web3_js.combineCodec(getBidTaEncoder(), getBidTaDecoder());
}
function decodeBidTa(encodedAccount) {
  return web3_js.decodeAccount(
    encodedAccount,
    getBidTaDecoder()
  );
}
async function fetchBidTa(rpc, address3, config) {
  const maybeAccount = await fetchMaybeBidTa(rpc, address3, config);
  web3_js.assertAccountExists(maybeAccount);
  return maybeAccount;
}
async function fetchMaybeBidTa(rpc, address3, config) {
  const maybeAccount = await web3_js.fetchEncodedAccount(rpc, address3, config);
  return decodeBidTa(maybeAccount);
}
async function fetchAllBidTa(rpc, addresses, config) {
  const maybeAccounts = await fetchAllMaybeBidTa(rpc, addresses, config);
  web3_js.assertAccountsExist(maybeAccounts);
  return maybeAccounts;
}
async function fetchAllMaybeBidTa(rpc, addresses, config) {
  const maybeAccounts = await web3_js.fetchEncodedAccounts(rpc, addresses, config);
  return maybeAccounts.map((maybeAccount) => decodeBidTa(maybeAccount));
}
function getBidTaSize() {
  return 8;
}
async function fetchBidTaFromSeeds(rpc, seeds, config = {}) {
  const maybeAccount = await fetchMaybeBidTaFromSeeds(rpc, seeds, config);
  web3_js.assertAccountExists(maybeAccount);
  return maybeAccount;
}
async function fetchMaybeBidTaFromSeeds(rpc, seeds, config = {}) {
  const { programAddress, ...fetchConfig } = config;
  const [address3] = await findBidTaPda(seeds, { programAddress });
  return await fetchMaybeBidTa(rpc, address3, fetchConfig);
}
function getListStateEncoder() {
  return web3_js.transformEncoder(
    web3_js.getStructEncoder([
      ["discriminator", web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 8)],
      ["version", web3_js.getU8Encoder()],
      ["bump", web3_js.getArrayEncoder(web3_js.getU8Encoder(), { size: 1 })],
      ["owner", web3_js.getAddressEncoder()],
      ["assetId", web3_js.getAddressEncoder()],
      ["amount", web3_js.getU64Encoder()],
      ["currency", web3_js.getOptionEncoder(web3_js.getAddressEncoder())],
      ["expiry", web3_js.getI64Encoder()],
      ["privateTaker", web3_js.getOptionEncoder(web3_js.getAddressEncoder())],
      ["makerBroker", web3_js.getOptionEncoder(web3_js.getAddressEncoder())],
      ["rentPayer", getNullableAddressEncoder()],
      ["cosigner", getNullableAddressEncoder()],
      ["reserved1", web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 64)]
    ]),
    (value) => ({
      ...value,
      discriminator: new Uint8Array([78, 242, 89, 138, 161, 221, 176, 75])
    })
  );
}
function getListStateDecoder() {
  return web3_js.getStructDecoder([
    ["discriminator", web3_js.fixDecoderSize(web3_js.getBytesDecoder(), 8)],
    ["version", web3_js.getU8Decoder()],
    ["bump", web3_js.getArrayDecoder(web3_js.getU8Decoder(), { size: 1 })],
    ["owner", web3_js.getAddressDecoder()],
    ["assetId", web3_js.getAddressDecoder()],
    ["amount", web3_js.getU64Decoder()],
    ["currency", web3_js.getOptionDecoder(web3_js.getAddressDecoder())],
    ["expiry", web3_js.getI64Decoder()],
    ["privateTaker", web3_js.getOptionDecoder(web3_js.getAddressDecoder())],
    ["makerBroker", web3_js.getOptionDecoder(web3_js.getAddressDecoder())],
    ["rentPayer", getNullableAddressDecoder()],
    ["cosigner", getNullableAddressDecoder()],
    ["reserved1", web3_js.fixDecoderSize(web3_js.getBytesDecoder(), 64)]
  ]);
}
function getListStateCodec() {
  return web3_js.combineCodec(getListStateEncoder(), getListStateDecoder());
}
function decodeListState(encodedAccount) {
  return web3_js.decodeAccount(
    encodedAccount,
    getListStateDecoder()
  );
}
async function fetchListState(rpc, address3, config) {
  const maybeAccount = await fetchMaybeListState(rpc, address3, config);
  web3_js.assertAccountExists(maybeAccount);
  return maybeAccount;
}
async function fetchMaybeListState(rpc, address3, config) {
  const maybeAccount = await web3_js.fetchEncodedAccount(rpc, address3, config);
  return decodeListState(maybeAccount);
}
async function fetchAllListState(rpc, addresses, config) {
  const maybeAccounts = await fetchAllMaybeListState(rpc, addresses, config);
  web3_js.assertAccountsExist(maybeAccounts);
  return maybeAccounts;
}
async function fetchAllMaybeListState(rpc, addresses, config) {
  const maybeAccounts = await web3_js.fetchEncodedAccounts(rpc, addresses, config);
  return maybeAccounts.map((maybeAccount) => decodeListState(maybeAccount));
}
async function fetchListStateFromSeeds(rpc, seeds, config = {}) {
  const maybeAccount = await fetchMaybeListStateFromSeeds(rpc, seeds, config);
  web3_js.assertAccountExists(maybeAccount);
  return maybeAccount;
}
async function fetchMaybeListStateFromSeeds(rpc, seeds, config = {}) {
  const { programAddress, ...fetchConfig } = config;
  const [address3] = await findListStatePda(seeds, { programAddress });
  return await fetchMaybeListState(rpc, address3, fetchConfig);
}

// src/generated/errors/tensorMarketplace.ts
var TENSOR_MARKETPLACE_ERROR__ARITHMETIC_ERROR = 6100;
var TENSOR_MARKETPLACE_ERROR__EXPIRY_TOO_LARGE = 6101;
var TENSOR_MARKETPLACE_ERROR__BAD_OWNER = 6102;
var TENSOR_MARKETPLACE_ERROR__BAD_LIST_STATE = 6103;
var TENSOR_MARKETPLACE_ERROR__BAD_ROYALTIES_PCT = 6104;
var TENSOR_MARKETPLACE_ERROR__PRICE_MISMATCH = 6105;
var TENSOR_MARKETPLACE_ERROR__CREATOR_MISMATCH = 6106;
var TENSOR_MARKETPLACE_ERROR__INSUFFICIENT_BALANCE = 6107;
var TENSOR_MARKETPLACE_ERROR__BID_EXPIRED = 6108;
var TENSOR_MARKETPLACE_ERROR__TAKER_NOT_ALLOWED = 6109;
var TENSOR_MARKETPLACE_ERROR__BAD_BID_FIELD = 6110;
var TENSOR_MARKETPLACE_ERROR__BID_NOT_YET_EXPIRED = 6111;
var TENSOR_MARKETPLACE_ERROR__BAD_MARGIN = 6112;
var TENSOR_MARKETPLACE_ERROR__WRONG_IX_FOR_BID_TARGET = 6113;
var TENSOR_MARKETPLACE_ERROR__WRONG_TARGET_ID = 6114;
var TENSOR_MARKETPLACE_ERROR__MISSING_FVC = 6115;
var TENSOR_MARKETPLACE_ERROR__MISSING_COLLECTION = 6116;
var TENSOR_MARKETPLACE_ERROR__CANNOT_MODIFY_TARGET = 6117;
var TENSOR_MARKETPLACE_ERROR__TARGET_ID_MUST_EQUAL_BID_ID = 6118;
var TENSOR_MARKETPLACE_ERROR__CURRENCY_NOT_YET_ENABLED = 6119;
var TENSOR_MARKETPLACE_ERROR__MAKER_BROKER_NOT_YET_ENABLED = 6120;
var TENSOR_MARKETPLACE_ERROR__OPTIONAL_ROYALTIES_NOT_YET_ENABLED = 6121;
var TENSOR_MARKETPLACE_ERROR__WRONG_STATE_VERSION = 6122;
var TENSOR_MARKETPLACE_ERROR__WRONG_BID_FIELD_ID = 6123;
var TENSOR_MARKETPLACE_ERROR__BROKER_MISMATCH = 6124;
var TENSOR_MARKETPLACE_ERROR__ASSET_ID_MISMATCH = 6125;
var TENSOR_MARKETPLACE_ERROR__LISTING_EXPIRED = 6126;
var TENSOR_MARKETPLACE_ERROR__LISTING_NOT_YET_EXPIRED = 6127;
var TENSOR_MARKETPLACE_ERROR__BAD_QUANTITY = 6128;
var TENSOR_MARKETPLACE_ERROR__BID_FULLY_FILLED = 6129;
var TENSOR_MARKETPLACE_ERROR__BAD_WHITELIST = 6130;
var TENSOR_MARKETPLACE_ERROR__FORBIDDEN_COLLECTION = 6131;
var TENSOR_MARKETPLACE_ERROR__BAD_COSIGNER = 6132;
var TENSOR_MARKETPLACE_ERROR__BAD_MINT_PROOF = 6133;
var TENSOR_MARKETPLACE_ERROR__CURRENCY_MISMATCH = 6134;
var TENSOR_MARKETPLACE_ERROR__BID_BALANCE_NOT_EMPTIED = 6135;
var TENSOR_MARKETPLACE_ERROR__BAD_RENT_DEST = 6136;
var TENSOR_MARKETPLACE_ERROR__CURRENCY_NOT_YET_WHITELISTED = 6137;
var TENSOR_MARKETPLACE_ERROR__MAKER_BROKER_NOT_YET_WHITELISTED = 6138;
var TENSOR_MARKETPLACE_ERROR__WRONG_TOKEN_RECORD_DERIVATION = 6139;
var TENSOR_MARKETPLACE_ERROR__INVALID_FEE_ACCOUNT = 6140;
var TENSOR_MARKETPLACE_ERROR__INSUFFICIENT_REMAINING_ACCOUNTS = 6141;
var TENSOR_MARKETPLACE_ERROR__MISSING_BROKER = 6142;
var TENSOR_MARKETPLACE_ERROR__MISSING_BROKER_TOKEN_ACCOUNT = 6143;
var TENSOR_MARKETPLACE_ERROR__INVALID_TOKEN_ACCOUNT = 6144;
var tensorMarketplaceErrorMessages;
if (process.env.NODE_ENV !== "production") {
  tensorMarketplaceErrorMessages = {
    [TENSOR_MARKETPLACE_ERROR__ARITHMETIC_ERROR]: `arithmetic error`,
    [TENSOR_MARKETPLACE_ERROR__ASSET_ID_MISMATCH]: `asset id mismatch`,
    [TENSOR_MARKETPLACE_ERROR__BAD_BID_FIELD]: `cannot pass bid field`,
    [TENSOR_MARKETPLACE_ERROR__BAD_COSIGNER]: `bad cosigner`,
    [TENSOR_MARKETPLACE_ERROR__BAD_LIST_STATE]: `bad list state`,
    [TENSOR_MARKETPLACE_ERROR__BAD_MARGIN]: `bad margin`,
    [TENSOR_MARKETPLACE_ERROR__BAD_MINT_PROOF]: `bad mint proof`,
    [TENSOR_MARKETPLACE_ERROR__BAD_OWNER]: `bad owner`,
    [TENSOR_MARKETPLACE_ERROR__BAD_QUANTITY]: `bad quantity passed in`,
    [TENSOR_MARKETPLACE_ERROR__BAD_RENT_DEST]: `Bad rent dest.`,
    [TENSOR_MARKETPLACE_ERROR__BAD_ROYALTIES_PCT]: `royalties pct must be between 0 and 100`,
    [TENSOR_MARKETPLACE_ERROR__BAD_WHITELIST]: `bad whitelist`,
    [TENSOR_MARKETPLACE_ERROR__BID_BALANCE_NOT_EMPTIED]: `The bid balance was not emptied`,
    [TENSOR_MARKETPLACE_ERROR__BID_EXPIRED]: `bid has expired`,
    [TENSOR_MARKETPLACE_ERROR__BID_FULLY_FILLED]: `bid fully filled`,
    [TENSOR_MARKETPLACE_ERROR__BID_NOT_YET_EXPIRED]: `bid not yet expired`,
    [TENSOR_MARKETPLACE_ERROR__BROKER_MISMATCH]: `broker mismatch`,
    [TENSOR_MARKETPLACE_ERROR__CANNOT_MODIFY_TARGET]: `cannot modify bid target, create a new bid`,
    [TENSOR_MARKETPLACE_ERROR__CREATOR_MISMATCH]: `creator mismatch`,
    [TENSOR_MARKETPLACE_ERROR__CURRENCY_MISMATCH]: `Currency mismatch`,
    [TENSOR_MARKETPLACE_ERROR__CURRENCY_NOT_YET_ENABLED]: `currency not yet enabled`,
    [TENSOR_MARKETPLACE_ERROR__CURRENCY_NOT_YET_WHITELISTED]: `currency not yet whitelisted`,
    [TENSOR_MARKETPLACE_ERROR__EXPIRY_TOO_LARGE]: `expiry too large`,
    [TENSOR_MARKETPLACE_ERROR__FORBIDDEN_COLLECTION]: `forbidden collection`,
    [TENSOR_MARKETPLACE_ERROR__INSUFFICIENT_BALANCE]: `insufficient balance`,
    [TENSOR_MARKETPLACE_ERROR__INSUFFICIENT_REMAINING_ACCOUNTS]: `insufficient remaining accounts`,
    [TENSOR_MARKETPLACE_ERROR__INVALID_FEE_ACCOUNT]: `invalid fee account`,
    [TENSOR_MARKETPLACE_ERROR__INVALID_TOKEN_ACCOUNT]: `invalidtoken account`,
    [TENSOR_MARKETPLACE_ERROR__LISTING_EXPIRED]: `listing has expired`,
    [TENSOR_MARKETPLACE_ERROR__LISTING_NOT_YET_EXPIRED]: `listing not yet expired`,
    [TENSOR_MARKETPLACE_ERROR__MAKER_BROKER_NOT_YET_ENABLED]: `maker broker not yet enabled`,
    [TENSOR_MARKETPLACE_ERROR__MAKER_BROKER_NOT_YET_WHITELISTED]: `maker broker not yet whitelisted`,
    [TENSOR_MARKETPLACE_ERROR__MISSING_BROKER]: `missing broker account`,
    [TENSOR_MARKETPLACE_ERROR__MISSING_BROKER_TOKEN_ACCOUNT]: `missing broker token account`,
    [TENSOR_MARKETPLACE_ERROR__MISSING_COLLECTION]: `metadata missing collection`,
    [TENSOR_MARKETPLACE_ERROR__MISSING_FVC]: `creator array missing first verified creator`,
    [TENSOR_MARKETPLACE_ERROR__OPTIONAL_ROYALTIES_NOT_YET_ENABLED]: `optional royalties not yet enabled`,
    [TENSOR_MARKETPLACE_ERROR__PRICE_MISMATCH]: `price mismatch`,
    [TENSOR_MARKETPLACE_ERROR__TAKER_NOT_ALLOWED]: `taker not allowed`,
    [TENSOR_MARKETPLACE_ERROR__TARGET_ID_MUST_EQUAL_BID_ID]: `target id and bid id must be the same for single bids`,
    [TENSOR_MARKETPLACE_ERROR__WRONG_BID_FIELD_ID]: `wrong field id`,
    [TENSOR_MARKETPLACE_ERROR__WRONG_IX_FOR_BID_TARGET]: `wrong ix for bid target called`,
    [TENSOR_MARKETPLACE_ERROR__WRONG_STATE_VERSION]: `wrong state version`,
    [TENSOR_MARKETPLACE_ERROR__WRONG_TARGET_ID]: `wrong target id`,
    [TENSOR_MARKETPLACE_ERROR__WRONG_TOKEN_RECORD_DERIVATION]: `token record derivation is wrong`
  };
}
function getTensorMarketplaceErrorMessage(code) {
  if (process.env.NODE_ENV !== "production") {
    return tensorMarketplaceErrorMessages[code];
  }
  return "Error message not available in production bundles.";
}
var TENSOR_MARKETPLACE_PROGRAM_ADDRESS = "TCMPhJdwDryooaGtiocG1u3xcYbRpiJzb283XfCZsDp";
var TensorMarketplaceAccount = /* @__PURE__ */ ((TensorMarketplaceAccount2) => {
  TensorMarketplaceAccount2[TensorMarketplaceAccount2["ListState"] = 0] = "ListState";
  TensorMarketplaceAccount2[TensorMarketplaceAccount2["BidState"] = 1] = "BidState";
  TensorMarketplaceAccount2[TensorMarketplaceAccount2["BidTa"] = 2] = "BidTa";
  return TensorMarketplaceAccount2;
})(TensorMarketplaceAccount || {});
function identifyTensorMarketplaceAccount(account) {
  const data = account instanceof Uint8Array ? account : account.data;
  if (web3_js.containsBytes(
    data,
    web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 8).encode(
      new Uint8Array([78, 242, 89, 138, 161, 221, 176, 75])
    ),
    0
  )) {
    return 0 /* ListState */;
  }
  if (web3_js.containsBytes(
    data,
    web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 8).encode(
      new Uint8Array([155, 197, 5, 97, 189, 60, 8, 183])
    ),
    0
  )) {
    return 1 /* BidState */;
  }
  if (web3_js.containsBytes(
    data,
    web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 8).encode(
      new Uint8Array([186, 230, 110, 26, 235, 24, 211, 156])
    ),
    0
  )) {
    return 2 /* BidTa */;
  }
  throw new Error(
    "The provided account could not be identified as a tensorMarketplace account."
  );
}
var TensorMarketplaceInstruction = /* @__PURE__ */ ((TensorMarketplaceInstruction2) => {
  TensorMarketplaceInstruction2[TensorMarketplaceInstruction2["TcompNoop"] = 0] = "TcompNoop";
  TensorMarketplaceInstruction2[TensorMarketplaceInstruction2["Edit"] = 1] = "Edit";
  TensorMarketplaceInstruction2[TensorMarketplaceInstruction2["Bid"] = 2] = "Bid";
  TensorMarketplaceInstruction2[TensorMarketplaceInstruction2["CancelBid"] = 3] = "CancelBid";
  TensorMarketplaceInstruction2[TensorMarketplaceInstruction2["CloseExpiredBid"] = 4] = "CloseExpiredBid";
  TensorMarketplaceInstruction2[TensorMarketplaceInstruction2["BuyCompressed"] = 5] = "BuyCompressed";
  TensorMarketplaceInstruction2[TensorMarketplaceInstruction2["BuySpl"] = 6] = "BuySpl";
  TensorMarketplaceInstruction2[TensorMarketplaceInstruction2["CloseExpiredListingCompressed"] = 7] = "CloseExpiredListingCompressed";
  TensorMarketplaceInstruction2[TensorMarketplaceInstruction2["ListCompressed"] = 8] = "ListCompressed";
  TensorMarketplaceInstruction2[TensorMarketplaceInstruction2["DelistCompressed"] = 9] = "DelistCompressed";
  TensorMarketplaceInstruction2[TensorMarketplaceInstruction2["TakeBidCompressedMetaHash"] = 10] = "TakeBidCompressedMetaHash";
  TensorMarketplaceInstruction2[TensorMarketplaceInstruction2["TakeBidCompressedFullMeta"] = 11] = "TakeBidCompressedFullMeta";
  TensorMarketplaceInstruction2[TensorMarketplaceInstruction2["BuyLegacy"] = 12] = "BuyLegacy";
  TensorMarketplaceInstruction2[TensorMarketplaceInstruction2["BuyLegacySpl"] = 13] = "BuyLegacySpl";
  TensorMarketplaceInstruction2[TensorMarketplaceInstruction2["CloseExpiredListingLegacy"] = 14] = "CloseExpiredListingLegacy";
  TensorMarketplaceInstruction2[TensorMarketplaceInstruction2["DelistLegacy"] = 15] = "DelistLegacy";
  TensorMarketplaceInstruction2[TensorMarketplaceInstruction2["ListLegacy"] = 16] = "ListLegacy";
  TensorMarketplaceInstruction2[TensorMarketplaceInstruction2["TakeBidLegacy"] = 17] = "TakeBidLegacy";
  TensorMarketplaceInstruction2[TensorMarketplaceInstruction2["BuyT22"] = 18] = "BuyT22";
  TensorMarketplaceInstruction2[TensorMarketplaceInstruction2["BuyT22Spl"] = 19] = "BuyT22Spl";
  TensorMarketplaceInstruction2[TensorMarketplaceInstruction2["CloseExpiredListingT22"] = 20] = "CloseExpiredListingT22";
  TensorMarketplaceInstruction2[TensorMarketplaceInstruction2["DelistT22"] = 21] = "DelistT22";
  TensorMarketplaceInstruction2[TensorMarketplaceInstruction2["ListT22"] = 22] = "ListT22";
  TensorMarketplaceInstruction2[TensorMarketplaceInstruction2["TakeBidT22"] = 23] = "TakeBidT22";
  TensorMarketplaceInstruction2[TensorMarketplaceInstruction2["BuyWns"] = 24] = "BuyWns";
  TensorMarketplaceInstruction2[TensorMarketplaceInstruction2["BuyWnsSpl"] = 25] = "BuyWnsSpl";
  TensorMarketplaceInstruction2[TensorMarketplaceInstruction2["CloseExpiredListingWns"] = 26] = "CloseExpiredListingWns";
  TensorMarketplaceInstruction2[TensorMarketplaceInstruction2["DelistWns"] = 27] = "DelistWns";
  TensorMarketplaceInstruction2[TensorMarketplaceInstruction2["ListWns"] = 28] = "ListWns";
  TensorMarketplaceInstruction2[TensorMarketplaceInstruction2["TakeBidWns"] = 29] = "TakeBidWns";
  TensorMarketplaceInstruction2[TensorMarketplaceInstruction2["BuyCore"] = 30] = "BuyCore";
  TensorMarketplaceInstruction2[TensorMarketplaceInstruction2["BuyCoreSpl"] = 31] = "BuyCoreSpl";
  TensorMarketplaceInstruction2[TensorMarketplaceInstruction2["CloseExpiredListingCore"] = 32] = "CloseExpiredListingCore";
  TensorMarketplaceInstruction2[TensorMarketplaceInstruction2["DelistCore"] = 33] = "DelistCore";
  TensorMarketplaceInstruction2[TensorMarketplaceInstruction2["ListCore"] = 34] = "ListCore";
  TensorMarketplaceInstruction2[TensorMarketplaceInstruction2["TakeBidCore"] = 35] = "TakeBidCore";
  return TensorMarketplaceInstruction2;
})(TensorMarketplaceInstruction || {});
function identifyTensorMarketplaceInstruction(instruction) {
  const data = instruction instanceof Uint8Array ? instruction : instruction.data;
  if (web3_js.containsBytes(
    data,
    web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 8).encode(
      new Uint8Array([106, 162, 10, 226, 132, 68, 223, 21])
    ),
    0
  )) {
    return 0 /* TcompNoop */;
  }
  if (web3_js.containsBytes(
    data,
    web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 8).encode(
      new Uint8Array([15, 183, 33, 86, 87, 28, 151, 145])
    ),
    0
  )) {
    return 1 /* Edit */;
  }
  if (web3_js.containsBytes(
    data,
    web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 8).encode(
      new Uint8Array([199, 56, 85, 38, 146, 243, 37, 158])
    ),
    0
  )) {
    return 2 /* Bid */;
  }
  if (web3_js.containsBytes(
    data,
    web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 8).encode(
      new Uint8Array([40, 243, 190, 217, 208, 253, 86, 206])
    ),
    0
  )) {
    return 3 /* CancelBid */;
  }
  if (web3_js.containsBytes(
    data,
    web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 8).encode(
      new Uint8Array([83, 20, 105, 67, 248, 68, 104, 190])
    ),
    0
  )) {
    return 4 /* CloseExpiredBid */;
  }
  if (web3_js.containsBytes(
    data,
    web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 8).encode(
      new Uint8Array([102, 6, 61, 18, 1, 218, 235, 234])
    ),
    0
  )) {
    return 5 /* BuyCompressed */;
  }
  if (web3_js.containsBytes(
    data,
    web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 8).encode(
      new Uint8Array([65, 136, 254, 255, 59, 130, 234, 174])
    ),
    0
  )) {
    return 6 /* BuySpl */;
  }
  if (web3_js.containsBytes(
    data,
    web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 8).encode(
      new Uint8Array([150, 70, 13, 135, 9, 204, 75, 4])
    ),
    0
  )) {
    return 7 /* CloseExpiredListingCompressed */;
  }
  if (web3_js.containsBytes(
    data,
    web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 8).encode(
      new Uint8Array([54, 174, 193, 67, 17, 41, 132, 38])
    ),
    0
  )) {
    return 8 /* ListCompressed */;
  }
  if (web3_js.containsBytes(
    data,
    web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 8).encode(
      new Uint8Array([55, 136, 205, 107, 107, 173, 4, 31])
    ),
    0
  )) {
    return 9 /* DelistCompressed */;
  }
  if (web3_js.containsBytes(
    data,
    web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 8).encode(
      new Uint8Array([85, 227, 202, 70, 45, 215, 10, 193])
    ),
    0
  )) {
    return 10 /* TakeBidCompressedMetaHash */;
  }
  if (web3_js.containsBytes(
    data,
    web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 8).encode(
      new Uint8Array([242, 194, 203, 225, 234, 53, 10, 96])
    ),
    0
  )) {
    return 11 /* TakeBidCompressedFullMeta */;
  }
  if (web3_js.containsBytes(
    data,
    web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 8).encode(
      new Uint8Array([68, 127, 43, 8, 212, 31, 249, 114])
    ),
    0
  )) {
    return 12 /* BuyLegacy */;
  }
  if (web3_js.containsBytes(
    data,
    web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 8).encode(
      new Uint8Array([134, 94, 125, 229, 24, 157, 194, 199])
    ),
    0
  )) {
    return 13 /* BuyLegacySpl */;
  }
  if (web3_js.containsBytes(
    data,
    web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 8).encode(
      new Uint8Array([56, 16, 96, 188, 55, 68, 250, 58])
    ),
    0
  )) {
    return 14 /* CloseExpiredListingLegacy */;
  }
  if (web3_js.containsBytes(
    data,
    web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 8).encode(
      new Uint8Array([88, 35, 231, 184, 110, 218, 149, 23])
    ),
    0
  )) {
    return 15 /* DelistLegacy */;
  }
  if (web3_js.containsBytes(
    data,
    web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 8).encode(
      new Uint8Array([6, 110, 255, 18, 16, 36, 8, 30])
    ),
    0
  )) {
    return 16 /* ListLegacy */;
  }
  if (web3_js.containsBytes(
    data,
    web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 8).encode(
      new Uint8Array([188, 35, 116, 108, 0, 233, 237, 201])
    ),
    0
  )) {
    return 17 /* TakeBidLegacy */;
  }
  if (web3_js.containsBytes(
    data,
    web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 8).encode(
      new Uint8Array([81, 98, 227, 171, 201, 105, 180, 216])
    ),
    0
  )) {
    return 18 /* BuyT22 */;
  }
  if (web3_js.containsBytes(
    data,
    web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 8).encode(
      new Uint8Array([102, 21, 163, 39, 94, 39, 122, 94])
    ),
    0
  )) {
    return 19 /* BuyT22Spl */;
  }
  if (web3_js.containsBytes(
    data,
    web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 8).encode(
      new Uint8Array([69, 2, 190, 122, 144, 119, 122, 220])
    ),
    0
  )) {
    return 20 /* CloseExpiredListingT22 */;
  }
  if (web3_js.containsBytes(
    data,
    web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 8).encode(
      new Uint8Array([216, 72, 73, 18, 204, 82, 123, 26])
    ),
    0
  )) {
    return 21 /* DelistT22 */;
  }
  if (web3_js.containsBytes(
    data,
    web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 8).encode(
      new Uint8Array([9, 117, 93, 230, 221, 4, 199, 212])
    ),
    0
  )) {
    return 22 /* ListT22 */;
  }
  if (web3_js.containsBytes(
    data,
    web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 8).encode(
      new Uint8Array([18, 250, 113, 242, 31, 244, 19, 150])
    ),
    0
  )) {
    return 23 /* TakeBidT22 */;
  }
  if (web3_js.containsBytes(
    data,
    web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 8).encode(
      new Uint8Array([168, 43, 179, 217, 44, 59, 35, 244])
    ),
    0
  )) {
    return 24 /* BuyWns */;
  }
  if (web3_js.containsBytes(
    data,
    web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 8).encode(
      new Uint8Array([113, 137, 57, 23, 186, 196, 217, 210])
    ),
    0
  )) {
    return 25 /* BuyWnsSpl */;
  }
  if (web3_js.containsBytes(
    data,
    web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 8).encode(
      new Uint8Array([222, 31, 183, 134, 230, 207, 7, 132])
    ),
    0
  )) {
    return 26 /* CloseExpiredListingWns */;
  }
  if (web3_js.containsBytes(
    data,
    web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 8).encode(
      new Uint8Array([172, 171, 57, 16, 74, 158, 32, 57])
    ),
    0
  )) {
    return 27 /* DelistWns */;
  }
  if (web3_js.containsBytes(
    data,
    web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 8).encode(
      new Uint8Array([23, 202, 102, 138, 255, 190, 39, 196])
    ),
    0
  )) {
    return 28 /* ListWns */;
  }
  if (web3_js.containsBytes(
    data,
    web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 8).encode(
      new Uint8Array([88, 5, 122, 88, 250, 139, 35, 216])
    ),
    0
  )) {
    return 29 /* TakeBidWns */;
  }
  if (web3_js.containsBytes(
    data,
    web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 8).encode(
      new Uint8Array([169, 227, 87, 255, 76, 86, 255, 25])
    ),
    0
  )) {
    return 30 /* BuyCore */;
  }
  if (web3_js.containsBytes(
    data,
    web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 8).encode(
      new Uint8Array([234, 28, 37, 122, 114, 239, 233, 208])
    ),
    0
  )) {
    return 31 /* BuyCoreSpl */;
  }
  if (web3_js.containsBytes(
    data,
    web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 8).encode(
      new Uint8Array([89, 171, 78, 80, 74, 188, 63, 58])
    ),
    0
  )) {
    return 32 /* CloseExpiredListingCore */;
  }
  if (web3_js.containsBytes(
    data,
    web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 8).encode(
      new Uint8Array([56, 24, 231, 2, 227, 19, 14, 68])
    ),
    0
  )) {
    return 33 /* DelistCore */;
  }
  if (web3_js.containsBytes(
    data,
    web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 8).encode(
      new Uint8Array([173, 76, 167, 125, 118, 71, 1, 153])
    ),
    0
  )) {
    return 34 /* ListCore */;
  }
  if (web3_js.containsBytes(
    data,
    web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 8).encode(
      new Uint8Array([250, 41, 248, 20, 61, 161, 27, 141])
    ),
    0
  )) {
    return 35 /* TakeBidCore */;
  }
  throw new Error(
    "The provided instruction could not be identified as a tensorMarketplace instruction."
  );
}

// src/generated/instructions/bid.ts
function getBidInstructionDataEncoder() {
  return web3_js.transformEncoder(
    web3_js.getStructEncoder([
      ["discriminator", web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 8)],
      ["bidId", web3_js.getAddressEncoder()],
      ["target", getTargetEncoder()],
      ["targetId", web3_js.getAddressEncoder()],
      ["field", web3_js.getOptionEncoder(getFieldEncoder())],
      ["fieldId", web3_js.getOptionEncoder(web3_js.getAddressEncoder())],
      ["amount", web3_js.getU64Encoder()],
      ["quantity", web3_js.getU32Encoder()],
      ["expireInSec", web3_js.getOptionEncoder(web3_js.getU64Encoder())],
      ["currency", web3_js.getOptionEncoder(web3_js.getAddressEncoder())],
      ["privateTaker", web3_js.getOptionEncoder(web3_js.getAddressEncoder())],
      ["makerBroker", web3_js.getOptionEncoder(web3_js.getAddressEncoder())]
    ]),
    (value) => ({
      ...value,
      discriminator: new Uint8Array([199, 56, 85, 38, 146, 243, 37, 158]),
      field: value.field ?? web3_js.none(),
      fieldId: value.fieldId ?? web3_js.none(),
      quantity: value.quantity ?? 1,
      expireInSec: value.expireInSec ?? web3_js.none(),
      currency: value.currency ?? web3_js.none(),
      privateTaker: value.privateTaker ?? web3_js.none(),
      makerBroker: value.makerBroker ?? web3_js.none()
    })
  );
}
function getBidInstructionDataDecoder() {
  return web3_js.getStructDecoder([
    ["discriminator", web3_js.fixDecoderSize(web3_js.getBytesDecoder(), 8)],
    ["bidId", web3_js.getAddressDecoder()],
    ["target", getTargetDecoder()],
    ["targetId", web3_js.getAddressDecoder()],
    ["field", web3_js.getOptionDecoder(getFieldDecoder())],
    ["fieldId", web3_js.getOptionDecoder(web3_js.getAddressDecoder())],
    ["amount", web3_js.getU64Decoder()],
    ["quantity", web3_js.getU32Decoder()],
    ["expireInSec", web3_js.getOptionDecoder(web3_js.getU64Decoder())],
    ["currency", web3_js.getOptionDecoder(web3_js.getAddressDecoder())],
    ["privateTaker", web3_js.getOptionDecoder(web3_js.getAddressDecoder())],
    ["makerBroker", web3_js.getOptionDecoder(web3_js.getAddressDecoder())]
  ]);
}
function getBidInstructionDataCodec() {
  return web3_js.combineCodec(
    getBidInstructionDataEncoder(),
    getBidInstructionDataDecoder()
  );
}
async function getBidInstructionAsync(input) {
  const programAddress = TENSOR_MARKETPLACE_PROGRAM_ADDRESS;
  const originalAccounts = {
    systemProgram: { value: input.systemProgram ?? null, isWritable: false },
    marketplaceProgram: {
      value: input.marketplaceProgram ?? null,
      isWritable: false
    },
    bidState: { value: input.bidState ?? null, isWritable: true },
    owner: { value: input.owner ?? null, isWritable: true },
    sharedEscrow: { value: input.sharedEscrow ?? null, isWritable: true },
    cosigner: { value: input.cosigner ?? null, isWritable: false },
    rentPayer: { value: input.rentPayer ?? null, isWritable: true }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  const resolverScope = { programAddress, accounts, args };
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  if (!accounts.marketplaceProgram.value) {
    accounts.marketplaceProgram.value = "TCMPhJdwDryooaGtiocG1u3xcYbRpiJzb283XfCZsDp";
  }
  if (!args.bidId) {
    args.bidId = await resolveBidIdOnCreate(resolverScope);
  }
  if (!accounts.bidState.value) {
    accounts.bidState.value = await findBidStatePda({
      bidId: expectSome(args.bidId),
      owner: expectAddress(accounts.owner.value)
    });
  }
  if (!accounts.sharedEscrow.value) {
    accounts.sharedEscrow.value = expectTransactionSigner(
      accounts.owner.value
    ).address;
  }
  if (!accounts.rentPayer.value) {
    accounts.rentPayer.value = expectSome(accounts.owner.value);
  }
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.systemProgram),
      getAccountMeta(accounts.marketplaceProgram),
      getAccountMeta(accounts.bidState),
      getAccountMeta(accounts.owner),
      getAccountMeta(accounts.sharedEscrow),
      getAccountMeta(accounts.cosigner),
      getAccountMeta(accounts.rentPayer)
    ],
    programAddress,
    data: getBidInstructionDataEncoder().encode(args)
  };
  return instruction;
}
function getBidInstruction(input) {
  const programAddress = TENSOR_MARKETPLACE_PROGRAM_ADDRESS;
  const originalAccounts = {
    systemProgram: { value: input.systemProgram ?? null, isWritable: false },
    marketplaceProgram: {
      value: input.marketplaceProgram ?? null,
      isWritable: false
    },
    bidState: { value: input.bidState ?? null, isWritable: true },
    owner: { value: input.owner ?? null, isWritable: true },
    sharedEscrow: { value: input.sharedEscrow ?? null, isWritable: true },
    cosigner: { value: input.cosigner ?? null, isWritable: false },
    rentPayer: { value: input.rentPayer ?? null, isWritable: true }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  if (!accounts.marketplaceProgram.value) {
    accounts.marketplaceProgram.value = "TCMPhJdwDryooaGtiocG1u3xcYbRpiJzb283XfCZsDp";
  }
  if (!accounts.sharedEscrow.value) {
    accounts.sharedEscrow.value = expectTransactionSigner(
      accounts.owner.value
    ).address;
  }
  if (!accounts.rentPayer.value) {
    accounts.rentPayer.value = expectSome(accounts.owner.value);
  }
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.systemProgram),
      getAccountMeta(accounts.marketplaceProgram),
      getAccountMeta(accounts.bidState),
      getAccountMeta(accounts.owner),
      getAccountMeta(accounts.sharedEscrow),
      getAccountMeta(accounts.cosigner),
      getAccountMeta(accounts.rentPayer)
    ],
    programAddress,
    data: getBidInstructionDataEncoder().encode(args)
  };
  return instruction;
}
function parseBidInstruction(instruction) {
  if (instruction.accounts.length < 7) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  const getNextOptionalAccount = () => {
    const accountMeta = getNextAccount();
    return accountMeta.address === TENSOR_MARKETPLACE_PROGRAM_ADDRESS ? void 0 : accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      systemProgram: getNextAccount(),
      marketplaceProgram: getNextAccount(),
      bidState: getNextAccount(),
      owner: getNextAccount(),
      sharedEscrow: getNextAccount(),
      cosigner: getNextOptionalAccount(),
      rentPayer: getNextAccount()
    },
    data: getBidInstructionDataDecoder().decode(instruction.data)
  };
}
function getBuyCompressedInstructionDataEncoder() {
  return web3_js.transformEncoder(
    web3_js.getStructEncoder([
      ["discriminator", web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 8)],
      ["nonce", web3_js.getU64Encoder()],
      ["index", web3_js.getU32Encoder()],
      ["root", web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 32)],
      ["metaHash", web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 32)],
      [
        "creatorShares",
        web3_js.addEncoderSizePrefix(web3_js.getBytesEncoder(), web3_js.getU32Encoder())
      ],
      ["creatorVerified", web3_js.getArrayEncoder(web3_js.getBooleanEncoder())],
      ["sellerFeeBasisPoints", web3_js.getU16Encoder()],
      ["maxAmount", web3_js.getU64Encoder()],
      ["optionalRoyaltyPct", web3_js.getOptionEncoder(web3_js.getU16Encoder())]
    ]),
    (value) => ({
      ...value,
      discriminator: new Uint8Array([102, 6, 61, 18, 1, 218, 235, 234]),
      optionalRoyaltyPct: value.optionalRoyaltyPct ?? 100
    })
  );
}
function getBuyCompressedInstructionDataDecoder() {
  return web3_js.getStructDecoder([
    ["discriminator", web3_js.fixDecoderSize(web3_js.getBytesDecoder(), 8)],
    ["nonce", web3_js.getU64Decoder()],
    ["index", web3_js.getU32Decoder()],
    ["root", web3_js.fixDecoderSize(web3_js.getBytesDecoder(), 32)],
    ["metaHash", web3_js.fixDecoderSize(web3_js.getBytesDecoder(), 32)],
    ["creatorShares", web3_js.addDecoderSizePrefix(web3_js.getBytesDecoder(), web3_js.getU32Decoder())],
    ["creatorVerified", web3_js.getArrayDecoder(web3_js.getBooleanDecoder())],
    ["sellerFeeBasisPoints", web3_js.getU16Decoder()],
    ["maxAmount", web3_js.getU64Decoder()],
    ["optionalRoyaltyPct", web3_js.getOptionDecoder(web3_js.getU16Decoder())]
  ]);
}
function getBuyCompressedInstructionDataCodec() {
  return web3_js.combineCodec(
    getBuyCompressedInstructionDataEncoder(),
    getBuyCompressedInstructionDataDecoder()
  );
}
async function getBuyCompressedInstructionAsync(input) {
  const programAddress = TENSOR_MARKETPLACE_PROGRAM_ADDRESS;
  const originalAccounts = {
    feeVault: { value: input.feeVault ?? null, isWritable: true },
    treeAuthority: { value: input.treeAuthority ?? null, isWritable: false },
    merkleTree: { value: input.merkleTree ?? null, isWritable: true },
    logWrapper: { value: input.logWrapper ?? null, isWritable: false },
    compressionProgram: {
      value: input.compressionProgram ?? null,
      isWritable: false
    },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false },
    bubblegumProgram: {
      value: input.bubblegumProgram ?? null,
      isWritable: false
    },
    marketplaceProgram: {
      value: input.marketplaceProgram ?? null,
      isWritable: false
    },
    listState: { value: input.listState ?? null, isWritable: true },
    buyer: { value: input.buyer ?? null, isWritable: false },
    payer: { value: input.payer ?? null, isWritable: true },
    owner: { value: input.owner ?? null, isWritable: true },
    takerBroker: { value: input.takerBroker ?? null, isWritable: true },
    makerBroker: { value: input.makerBroker ?? null, isWritable: true },
    rentDestination: { value: input.rentDestination ?? null, isWritable: true },
    cosigner: { value: input.cosigner ?? null, isWritable: false }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  const resolverScope = { programAddress, accounts, args };
  if (!accounts.feeVault.value) {
    accounts.feeVault = {
      ...accounts.feeVault,
      ...await resolveFeeVaultPdaFromListState(resolverScope)
    };
  }
  if (!accounts.bubblegumProgram.value) {
    accounts.bubblegumProgram.value = "BGUMAp9Gq7iTEuizy4pqaxsTyUCBK68MDfK752saRPUY";
  }
  if (!accounts.treeAuthority.value) {
    accounts.treeAuthority = {
      ...accounts.treeAuthority,
      ...await resolveTreeAuthorityPda(resolverScope)
    };
  }
  if (!accounts.logWrapper.value) {
    accounts.logWrapper.value = "noopb9bkMVfRPU8AsbpTUg8AQkHtKwMYZiFUjNRtMmV";
  }
  if (!accounts.compressionProgram.value) {
    accounts.compressionProgram.value = "cmtDvXumGCrqC1Age74AVPhSRVXJMd8PJS91L8KbNCK";
  }
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  if (!accounts.marketplaceProgram.value) {
    accounts.marketplaceProgram.value = "TCMPhJdwDryooaGtiocG1u3xcYbRpiJzb283XfCZsDp";
  }
  if (!accounts.buyer.value) {
    accounts.buyer.value = expectTransactionSigner(
      accounts.payer.value
    ).address;
  }
  if (!accounts.rentDestination.value) {
    accounts.rentDestination.value = expectSome(accounts.owner.value);
  }
  if (!accounts.cosigner.value) {
    accounts.cosigner.value = "TCMPhJdwDryooaGtiocG1u3xcYbRpiJzb283XfCZsDp";
  }
  if (!args.nonce) {
    args.nonce = expectSome(args.index);
  }
  if (!args.creators) {
    args.creators = [];
  }
  if (!args.proof) {
    args.proof = [];
  }
  if (!args.canopyDepth) {
    args.canopyDepth = 0;
  }
  const remainingAccounts = [
    ...resolveCreatorPath(resolverScope),
    ...resolveProofPath(resolverScope)
  ];
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.feeVault),
      getAccountMeta(accounts.treeAuthority),
      getAccountMeta(accounts.merkleTree),
      getAccountMeta(accounts.logWrapper),
      getAccountMeta(accounts.compressionProgram),
      getAccountMeta(accounts.systemProgram),
      getAccountMeta(accounts.bubblegumProgram),
      getAccountMeta(accounts.marketplaceProgram),
      getAccountMeta(accounts.listState),
      getAccountMeta(accounts.buyer),
      getAccountMeta(accounts.payer),
      getAccountMeta(accounts.owner),
      getAccountMeta(accounts.takerBroker),
      getAccountMeta(accounts.makerBroker),
      getAccountMeta(accounts.rentDestination),
      getAccountMeta(accounts.cosigner),
      ...remainingAccounts
    ],
    programAddress,
    data: getBuyCompressedInstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function getBuyCompressedInstruction(input) {
  const programAddress = TENSOR_MARKETPLACE_PROGRAM_ADDRESS;
  const originalAccounts = {
    feeVault: { value: input.feeVault ?? null, isWritable: true },
    treeAuthority: { value: input.treeAuthority ?? null, isWritable: false },
    merkleTree: { value: input.merkleTree ?? null, isWritable: true },
    logWrapper: { value: input.logWrapper ?? null, isWritable: false },
    compressionProgram: {
      value: input.compressionProgram ?? null,
      isWritable: false
    },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false },
    bubblegumProgram: {
      value: input.bubblegumProgram ?? null,
      isWritable: false
    },
    marketplaceProgram: {
      value: input.marketplaceProgram ?? null,
      isWritable: false
    },
    listState: { value: input.listState ?? null, isWritable: true },
    buyer: { value: input.buyer ?? null, isWritable: false },
    payer: { value: input.payer ?? null, isWritable: true },
    owner: { value: input.owner ?? null, isWritable: true },
    takerBroker: { value: input.takerBroker ?? null, isWritable: true },
    makerBroker: { value: input.makerBroker ?? null, isWritable: true },
    rentDestination: { value: input.rentDestination ?? null, isWritable: true },
    cosigner: { value: input.cosigner ?? null, isWritable: false }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  const resolverScope = { programAddress, accounts, args };
  if (!accounts.bubblegumProgram.value) {
    accounts.bubblegumProgram.value = "BGUMAp9Gq7iTEuizy4pqaxsTyUCBK68MDfK752saRPUY";
  }
  if (!accounts.logWrapper.value) {
    accounts.logWrapper.value = "noopb9bkMVfRPU8AsbpTUg8AQkHtKwMYZiFUjNRtMmV";
  }
  if (!accounts.compressionProgram.value) {
    accounts.compressionProgram.value = "cmtDvXumGCrqC1Age74AVPhSRVXJMd8PJS91L8KbNCK";
  }
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  if (!accounts.marketplaceProgram.value) {
    accounts.marketplaceProgram.value = "TCMPhJdwDryooaGtiocG1u3xcYbRpiJzb283XfCZsDp";
  }
  if (!accounts.buyer.value) {
    accounts.buyer.value = expectTransactionSigner(
      accounts.payer.value
    ).address;
  }
  if (!accounts.rentDestination.value) {
    accounts.rentDestination.value = expectSome(accounts.owner.value);
  }
  if (!accounts.cosigner.value) {
    accounts.cosigner.value = "TCMPhJdwDryooaGtiocG1u3xcYbRpiJzb283XfCZsDp";
  }
  if (!args.nonce) {
    args.nonce = expectSome(args.index);
  }
  if (!args.creators) {
    args.creators = [];
  }
  if (!args.proof) {
    args.proof = [];
  }
  if (!args.canopyDepth) {
    args.canopyDepth = 0;
  }
  const remainingAccounts = [
    ...resolveCreatorPath(resolverScope),
    ...resolveProofPath(resolverScope)
  ];
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.feeVault),
      getAccountMeta(accounts.treeAuthority),
      getAccountMeta(accounts.merkleTree),
      getAccountMeta(accounts.logWrapper),
      getAccountMeta(accounts.compressionProgram),
      getAccountMeta(accounts.systemProgram),
      getAccountMeta(accounts.bubblegumProgram),
      getAccountMeta(accounts.marketplaceProgram),
      getAccountMeta(accounts.listState),
      getAccountMeta(accounts.buyer),
      getAccountMeta(accounts.payer),
      getAccountMeta(accounts.owner),
      getAccountMeta(accounts.takerBroker),
      getAccountMeta(accounts.makerBroker),
      getAccountMeta(accounts.rentDestination),
      getAccountMeta(accounts.cosigner),
      ...remainingAccounts
    ],
    programAddress,
    data: getBuyCompressedInstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function parseBuyCompressedInstruction(instruction) {
  if (instruction.accounts.length < 16) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  const getNextOptionalAccount = () => {
    const accountMeta = getNextAccount();
    return accountMeta.address === TENSOR_MARKETPLACE_PROGRAM_ADDRESS ? void 0 : accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      feeVault: getNextAccount(),
      treeAuthority: getNextAccount(),
      merkleTree: getNextAccount(),
      logWrapper: getNextAccount(),
      compressionProgram: getNextAccount(),
      systemProgram: getNextAccount(),
      bubblegumProgram: getNextAccount(),
      marketplaceProgram: getNextAccount(),
      listState: getNextAccount(),
      buyer: getNextAccount(),
      payer: getNextAccount(),
      owner: getNextAccount(),
      takerBroker: getNextOptionalAccount(),
      makerBroker: getNextOptionalAccount(),
      rentDestination: getNextAccount(),
      cosigner: getNextOptionalAccount()
    },
    data: getBuyCompressedInstructionDataDecoder().decode(instruction.data)
  };
}
function getBuyCoreInstructionDataEncoder() {
  return web3_js.transformEncoder(
    web3_js.getStructEncoder([
      ["discriminator", web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 8)],
      ["maxAmount", web3_js.getU64Encoder()]
    ]),
    (value) => ({
      ...value,
      discriminator: new Uint8Array([169, 227, 87, 255, 76, 86, 255, 25])
    })
  );
}
function getBuyCoreInstructionDataDecoder() {
  return web3_js.getStructDecoder([
    ["discriminator", web3_js.fixDecoderSize(web3_js.getBytesDecoder(), 8)],
    ["maxAmount", web3_js.getU64Decoder()]
  ]);
}
function getBuyCoreInstructionDataCodec() {
  return web3_js.combineCodec(
    getBuyCoreInstructionDataEncoder(),
    getBuyCoreInstructionDataDecoder()
  );
}
function getBuyCoreInstruction(input) {
  const programAddress = TENSOR_MARKETPLACE_PROGRAM_ADDRESS;
  const originalAccounts = {
    feeVault: { value: input.feeVault ?? null, isWritable: true },
    listState: { value: input.listState ?? null, isWritable: true },
    asset: { value: input.asset ?? null, isWritable: true },
    collection: { value: input.collection ?? null, isWritable: false },
    buyer: { value: input.buyer ?? null, isWritable: false },
    payer: { value: input.payer ?? null, isWritable: true },
    owner: { value: input.owner ?? null, isWritable: true },
    takerBroker: { value: input.takerBroker ?? null, isWritable: true },
    makerBroker: { value: input.makerBroker ?? null, isWritable: true },
    rentDestination: { value: input.rentDestination ?? null, isWritable: true },
    mplCoreProgram: { value: input.mplCoreProgram ?? null, isWritable: false },
    marketplaceProgram: {
      value: input.marketplaceProgram ?? null,
      isWritable: false
    },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false },
    cosigner: { value: input.cosigner ?? null, isWritable: false }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  if (!accounts.buyer.value) {
    accounts.buyer.value = expectTransactionSigner(
      accounts.payer.value
    ).address;
  }
  if (!accounts.rentDestination.value) {
    accounts.rentDestination.value = expectSome(accounts.owner.value);
  }
  if (!accounts.mplCoreProgram.value) {
    accounts.mplCoreProgram.value = "CoREENxT6tW1HoK8ypY1SxRMZTcVPm7R94rH4PZNhX7d";
  }
  if (!accounts.marketplaceProgram.value) {
    accounts.marketplaceProgram.value = "TCMPhJdwDryooaGtiocG1u3xcYbRpiJzb283XfCZsDp";
  }
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  if (!accounts.cosigner.value) {
    accounts.cosigner.value = "TCMPhJdwDryooaGtiocG1u3xcYbRpiJzb283XfCZsDp";
  }
  const remainingAccounts = (args.creators ?? []).map(
    (address3) => ({ address: address3, role: web3_js.AccountRole.WRITABLE })
  );
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.feeVault),
      getAccountMeta(accounts.listState),
      getAccountMeta(accounts.asset),
      getAccountMeta(accounts.collection),
      getAccountMeta(accounts.buyer),
      getAccountMeta(accounts.payer),
      getAccountMeta(accounts.owner),
      getAccountMeta(accounts.takerBroker),
      getAccountMeta(accounts.makerBroker),
      getAccountMeta(accounts.rentDestination),
      getAccountMeta(accounts.mplCoreProgram),
      getAccountMeta(accounts.marketplaceProgram),
      getAccountMeta(accounts.systemProgram),
      getAccountMeta(accounts.cosigner),
      ...remainingAccounts
    ],
    programAddress,
    data: getBuyCoreInstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function parseBuyCoreInstruction(instruction) {
  if (instruction.accounts.length < 14) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  const getNextOptionalAccount = () => {
    const accountMeta = getNextAccount();
    return accountMeta.address === TENSOR_MARKETPLACE_PROGRAM_ADDRESS ? void 0 : accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      feeVault: getNextAccount(),
      listState: getNextAccount(),
      asset: getNextAccount(),
      collection: getNextOptionalAccount(),
      buyer: getNextAccount(),
      payer: getNextAccount(),
      owner: getNextAccount(),
      takerBroker: getNextOptionalAccount(),
      makerBroker: getNextOptionalAccount(),
      rentDestination: getNextAccount(),
      mplCoreProgram: getNextAccount(),
      marketplaceProgram: getNextAccount(),
      systemProgram: getNextAccount(),
      cosigner: getNextOptionalAccount()
    },
    data: getBuyCoreInstructionDataDecoder().decode(instruction.data)
  };
}
function getBuyCoreSplInstructionDataEncoder() {
  return web3_js.transformEncoder(
    web3_js.getStructEncoder([
      ["discriminator", web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 8)],
      ["maxAmount", web3_js.getU64Encoder()]
    ]),
    (value) => ({
      ...value,
      discriminator: new Uint8Array([234, 28, 37, 122, 114, 239, 233, 208])
    })
  );
}
function getBuyCoreSplInstructionDataDecoder() {
  return web3_js.getStructDecoder([
    ["discriminator", web3_js.fixDecoderSize(web3_js.getBytesDecoder(), 8)],
    ["maxAmount", web3_js.getU64Decoder()]
  ]);
}
function getBuyCoreSplInstructionDataCodec() {
  return web3_js.combineCodec(
    getBuyCoreSplInstructionDataEncoder(),
    getBuyCoreSplInstructionDataDecoder()
  );
}
function getBuyCoreSplInstruction(input) {
  const programAddress = TENSOR_MARKETPLACE_PROGRAM_ADDRESS;
  const originalAccounts = {
    feeVault: { value: input.feeVault ?? null, isWritable: true },
    feeVaultCurrencyTa: {
      value: input.feeVaultCurrencyTa ?? null,
      isWritable: true
    },
    buyer: { value: input.buyer ?? null, isWritable: false },
    listState: { value: input.listState ?? null, isWritable: true },
    asset: { value: input.asset ?? null, isWritable: true },
    collection: { value: input.collection ?? null, isWritable: false },
    currency: { value: input.currency ?? null, isWritable: false },
    owner: { value: input.owner ?? null, isWritable: true },
    ownerCurrencyTa: { value: input.ownerCurrencyTa ?? null, isWritable: true },
    payer: { value: input.payer ?? null, isWritable: true },
    payerCurrencyTa: { value: input.payerCurrencyTa ?? null, isWritable: true },
    takerBroker: { value: input.takerBroker ?? null, isWritable: true },
    takerBrokerTa: { value: input.takerBrokerTa ?? null, isWritable: true },
    makerBroker: { value: input.makerBroker ?? null, isWritable: true },
    makerBrokerTa: { value: input.makerBrokerTa ?? null, isWritable: true },
    rentDestination: { value: input.rentDestination ?? null, isWritable: true },
    tokenProgram: { value: input.tokenProgram ?? null, isWritable: false },
    associatedTokenProgram: {
      value: input.associatedTokenProgram ?? null,
      isWritable: false
    },
    mplCoreProgram: { value: input.mplCoreProgram ?? null, isWritable: false },
    marketplaceProgram: {
      value: input.marketplaceProgram ?? null,
      isWritable: false
    },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false },
    cosigner: { value: input.cosigner ?? null, isWritable: false }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  if (!accounts.buyer.value) {
    accounts.buyer.value = expectTransactionSigner(
      accounts.payer.value
    ).address;
  }
  if (!accounts.rentDestination.value) {
    accounts.rentDestination.value = expectSome(accounts.owner.value);
  }
  if (!accounts.tokenProgram.value) {
    accounts.tokenProgram.value = "TokenkegQfeZyiNwAJbNbGKPFXCWuBvf9Ss623VQ5DA";
  }
  if (!accounts.associatedTokenProgram.value) {
    accounts.associatedTokenProgram.value = "ATokenGPvbdGVxr1b2hvZbsiqW5xWH25efTNsLJA8knL";
  }
  if (!accounts.mplCoreProgram.value) {
    accounts.mplCoreProgram.value = "CoREENxT6tW1HoK8ypY1SxRMZTcVPm7R94rH4PZNhX7d";
  }
  if (!accounts.marketplaceProgram.value) {
    accounts.marketplaceProgram.value = "TCMPhJdwDryooaGtiocG1u3xcYbRpiJzb283XfCZsDp";
  }
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  const remainingAccounts = [
    ...(args.creators ?? []).map((address3) => ({
      address: address3,
      role: web3_js.AccountRole.WRITABLE
    })),
    ...(args.creatorsAtas ?? []).map((address3) => ({
      address: address3,
      role: web3_js.AccountRole.WRITABLE
    }))
  ];
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.feeVault),
      getAccountMeta(accounts.feeVaultCurrencyTa),
      getAccountMeta(accounts.buyer),
      getAccountMeta(accounts.listState),
      getAccountMeta(accounts.asset),
      getAccountMeta(accounts.collection),
      getAccountMeta(accounts.currency),
      getAccountMeta(accounts.owner),
      getAccountMeta(accounts.ownerCurrencyTa),
      getAccountMeta(accounts.payer),
      getAccountMeta(accounts.payerCurrencyTa),
      getAccountMeta(accounts.takerBroker),
      getAccountMeta(accounts.takerBrokerTa),
      getAccountMeta(accounts.makerBroker),
      getAccountMeta(accounts.makerBrokerTa),
      getAccountMeta(accounts.rentDestination),
      getAccountMeta(accounts.tokenProgram),
      getAccountMeta(accounts.associatedTokenProgram),
      getAccountMeta(accounts.mplCoreProgram),
      getAccountMeta(accounts.marketplaceProgram),
      getAccountMeta(accounts.systemProgram),
      getAccountMeta(accounts.cosigner),
      ...remainingAccounts
    ],
    programAddress,
    data: getBuyCoreSplInstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function parseBuyCoreSplInstruction(instruction) {
  if (instruction.accounts.length < 22) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  const getNextOptionalAccount = () => {
    const accountMeta = getNextAccount();
    return accountMeta.address === TENSOR_MARKETPLACE_PROGRAM_ADDRESS ? void 0 : accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      feeVault: getNextAccount(),
      feeVaultCurrencyTa: getNextAccount(),
      buyer: getNextAccount(),
      listState: getNextAccount(),
      asset: getNextAccount(),
      collection: getNextOptionalAccount(),
      currency: getNextAccount(),
      owner: getNextAccount(),
      ownerCurrencyTa: getNextAccount(),
      payer: getNextAccount(),
      payerCurrencyTa: getNextAccount(),
      takerBroker: getNextOptionalAccount(),
      takerBrokerTa: getNextOptionalAccount(),
      makerBroker: getNextOptionalAccount(),
      makerBrokerTa: getNextOptionalAccount(),
      rentDestination: getNextAccount(),
      tokenProgram: getNextAccount(),
      associatedTokenProgram: getNextAccount(),
      mplCoreProgram: getNextAccount(),
      marketplaceProgram: getNextAccount(),
      systemProgram: getNextAccount(),
      cosigner: getNextOptionalAccount()
    },
    data: getBuyCoreSplInstructionDataDecoder().decode(instruction.data)
  };
}
function getBuyLegacyInstructionDataEncoder() {
  return web3_js.transformEncoder(
    web3_js.getStructEncoder([
      ["discriminator", web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 8)],
      ["maxAmount", web3_js.getU64Encoder()],
      ["optionalRoyaltyPct", web3_js.getOptionEncoder(web3_js.getU16Encoder())],
      [
        "authorizationData",
        web3_js.getOptionEncoder(getAuthorizationDataLocalEncoder())
      ]
    ]),
    (value) => ({
      ...value,
      discriminator: new Uint8Array([68, 127, 43, 8, 212, 31, 249, 114]),
      optionalRoyaltyPct: value.optionalRoyaltyPct ?? web3_js.none(),
      authorizationData: value.authorizationData ?? web3_js.none()
    })
  );
}
function getBuyLegacyInstructionDataDecoder() {
  return web3_js.getStructDecoder([
    ["discriminator", web3_js.fixDecoderSize(web3_js.getBytesDecoder(), 8)],
    ["maxAmount", web3_js.getU64Decoder()],
    ["optionalRoyaltyPct", web3_js.getOptionDecoder(web3_js.getU16Decoder())],
    ["authorizationData", web3_js.getOptionDecoder(getAuthorizationDataLocalDecoder())]
  ]);
}
function getBuyLegacyInstructionDataCodec() {
  return web3_js.combineCodec(
    getBuyLegacyInstructionDataEncoder(),
    getBuyLegacyInstructionDataDecoder()
  );
}
async function getBuyLegacyInstructionAsync(input) {
  const programAddress = TENSOR_MARKETPLACE_PROGRAM_ADDRESS;
  const originalAccounts = {
    feeVault: { value: input.feeVault ?? null, isWritable: true },
    buyer: { value: input.buyer ?? null, isWritable: false },
    buyerTa: { value: input.buyerTa ?? null, isWritable: true },
    listTa: { value: input.listTa ?? null, isWritable: true },
    listState: { value: input.listState ?? null, isWritable: true },
    mint: { value: input.mint ?? null, isWritable: false },
    owner: { value: input.owner ?? null, isWritable: true },
    payer: { value: input.payer ?? null, isWritable: true },
    takerBroker: { value: input.takerBroker ?? null, isWritable: true },
    makerBroker: { value: input.makerBroker ?? null, isWritable: true },
    rentDestination: { value: input.rentDestination ?? null, isWritable: true },
    tokenProgram: { value: input.tokenProgram ?? null, isWritable: false },
    associatedTokenProgram: {
      value: input.associatedTokenProgram ?? null,
      isWritable: false
    },
    marketplaceProgram: {
      value: input.marketplaceProgram ?? null,
      isWritable: false
    },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false },
    metadata: { value: input.metadata ?? null, isWritable: true },
    edition: { value: input.edition ?? null, isWritable: false },
    buyerTokenRecord: {
      value: input.buyerTokenRecord ?? null,
      isWritable: true
    },
    listTokenRecord: { value: input.listTokenRecord ?? null, isWritable: true },
    authorizationRules: {
      value: input.authorizationRules ?? null,
      isWritable: false
    },
    authorizationRulesProgram: {
      value: input.authorizationRulesProgram ?? null,
      isWritable: false
    },
    tokenMetadataProgram: {
      value: input.tokenMetadataProgram ?? null,
      isWritable: false
    },
    sysvarInstructions: {
      value: input.sysvarInstructions ?? null,
      isWritable: false
    },
    cosigner: { value: input.cosigner ?? null, isWritable: false }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  const resolverScope = { programAddress, accounts, args };
  if (!accounts.listState.value) {
    accounts.listState.value = await findListStatePda({
      mint: expectAddress(accounts.mint.value)
    });
  }
  if (!accounts.feeVault.value) {
    accounts.feeVault = {
      ...accounts.feeVault,
      ...await resolveFeeVaultPdaFromListState(resolverScope)
    };
  }
  if (!accounts.buyer.value) {
    accounts.buyer.value = expectTransactionSigner(
      accounts.payer.value
    ).address;
  }
  if (!accounts.tokenProgram.value) {
    accounts.tokenProgram.value = "TokenkegQfeZyiNwAJbNbGKPFXCWuBvf9Ss623VQ5DA";
  }
  if (!accounts.buyerTa.value) {
    accounts.buyerTa = {
      ...accounts.buyerTa,
      ...await resolvers.resolveBuyerAta(resolverScope)
    };
  }
  if (!accounts.listTa.value) {
    accounts.listTa = {
      ...accounts.listTa,
      ...await resolvers.resolveListAta(resolverScope)
    };
  }
  if (!accounts.rentDestination.value) {
    accounts.rentDestination.value = expectSome(accounts.owner.value);
  }
  if (!accounts.associatedTokenProgram.value) {
    accounts.associatedTokenProgram.value = "ATokenGPvbdGVxr1b2hvZbsiqW5xWH25efTNsLJA8knL";
  }
  if (!accounts.marketplaceProgram.value) {
    accounts.marketplaceProgram.value = "TCMPhJdwDryooaGtiocG1u3xcYbRpiJzb283XfCZsDp";
  }
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  if (!accounts.metadata.value) {
    accounts.metadata = {
      ...accounts.metadata,
      ...await resolvers.resolveMetadata(resolverScope)
    };
  }
  if (!args.tokenStandard) {
    args.tokenStandard = resolvers.TokenStandard.ProgrammableNonFungible;
  }
  if (!accounts.edition.value) {
    accounts.edition = {
      ...accounts.edition,
      ...await resolvers.resolveEditionFromTokenStandard(resolverScope)
    };
  }
  if (!accounts.buyerTokenRecord.value) {
    accounts.buyerTokenRecord = {
      ...accounts.buyerTokenRecord,
      ...await resolvers.resolveBuyerTokenRecordFromTokenStandard(resolverScope)
    };
  }
  if (!accounts.listTokenRecord.value) {
    accounts.listTokenRecord = {
      ...accounts.listTokenRecord,
      ...await resolvers.resolveListTokenRecordFromTokenStandard(resolverScope)
    };
  }
  if (!accounts.authorizationRulesProgram.value) {
    accounts.authorizationRulesProgram = {
      ...accounts.authorizationRulesProgram,
      ...resolvers.resolveAuthorizationRulesProgramFromTokenStandard(resolverScope)
    };
  }
  if (!accounts.tokenMetadataProgram.value) {
    accounts.tokenMetadataProgram = {
      ...accounts.tokenMetadataProgram,
      ...resolvers.resolveTokenMetadataProgramFromTokenStandard(resolverScope)
    };
  }
  if (!accounts.sysvarInstructions.value) {
    accounts.sysvarInstructions = {
      ...accounts.sysvarInstructions,
      ...resolvers.resolveSysvarInstructionsFromTokenStandard(resolverScope)
    };
  }
  if (!accounts.cosigner.value) {
    accounts.cosigner.value = "TCMPhJdwDryooaGtiocG1u3xcYbRpiJzb283XfCZsDp";
  }
  const remainingAccounts = (args.creators ?? []).map(
    (address3) => ({ address: address3, role: web3_js.AccountRole.WRITABLE })
  );
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.feeVault),
      getAccountMeta(accounts.buyer),
      getAccountMeta(accounts.buyerTa),
      getAccountMeta(accounts.listTa),
      getAccountMeta(accounts.listState),
      getAccountMeta(accounts.mint),
      getAccountMeta(accounts.owner),
      getAccountMeta(accounts.payer),
      getAccountMeta(accounts.takerBroker),
      getAccountMeta(accounts.makerBroker),
      getAccountMeta(accounts.rentDestination),
      getAccountMeta(accounts.tokenProgram),
      getAccountMeta(accounts.associatedTokenProgram),
      getAccountMeta(accounts.marketplaceProgram),
      getAccountMeta(accounts.systemProgram),
      getAccountMeta(accounts.metadata),
      getAccountMeta(accounts.edition),
      getAccountMeta(accounts.buyerTokenRecord),
      getAccountMeta(accounts.listTokenRecord),
      getAccountMeta(accounts.authorizationRules),
      getAccountMeta(accounts.authorizationRulesProgram),
      getAccountMeta(accounts.tokenMetadataProgram),
      getAccountMeta(accounts.sysvarInstructions),
      getAccountMeta(accounts.cosigner),
      ...remainingAccounts
    ],
    programAddress,
    data: getBuyLegacyInstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function getBuyLegacyInstruction(input) {
  const programAddress = TENSOR_MARKETPLACE_PROGRAM_ADDRESS;
  const originalAccounts = {
    feeVault: { value: input.feeVault ?? null, isWritable: true },
    buyer: { value: input.buyer ?? null, isWritable: false },
    buyerTa: { value: input.buyerTa ?? null, isWritable: true },
    listTa: { value: input.listTa ?? null, isWritable: true },
    listState: { value: input.listState ?? null, isWritable: true },
    mint: { value: input.mint ?? null, isWritable: false },
    owner: { value: input.owner ?? null, isWritable: true },
    payer: { value: input.payer ?? null, isWritable: true },
    takerBroker: { value: input.takerBroker ?? null, isWritable: true },
    makerBroker: { value: input.makerBroker ?? null, isWritable: true },
    rentDestination: { value: input.rentDestination ?? null, isWritable: true },
    tokenProgram: { value: input.tokenProgram ?? null, isWritable: false },
    associatedTokenProgram: {
      value: input.associatedTokenProgram ?? null,
      isWritable: false
    },
    marketplaceProgram: {
      value: input.marketplaceProgram ?? null,
      isWritable: false
    },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false },
    metadata: { value: input.metadata ?? null, isWritable: true },
    edition: { value: input.edition ?? null, isWritable: false },
    buyerTokenRecord: {
      value: input.buyerTokenRecord ?? null,
      isWritable: true
    },
    listTokenRecord: { value: input.listTokenRecord ?? null, isWritable: true },
    authorizationRules: {
      value: input.authorizationRules ?? null,
      isWritable: false
    },
    authorizationRulesProgram: {
      value: input.authorizationRulesProgram ?? null,
      isWritable: false
    },
    tokenMetadataProgram: {
      value: input.tokenMetadataProgram ?? null,
      isWritable: false
    },
    sysvarInstructions: {
      value: input.sysvarInstructions ?? null,
      isWritable: false
    },
    cosigner: { value: input.cosigner ?? null, isWritable: false }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  const resolverScope = { programAddress, accounts, args };
  if (!accounts.buyer.value) {
    accounts.buyer.value = expectTransactionSigner(
      accounts.payer.value
    ).address;
  }
  if (!accounts.tokenProgram.value) {
    accounts.tokenProgram.value = "TokenkegQfeZyiNwAJbNbGKPFXCWuBvf9Ss623VQ5DA";
  }
  if (!accounts.rentDestination.value) {
    accounts.rentDestination.value = expectSome(accounts.owner.value);
  }
  if (!accounts.associatedTokenProgram.value) {
    accounts.associatedTokenProgram.value = "ATokenGPvbdGVxr1b2hvZbsiqW5xWH25efTNsLJA8knL";
  }
  if (!accounts.marketplaceProgram.value) {
    accounts.marketplaceProgram.value = "TCMPhJdwDryooaGtiocG1u3xcYbRpiJzb283XfCZsDp";
  }
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  if (!args.tokenStandard) {
    args.tokenStandard = resolvers.TokenStandard.ProgrammableNonFungible;
  }
  if (!accounts.authorizationRulesProgram.value) {
    accounts.authorizationRulesProgram = {
      ...accounts.authorizationRulesProgram,
      ...resolvers.resolveAuthorizationRulesProgramFromTokenStandard(resolverScope)
    };
  }
  if (!accounts.tokenMetadataProgram.value) {
    accounts.tokenMetadataProgram = {
      ...accounts.tokenMetadataProgram,
      ...resolvers.resolveTokenMetadataProgramFromTokenStandard(resolverScope)
    };
  }
  if (!accounts.sysvarInstructions.value) {
    accounts.sysvarInstructions = {
      ...accounts.sysvarInstructions,
      ...resolvers.resolveSysvarInstructionsFromTokenStandard(resolverScope)
    };
  }
  if (!accounts.cosigner.value) {
    accounts.cosigner.value = "TCMPhJdwDryooaGtiocG1u3xcYbRpiJzb283XfCZsDp";
  }
  const remainingAccounts = (args.creators ?? []).map(
    (address3) => ({ address: address3, role: web3_js.AccountRole.WRITABLE })
  );
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.feeVault),
      getAccountMeta(accounts.buyer),
      getAccountMeta(accounts.buyerTa),
      getAccountMeta(accounts.listTa),
      getAccountMeta(accounts.listState),
      getAccountMeta(accounts.mint),
      getAccountMeta(accounts.owner),
      getAccountMeta(accounts.payer),
      getAccountMeta(accounts.takerBroker),
      getAccountMeta(accounts.makerBroker),
      getAccountMeta(accounts.rentDestination),
      getAccountMeta(accounts.tokenProgram),
      getAccountMeta(accounts.associatedTokenProgram),
      getAccountMeta(accounts.marketplaceProgram),
      getAccountMeta(accounts.systemProgram),
      getAccountMeta(accounts.metadata),
      getAccountMeta(accounts.edition),
      getAccountMeta(accounts.buyerTokenRecord),
      getAccountMeta(accounts.listTokenRecord),
      getAccountMeta(accounts.authorizationRules),
      getAccountMeta(accounts.authorizationRulesProgram),
      getAccountMeta(accounts.tokenMetadataProgram),
      getAccountMeta(accounts.sysvarInstructions),
      getAccountMeta(accounts.cosigner),
      ...remainingAccounts
    ],
    programAddress,
    data: getBuyLegacyInstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function parseBuyLegacyInstruction(instruction) {
  if (instruction.accounts.length < 24) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  const getNextOptionalAccount = () => {
    const accountMeta = getNextAccount();
    return accountMeta.address === TENSOR_MARKETPLACE_PROGRAM_ADDRESS ? void 0 : accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      feeVault: getNextAccount(),
      buyer: getNextAccount(),
      buyerTa: getNextAccount(),
      listTa: getNextAccount(),
      listState: getNextAccount(),
      mint: getNextAccount(),
      owner: getNextAccount(),
      payer: getNextAccount(),
      takerBroker: getNextOptionalAccount(),
      makerBroker: getNextOptionalAccount(),
      rentDestination: getNextAccount(),
      tokenProgram: getNextAccount(),
      associatedTokenProgram: getNextAccount(),
      marketplaceProgram: getNextAccount(),
      systemProgram: getNextAccount(),
      metadata: getNextAccount(),
      edition: getNextAccount(),
      buyerTokenRecord: getNextOptionalAccount(),
      listTokenRecord: getNextOptionalAccount(),
      authorizationRules: getNextOptionalAccount(),
      authorizationRulesProgram: getNextOptionalAccount(),
      tokenMetadataProgram: getNextOptionalAccount(),
      sysvarInstructions: getNextOptionalAccount(),
      cosigner: getNextOptionalAccount()
    },
    data: getBuyLegacyInstructionDataDecoder().decode(instruction.data)
  };
}
function getBuyLegacySplInstructionDataEncoder() {
  return web3_js.transformEncoder(
    web3_js.getStructEncoder([
      ["discriminator", web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 8)],
      ["maxAmount", web3_js.getU64Encoder()],
      ["optionalRoyaltyPct", web3_js.getOptionEncoder(web3_js.getU16Encoder())],
      [
        "authorizationData",
        web3_js.getOptionEncoder(getAuthorizationDataLocalEncoder())
      ]
    ]),
    (value) => ({
      ...value,
      discriminator: new Uint8Array([134, 94, 125, 229, 24, 157, 194, 199]),
      optionalRoyaltyPct: value.optionalRoyaltyPct ?? web3_js.none(),
      authorizationData: value.authorizationData ?? web3_js.none()
    })
  );
}
function getBuyLegacySplInstructionDataDecoder() {
  return web3_js.getStructDecoder([
    ["discriminator", web3_js.fixDecoderSize(web3_js.getBytesDecoder(), 8)],
    ["maxAmount", web3_js.getU64Decoder()],
    ["optionalRoyaltyPct", web3_js.getOptionDecoder(web3_js.getU16Decoder())],
    ["authorizationData", web3_js.getOptionDecoder(getAuthorizationDataLocalDecoder())]
  ]);
}
function getBuyLegacySplInstructionDataCodec() {
  return web3_js.combineCodec(
    getBuyLegacySplInstructionDataEncoder(),
    getBuyLegacySplInstructionDataDecoder()
  );
}
async function getBuyLegacySplInstructionAsync(input) {
  const programAddress = TENSOR_MARKETPLACE_PROGRAM_ADDRESS;
  const originalAccounts = {
    feeVault: { value: input.feeVault ?? null, isWritable: true },
    feeVaultCurrencyTa: {
      value: input.feeVaultCurrencyTa ?? null,
      isWritable: true
    },
    buyer: { value: input.buyer ?? null, isWritable: false },
    buyerTa: { value: input.buyerTa ?? null, isWritable: true },
    listTa: { value: input.listTa ?? null, isWritable: true },
    listState: { value: input.listState ?? null, isWritable: true },
    mint: { value: input.mint ?? null, isWritable: false },
    currency: { value: input.currency ?? null, isWritable: false },
    owner: { value: input.owner ?? null, isWritable: true },
    ownerCurrencyTa: { value: input.ownerCurrencyTa ?? null, isWritable: true },
    payer: { value: input.payer ?? null, isWritable: true },
    payerCurrencyTa: { value: input.payerCurrencyTa ?? null, isWritable: true },
    makerBroker: { value: input.makerBroker ?? null, isWritable: true },
    takerBroker: { value: input.takerBroker ?? null, isWritable: true },
    rentDestination: { value: input.rentDestination ?? null, isWritable: true },
    tokenProgram: { value: input.tokenProgram ?? null, isWritable: false },
    currencyTokenProgram: {
      value: input.currencyTokenProgram ?? null,
      isWritable: false
    },
    associatedTokenProgram: {
      value: input.associatedTokenProgram ?? null,
      isWritable: false
    },
    marketplaceProgram: {
      value: input.marketplaceProgram ?? null,
      isWritable: false
    },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false },
    metadata: { value: input.metadata ?? null, isWritable: true },
    edition: { value: input.edition ?? null, isWritable: false },
    buyerTokenRecord: {
      value: input.buyerTokenRecord ?? null,
      isWritable: true
    },
    listTokenRecord: { value: input.listTokenRecord ?? null, isWritable: true },
    authorizationRules: {
      value: input.authorizationRules ?? null,
      isWritable: false
    },
    authorizationRulesProgram: {
      value: input.authorizationRulesProgram ?? null,
      isWritable: false
    },
    tokenMetadataProgram: {
      value: input.tokenMetadataProgram ?? null,
      isWritable: false
    },
    sysvarInstructions: {
      value: input.sysvarInstructions ?? null,
      isWritable: false
    },
    cosigner: { value: input.cosigner ?? null, isWritable: false }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  const resolverScope = { programAddress, accounts, args };
  if (!accounts.listState.value) {
    accounts.listState.value = await findListStatePda({
      mint: expectAddress(accounts.mint.value)
    });
  }
  if (!accounts.feeVault.value) {
    accounts.feeVault = {
      ...accounts.feeVault,
      ...await resolveFeeVaultPdaFromListState(resolverScope)
    };
  }
  if (!accounts.buyer.value) {
    accounts.buyer.value = expectTransactionSigner(
      accounts.payer.value
    ).address;
  }
  if (!accounts.tokenProgram.value) {
    accounts.tokenProgram.value = "TokenkegQfeZyiNwAJbNbGKPFXCWuBvf9Ss623VQ5DA";
  }
  if (!accounts.buyerTa.value) {
    accounts.buyerTa = {
      ...accounts.buyerTa,
      ...await resolvers.resolveBuyerAta(resolverScope)
    };
  }
  if (!accounts.listTa.value) {
    accounts.listTa = {
      ...accounts.listTa,
      ...await resolvers.resolveListAta(resolverScope)
    };
  }
  if (!accounts.rentDestination.value) {
    accounts.rentDestination.value = expectSome(accounts.owner.value);
  }
  if (!accounts.associatedTokenProgram.value) {
    accounts.associatedTokenProgram.value = "ATokenGPvbdGVxr1b2hvZbsiqW5xWH25efTNsLJA8knL";
  }
  if (!accounts.marketplaceProgram.value) {
    accounts.marketplaceProgram.value = "TCMPhJdwDryooaGtiocG1u3xcYbRpiJzb283XfCZsDp";
  }
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  if (!accounts.metadata.value) {
    accounts.metadata = {
      ...accounts.metadata,
      ...await resolvers.resolveMetadata(resolverScope)
    };
  }
  if (!args.tokenStandard) {
    args.tokenStandard = resolvers.TokenStandard.ProgrammableNonFungible;
  }
  if (!accounts.edition.value) {
    accounts.edition = {
      ...accounts.edition,
      ...await resolvers.resolveEditionFromTokenStandard(resolverScope)
    };
  }
  if (!accounts.buyerTokenRecord.value) {
    accounts.buyerTokenRecord = {
      ...accounts.buyerTokenRecord,
      ...await resolvers.resolveBuyerTokenRecordFromTokenStandard(resolverScope)
    };
  }
  if (!accounts.listTokenRecord.value) {
    accounts.listTokenRecord = {
      ...accounts.listTokenRecord,
      ...await resolvers.resolveListTokenRecordFromTokenStandard(resolverScope)
    };
  }
  if (!accounts.authorizationRulesProgram.value) {
    accounts.authorizationRulesProgram = {
      ...accounts.authorizationRulesProgram,
      ...resolvers.resolveAuthorizationRulesProgramFromTokenStandard(resolverScope)
    };
  }
  if (!accounts.tokenMetadataProgram.value) {
    accounts.tokenMetadataProgram = {
      ...accounts.tokenMetadataProgram,
      ...resolvers.resolveTokenMetadataProgramFromTokenStandard(resolverScope)
    };
  }
  if (!accounts.sysvarInstructions.value) {
    accounts.sysvarInstructions = {
      ...accounts.sysvarInstructions,
      ...resolvers.resolveSysvarInstructionsFromTokenStandard(resolverScope)
    };
  }
  const remainingAccounts = [
    ...(args.creators ?? []).map((address3) => ({
      address: address3,
      role: web3_js.AccountRole.WRITABLE
    })),
    ...(args.creatorsTa ?? []).map((address3) => ({
      address: address3,
      role: web3_js.AccountRole.WRITABLE
    }))
  ];
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.feeVault),
      getAccountMeta(accounts.feeVaultCurrencyTa),
      getAccountMeta(accounts.buyer),
      getAccountMeta(accounts.buyerTa),
      getAccountMeta(accounts.listTa),
      getAccountMeta(accounts.listState),
      getAccountMeta(accounts.mint),
      getAccountMeta(accounts.currency),
      getAccountMeta(accounts.owner),
      getAccountMeta(accounts.ownerCurrencyTa),
      getAccountMeta(accounts.payer),
      getAccountMeta(accounts.payerCurrencyTa),
      getAccountMeta(accounts.makerBroker),
      getAccountMeta(accounts.takerBroker),
      getAccountMeta(accounts.rentDestination),
      getAccountMeta(accounts.tokenProgram),
      getAccountMeta(accounts.currencyTokenProgram),
      getAccountMeta(accounts.associatedTokenProgram),
      getAccountMeta(accounts.marketplaceProgram),
      getAccountMeta(accounts.systemProgram),
      getAccountMeta(accounts.metadata),
      getAccountMeta(accounts.edition),
      getAccountMeta(accounts.buyerTokenRecord),
      getAccountMeta(accounts.listTokenRecord),
      getAccountMeta(accounts.authorizationRules),
      getAccountMeta(accounts.authorizationRulesProgram),
      getAccountMeta(accounts.tokenMetadataProgram),
      getAccountMeta(accounts.sysvarInstructions),
      getAccountMeta(accounts.cosigner),
      ...remainingAccounts
    ],
    programAddress,
    data: getBuyLegacySplInstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function getBuyLegacySplInstruction(input) {
  const programAddress = TENSOR_MARKETPLACE_PROGRAM_ADDRESS;
  const originalAccounts = {
    feeVault: { value: input.feeVault ?? null, isWritable: true },
    feeVaultCurrencyTa: {
      value: input.feeVaultCurrencyTa ?? null,
      isWritable: true
    },
    buyer: { value: input.buyer ?? null, isWritable: false },
    buyerTa: { value: input.buyerTa ?? null, isWritable: true },
    listTa: { value: input.listTa ?? null, isWritable: true },
    listState: { value: input.listState ?? null, isWritable: true },
    mint: { value: input.mint ?? null, isWritable: false },
    currency: { value: input.currency ?? null, isWritable: false },
    owner: { value: input.owner ?? null, isWritable: true },
    ownerCurrencyTa: { value: input.ownerCurrencyTa ?? null, isWritable: true },
    payer: { value: input.payer ?? null, isWritable: true },
    payerCurrencyTa: { value: input.payerCurrencyTa ?? null, isWritable: true },
    makerBroker: { value: input.makerBroker ?? null, isWritable: true },
    takerBroker: { value: input.takerBroker ?? null, isWritable: true },
    rentDestination: { value: input.rentDestination ?? null, isWritable: true },
    tokenProgram: { value: input.tokenProgram ?? null, isWritable: false },
    currencyTokenProgram: {
      value: input.currencyTokenProgram ?? null,
      isWritable: false
    },
    associatedTokenProgram: {
      value: input.associatedTokenProgram ?? null,
      isWritable: false
    },
    marketplaceProgram: {
      value: input.marketplaceProgram ?? null,
      isWritable: false
    },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false },
    metadata: { value: input.metadata ?? null, isWritable: true },
    edition: { value: input.edition ?? null, isWritable: false },
    buyerTokenRecord: {
      value: input.buyerTokenRecord ?? null,
      isWritable: true
    },
    listTokenRecord: { value: input.listTokenRecord ?? null, isWritable: true },
    authorizationRules: {
      value: input.authorizationRules ?? null,
      isWritable: false
    },
    authorizationRulesProgram: {
      value: input.authorizationRulesProgram ?? null,
      isWritable: false
    },
    tokenMetadataProgram: {
      value: input.tokenMetadataProgram ?? null,
      isWritable: false
    },
    sysvarInstructions: {
      value: input.sysvarInstructions ?? null,
      isWritable: false
    },
    cosigner: { value: input.cosigner ?? null, isWritable: false }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  const resolverScope = { programAddress, accounts, args };
  if (!accounts.buyer.value) {
    accounts.buyer.value = expectTransactionSigner(
      accounts.payer.value
    ).address;
  }
  if (!accounts.tokenProgram.value) {
    accounts.tokenProgram.value = "TokenkegQfeZyiNwAJbNbGKPFXCWuBvf9Ss623VQ5DA";
  }
  if (!accounts.rentDestination.value) {
    accounts.rentDestination.value = expectSome(accounts.owner.value);
  }
  if (!accounts.associatedTokenProgram.value) {
    accounts.associatedTokenProgram.value = "ATokenGPvbdGVxr1b2hvZbsiqW5xWH25efTNsLJA8knL";
  }
  if (!accounts.marketplaceProgram.value) {
    accounts.marketplaceProgram.value = "TCMPhJdwDryooaGtiocG1u3xcYbRpiJzb283XfCZsDp";
  }
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  if (!args.tokenStandard) {
    args.tokenStandard = resolvers.TokenStandard.ProgrammableNonFungible;
  }
  if (!accounts.authorizationRulesProgram.value) {
    accounts.authorizationRulesProgram = {
      ...accounts.authorizationRulesProgram,
      ...resolvers.resolveAuthorizationRulesProgramFromTokenStandard(resolverScope)
    };
  }
  if (!accounts.tokenMetadataProgram.value) {
    accounts.tokenMetadataProgram = {
      ...accounts.tokenMetadataProgram,
      ...resolvers.resolveTokenMetadataProgramFromTokenStandard(resolverScope)
    };
  }
  if (!accounts.sysvarInstructions.value) {
    accounts.sysvarInstructions = {
      ...accounts.sysvarInstructions,
      ...resolvers.resolveSysvarInstructionsFromTokenStandard(resolverScope)
    };
  }
  const remainingAccounts = [
    ...(args.creators ?? []).map((address3) => ({
      address: address3,
      role: web3_js.AccountRole.WRITABLE
    })),
    ...(args.creatorsTa ?? []).map((address3) => ({
      address: address3,
      role: web3_js.AccountRole.WRITABLE
    }))
  ];
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.feeVault),
      getAccountMeta(accounts.feeVaultCurrencyTa),
      getAccountMeta(accounts.buyer),
      getAccountMeta(accounts.buyerTa),
      getAccountMeta(accounts.listTa),
      getAccountMeta(accounts.listState),
      getAccountMeta(accounts.mint),
      getAccountMeta(accounts.currency),
      getAccountMeta(accounts.owner),
      getAccountMeta(accounts.ownerCurrencyTa),
      getAccountMeta(accounts.payer),
      getAccountMeta(accounts.payerCurrencyTa),
      getAccountMeta(accounts.makerBroker),
      getAccountMeta(accounts.takerBroker),
      getAccountMeta(accounts.rentDestination),
      getAccountMeta(accounts.tokenProgram),
      getAccountMeta(accounts.currencyTokenProgram),
      getAccountMeta(accounts.associatedTokenProgram),
      getAccountMeta(accounts.marketplaceProgram),
      getAccountMeta(accounts.systemProgram),
      getAccountMeta(accounts.metadata),
      getAccountMeta(accounts.edition),
      getAccountMeta(accounts.buyerTokenRecord),
      getAccountMeta(accounts.listTokenRecord),
      getAccountMeta(accounts.authorizationRules),
      getAccountMeta(accounts.authorizationRulesProgram),
      getAccountMeta(accounts.tokenMetadataProgram),
      getAccountMeta(accounts.sysvarInstructions),
      getAccountMeta(accounts.cosigner),
      ...remainingAccounts
    ],
    programAddress,
    data: getBuyLegacySplInstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function parseBuyLegacySplInstruction(instruction) {
  if (instruction.accounts.length < 29) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  const getNextOptionalAccount = () => {
    const accountMeta = getNextAccount();
    return accountMeta.address === TENSOR_MARKETPLACE_PROGRAM_ADDRESS ? void 0 : accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      feeVault: getNextAccount(),
      feeVaultCurrencyTa: getNextAccount(),
      buyer: getNextAccount(),
      buyerTa: getNextAccount(),
      listTa: getNextAccount(),
      listState: getNextAccount(),
      mint: getNextAccount(),
      currency: getNextAccount(),
      owner: getNextAccount(),
      ownerCurrencyTa: getNextAccount(),
      payer: getNextAccount(),
      payerCurrencyTa: getNextAccount(),
      makerBroker: getNextOptionalAccount(),
      takerBroker: getNextOptionalAccount(),
      rentDestination: getNextAccount(),
      tokenProgram: getNextAccount(),
      currencyTokenProgram: getNextAccount(),
      associatedTokenProgram: getNextAccount(),
      marketplaceProgram: getNextAccount(),
      systemProgram: getNextAccount(),
      metadata: getNextAccount(),
      edition: getNextAccount(),
      buyerTokenRecord: getNextOptionalAccount(),
      listTokenRecord: getNextOptionalAccount(),
      authorizationRules: getNextOptionalAccount(),
      authorizationRulesProgram: getNextOptionalAccount(),
      tokenMetadataProgram: getNextOptionalAccount(),
      sysvarInstructions: getNextOptionalAccount(),
      cosigner: getNextOptionalAccount()
    },
    data: getBuyLegacySplInstructionDataDecoder().decode(instruction.data)
  };
}
function getBuySplInstructionDataEncoder() {
  return web3_js.transformEncoder(
    web3_js.getStructEncoder([
      ["discriminator", web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 8)],
      ["nonce", web3_js.getU64Encoder()],
      ["index", web3_js.getU32Encoder()],
      ["root", web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 32)],
      ["metaHash", web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 32)],
      [
        "creatorShares",
        web3_js.addEncoderSizePrefix(web3_js.getBytesEncoder(), web3_js.getU32Encoder())
      ],
      ["creatorVerified", web3_js.getArrayEncoder(web3_js.getBooleanEncoder())],
      ["sellerFeeBasisPoints", web3_js.getU16Encoder()],
      ["maxAmount", web3_js.getU64Encoder()],
      ["optionalRoyaltyPct", web3_js.getOptionEncoder(web3_js.getU16Encoder())]
    ]),
    (value) => ({
      ...value,
      discriminator: new Uint8Array([65, 136, 254, 255, 59, 130, 234, 174]),
      optionalRoyaltyPct: value.optionalRoyaltyPct ?? web3_js.none()
    })
  );
}
function getBuySplInstructionDataDecoder() {
  return web3_js.getStructDecoder([
    ["discriminator", web3_js.fixDecoderSize(web3_js.getBytesDecoder(), 8)],
    ["nonce", web3_js.getU64Decoder()],
    ["index", web3_js.getU32Decoder()],
    ["root", web3_js.fixDecoderSize(web3_js.getBytesDecoder(), 32)],
    ["metaHash", web3_js.fixDecoderSize(web3_js.getBytesDecoder(), 32)],
    ["creatorShares", web3_js.addDecoderSizePrefix(web3_js.getBytesDecoder(), web3_js.getU32Decoder())],
    ["creatorVerified", web3_js.getArrayDecoder(web3_js.getBooleanDecoder())],
    ["sellerFeeBasisPoints", web3_js.getU16Decoder()],
    ["maxAmount", web3_js.getU64Decoder()],
    ["optionalRoyaltyPct", web3_js.getOptionDecoder(web3_js.getU16Decoder())]
  ]);
}
function getBuySplInstructionDataCodec() {
  return web3_js.combineCodec(
    getBuySplInstructionDataEncoder(),
    getBuySplInstructionDataDecoder()
  );
}
async function getBuySplInstructionAsync(input) {
  const programAddress = TENSOR_MARKETPLACE_PROGRAM_ADDRESS;
  const originalAccounts = {
    feeVault: { value: input.feeVault ?? null, isWritable: true },
    feeVaultTa: { value: input.feeVaultTa ?? null, isWritable: true },
    treeAuthority: { value: input.treeAuthority ?? null, isWritable: false },
    merkleTree: { value: input.merkleTree ?? null, isWritable: true },
    logWrapper: { value: input.logWrapper ?? null, isWritable: false },
    compressionProgram: {
      value: input.compressionProgram ?? null,
      isWritable: false
    },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false },
    bubblegumProgram: {
      value: input.bubblegumProgram ?? null,
      isWritable: false
    },
    marketplaceProgram: {
      value: input.marketplaceProgram ?? null,
      isWritable: false
    },
    tokenProgram: { value: input.tokenProgram ?? null, isWritable: false },
    associatedTokenProgram: {
      value: input.associatedTokenProgram ?? null,
      isWritable: false
    },
    listState: { value: input.listState ?? null, isWritable: true },
    buyer: { value: input.buyer ?? null, isWritable: false },
    payer: { value: input.payer ?? null, isWritable: false },
    payerSource: { value: input.payerSource ?? null, isWritable: true },
    owner: { value: input.owner ?? null, isWritable: false },
    ownerDestination: {
      value: input.ownerDestination ?? null,
      isWritable: true
    },
    currency: { value: input.currency ?? null, isWritable: false },
    takerBroker: { value: input.takerBroker ?? null, isWritable: true },
    takerBrokerCurrencyTa: {
      value: input.takerBrokerCurrencyTa ?? null,
      isWritable: true
    },
    makerBroker: { value: input.makerBroker ?? null, isWritable: true },
    makerBrokerCurrencyTa: {
      value: input.makerBrokerCurrencyTa ?? null,
      isWritable: true
    },
    rentDestination: { value: input.rentDestination ?? null, isWritable: true },
    rentPayer: { value: input.rentPayer ?? null, isWritable: true },
    cosigner: { value: input.cosigner ?? null, isWritable: false }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  const resolverScope = { programAddress, accounts, args };
  if (!accounts.bubblegumProgram.value) {
    accounts.bubblegumProgram.value = "BGUMAp9Gq7iTEuizy4pqaxsTyUCBK68MDfK752saRPUY";
  }
  if (!accounts.treeAuthority.value) {
    accounts.treeAuthority = {
      ...accounts.treeAuthority,
      ...await resolveTreeAuthorityPda(resolverScope)
    };
  }
  if (!accounts.logWrapper.value) {
    accounts.logWrapper.value = "noopb9bkMVfRPU8AsbpTUg8AQkHtKwMYZiFUjNRtMmV";
  }
  if (!accounts.compressionProgram.value) {
    accounts.compressionProgram.value = "cmtDvXumGCrqC1Age74AVPhSRVXJMd8PJS91L8KbNCK";
  }
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  if (!accounts.marketplaceProgram.value) {
    accounts.marketplaceProgram.value = "TCMPhJdwDryooaGtiocG1u3xcYbRpiJzb283XfCZsDp";
  }
  if (!accounts.tokenProgram.value) {
    accounts.tokenProgram.value = "TokenkegQfeZyiNwAJbNbGKPFXCWuBvf9Ss623VQ5DA";
  }
  if (!accounts.associatedTokenProgram.value) {
    accounts.associatedTokenProgram.value = "ATokenGPvbdGVxr1b2hvZbsiqW5xWH25efTNsLJA8knL";
  }
  if (!accounts.cosigner.value) {
    accounts.cosigner.value = "TCMPhJdwDryooaGtiocG1u3xcYbRpiJzb283XfCZsDp";
  }
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.feeVault),
      getAccountMeta(accounts.feeVaultTa),
      getAccountMeta(accounts.treeAuthority),
      getAccountMeta(accounts.merkleTree),
      getAccountMeta(accounts.logWrapper),
      getAccountMeta(accounts.compressionProgram),
      getAccountMeta(accounts.systemProgram),
      getAccountMeta(accounts.bubblegumProgram),
      getAccountMeta(accounts.marketplaceProgram),
      getAccountMeta(accounts.tokenProgram),
      getAccountMeta(accounts.associatedTokenProgram),
      getAccountMeta(accounts.listState),
      getAccountMeta(accounts.buyer),
      getAccountMeta(accounts.payer),
      getAccountMeta(accounts.payerSource),
      getAccountMeta(accounts.owner),
      getAccountMeta(accounts.ownerDestination),
      getAccountMeta(accounts.currency),
      getAccountMeta(accounts.takerBroker),
      getAccountMeta(accounts.takerBrokerCurrencyTa),
      getAccountMeta(accounts.makerBroker),
      getAccountMeta(accounts.makerBrokerCurrencyTa),
      getAccountMeta(accounts.rentDestination),
      getAccountMeta(accounts.rentPayer),
      getAccountMeta(accounts.cosigner)
    ],
    programAddress,
    data: getBuySplInstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function getBuySplInstruction(input) {
  const programAddress = TENSOR_MARKETPLACE_PROGRAM_ADDRESS;
  const originalAccounts = {
    feeVault: { value: input.feeVault ?? null, isWritable: true },
    feeVaultTa: { value: input.feeVaultTa ?? null, isWritable: true },
    treeAuthority: { value: input.treeAuthority ?? null, isWritable: false },
    merkleTree: { value: input.merkleTree ?? null, isWritable: true },
    logWrapper: { value: input.logWrapper ?? null, isWritable: false },
    compressionProgram: {
      value: input.compressionProgram ?? null,
      isWritable: false
    },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false },
    bubblegumProgram: {
      value: input.bubblegumProgram ?? null,
      isWritable: false
    },
    marketplaceProgram: {
      value: input.marketplaceProgram ?? null,
      isWritable: false
    },
    tokenProgram: { value: input.tokenProgram ?? null, isWritable: false },
    associatedTokenProgram: {
      value: input.associatedTokenProgram ?? null,
      isWritable: false
    },
    listState: { value: input.listState ?? null, isWritable: true },
    buyer: { value: input.buyer ?? null, isWritable: false },
    payer: { value: input.payer ?? null, isWritable: false },
    payerSource: { value: input.payerSource ?? null, isWritable: true },
    owner: { value: input.owner ?? null, isWritable: false },
    ownerDestination: {
      value: input.ownerDestination ?? null,
      isWritable: true
    },
    currency: { value: input.currency ?? null, isWritable: false },
    takerBroker: { value: input.takerBroker ?? null, isWritable: true },
    takerBrokerCurrencyTa: {
      value: input.takerBrokerCurrencyTa ?? null,
      isWritable: true
    },
    makerBroker: { value: input.makerBroker ?? null, isWritable: true },
    makerBrokerCurrencyTa: {
      value: input.makerBrokerCurrencyTa ?? null,
      isWritable: true
    },
    rentDestination: { value: input.rentDestination ?? null, isWritable: true },
    rentPayer: { value: input.rentPayer ?? null, isWritable: true },
    cosigner: { value: input.cosigner ?? null, isWritable: false }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  if (!accounts.bubblegumProgram.value) {
    accounts.bubblegumProgram.value = "BGUMAp9Gq7iTEuizy4pqaxsTyUCBK68MDfK752saRPUY";
  }
  if (!accounts.logWrapper.value) {
    accounts.logWrapper.value = "noopb9bkMVfRPU8AsbpTUg8AQkHtKwMYZiFUjNRtMmV";
  }
  if (!accounts.compressionProgram.value) {
    accounts.compressionProgram.value = "cmtDvXumGCrqC1Age74AVPhSRVXJMd8PJS91L8KbNCK";
  }
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  if (!accounts.marketplaceProgram.value) {
    accounts.marketplaceProgram.value = "TCMPhJdwDryooaGtiocG1u3xcYbRpiJzb283XfCZsDp";
  }
  if (!accounts.tokenProgram.value) {
    accounts.tokenProgram.value = "TokenkegQfeZyiNwAJbNbGKPFXCWuBvf9Ss623VQ5DA";
  }
  if (!accounts.associatedTokenProgram.value) {
    accounts.associatedTokenProgram.value = "ATokenGPvbdGVxr1b2hvZbsiqW5xWH25efTNsLJA8knL";
  }
  if (!accounts.cosigner.value) {
    accounts.cosigner.value = "TCMPhJdwDryooaGtiocG1u3xcYbRpiJzb283XfCZsDp";
  }
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.feeVault),
      getAccountMeta(accounts.feeVaultTa),
      getAccountMeta(accounts.treeAuthority),
      getAccountMeta(accounts.merkleTree),
      getAccountMeta(accounts.logWrapper),
      getAccountMeta(accounts.compressionProgram),
      getAccountMeta(accounts.systemProgram),
      getAccountMeta(accounts.bubblegumProgram),
      getAccountMeta(accounts.marketplaceProgram),
      getAccountMeta(accounts.tokenProgram),
      getAccountMeta(accounts.associatedTokenProgram),
      getAccountMeta(accounts.listState),
      getAccountMeta(accounts.buyer),
      getAccountMeta(accounts.payer),
      getAccountMeta(accounts.payerSource),
      getAccountMeta(accounts.owner),
      getAccountMeta(accounts.ownerDestination),
      getAccountMeta(accounts.currency),
      getAccountMeta(accounts.takerBroker),
      getAccountMeta(accounts.takerBrokerCurrencyTa),
      getAccountMeta(accounts.makerBroker),
      getAccountMeta(accounts.makerBrokerCurrencyTa),
      getAccountMeta(accounts.rentDestination),
      getAccountMeta(accounts.rentPayer),
      getAccountMeta(accounts.cosigner)
    ],
    programAddress,
    data: getBuySplInstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function parseBuySplInstruction(instruction) {
  if (instruction.accounts.length < 25) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  const getNextOptionalAccount = () => {
    const accountMeta = getNextAccount();
    return accountMeta.address === TENSOR_MARKETPLACE_PROGRAM_ADDRESS ? void 0 : accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      feeVault: getNextAccount(),
      feeVaultTa: getNextAccount(),
      treeAuthority: getNextAccount(),
      merkleTree: getNextAccount(),
      logWrapper: getNextAccount(),
      compressionProgram: getNextAccount(),
      systemProgram: getNextAccount(),
      bubblegumProgram: getNextAccount(),
      marketplaceProgram: getNextAccount(),
      tokenProgram: getNextAccount(),
      associatedTokenProgram: getNextAccount(),
      listState: getNextAccount(),
      buyer: getNextAccount(),
      payer: getNextAccount(),
      payerSource: getNextAccount(),
      owner: getNextAccount(),
      ownerDestination: getNextAccount(),
      currency: getNextAccount(),
      takerBroker: getNextOptionalAccount(),
      takerBrokerCurrencyTa: getNextOptionalAccount(),
      makerBroker: getNextOptionalAccount(),
      makerBrokerCurrencyTa: getNextOptionalAccount(),
      rentDestination: getNextAccount(),
      rentPayer: getNextAccount(),
      cosigner: getNextOptionalAccount()
    },
    data: getBuySplInstructionDataDecoder().decode(instruction.data)
  };
}
function getBuyT22InstructionDataEncoder() {
  return web3_js.transformEncoder(
    web3_js.getStructEncoder([
      ["discriminator", web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 8)],
      ["maxAmount", web3_js.getU64Encoder()]
    ]),
    (value) => ({
      ...value,
      discriminator: new Uint8Array([81, 98, 227, 171, 201, 105, 180, 216])
    })
  );
}
function getBuyT22InstructionDataDecoder() {
  return web3_js.getStructDecoder([
    ["discriminator", web3_js.fixDecoderSize(web3_js.getBytesDecoder(), 8)],
    ["maxAmount", web3_js.getU64Decoder()]
  ]);
}
function getBuyT22InstructionDataCodec() {
  return web3_js.combineCodec(
    getBuyT22InstructionDataEncoder(),
    getBuyT22InstructionDataDecoder()
  );
}
async function getBuyT22InstructionAsync(input) {
  const programAddress = TENSOR_MARKETPLACE_PROGRAM_ADDRESS;
  const originalAccounts = {
    feeVault: { value: input.feeVault ?? null, isWritable: true },
    buyer: { value: input.buyer ?? null, isWritable: false },
    buyerTa: { value: input.buyerTa ?? null, isWritable: true },
    listState: { value: input.listState ?? null, isWritable: true },
    listTa: { value: input.listTa ?? null, isWritable: true },
    mint: { value: input.mint ?? null, isWritable: false },
    owner: { value: input.owner ?? null, isWritable: true },
    payer: { value: input.payer ?? null, isWritable: true },
    takerBroker: { value: input.takerBroker ?? null, isWritable: true },
    makerBroker: { value: input.makerBroker ?? null, isWritable: true },
    rentDestination: { value: input.rentDestination ?? null, isWritable: true },
    tokenProgram: { value: input.tokenProgram ?? null, isWritable: false },
    associatedTokenProgram: {
      value: input.associatedTokenProgram ?? null,
      isWritable: false
    },
    marketplaceProgram: {
      value: input.marketplaceProgram ?? null,
      isWritable: false
    },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false },
    cosigner: { value: input.cosigner ?? null, isWritable: false }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  const resolverScope = { programAddress, accounts, args };
  if (!accounts.buyer.value) {
    accounts.buyer.value = expectTransactionSigner(
      accounts.payer.value
    ).address;
  }
  if (!accounts.tokenProgram.value) {
    accounts.tokenProgram.value = "TokenkegQfeZyiNwAJbNbGKPFXCWuBvf9Ss623VQ5DA";
  }
  if (!accounts.buyerTa.value) {
    accounts.buyerTa = {
      ...accounts.buyerTa,
      ...await resolvers.resolveBuyerAta(resolverScope)
    };
  }
  if (!accounts.listState.value) {
    accounts.listState.value = await findListStatePda({
      mint: expectAddress(accounts.mint.value)
    });
  }
  if (!accounts.listTa.value) {
    accounts.listTa = {
      ...accounts.listTa,
      ...await resolvers.resolveListAta(resolverScope)
    };
  }
  if (!accounts.rentDestination.value) {
    accounts.rentDestination.value = expectSome(accounts.owner.value);
  }
  if (!accounts.associatedTokenProgram.value) {
    accounts.associatedTokenProgram.value = "ATokenGPvbdGVxr1b2hvZbsiqW5xWH25efTNsLJA8knL";
  }
  if (!accounts.marketplaceProgram.value) {
    accounts.marketplaceProgram.value = "TCMPhJdwDryooaGtiocG1u3xcYbRpiJzb283XfCZsDp";
  }
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  if (!accounts.cosigner.value) {
    accounts.cosigner.value = "TCMPhJdwDryooaGtiocG1u3xcYbRpiJzb283XfCZsDp";
  }
  const remainingAccounts = (args.creators ?? []).map(
    (address3) => ({ address: address3, role: web3_js.AccountRole.WRITABLE })
  );
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.feeVault),
      getAccountMeta(accounts.buyer),
      getAccountMeta(accounts.buyerTa),
      getAccountMeta(accounts.listState),
      getAccountMeta(accounts.listTa),
      getAccountMeta(accounts.mint),
      getAccountMeta(accounts.owner),
      getAccountMeta(accounts.payer),
      getAccountMeta(accounts.takerBroker),
      getAccountMeta(accounts.makerBroker),
      getAccountMeta(accounts.rentDestination),
      getAccountMeta(accounts.tokenProgram),
      getAccountMeta(accounts.associatedTokenProgram),
      getAccountMeta(accounts.marketplaceProgram),
      getAccountMeta(accounts.systemProgram),
      getAccountMeta(accounts.cosigner),
      ...remainingAccounts
    ],
    programAddress,
    data: getBuyT22InstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function getBuyT22Instruction(input) {
  const programAddress = TENSOR_MARKETPLACE_PROGRAM_ADDRESS;
  const originalAccounts = {
    feeVault: { value: input.feeVault ?? null, isWritable: true },
    buyer: { value: input.buyer ?? null, isWritable: false },
    buyerTa: { value: input.buyerTa ?? null, isWritable: true },
    listState: { value: input.listState ?? null, isWritable: true },
    listTa: { value: input.listTa ?? null, isWritable: true },
    mint: { value: input.mint ?? null, isWritable: false },
    owner: { value: input.owner ?? null, isWritable: true },
    payer: { value: input.payer ?? null, isWritable: true },
    takerBroker: { value: input.takerBroker ?? null, isWritable: true },
    makerBroker: { value: input.makerBroker ?? null, isWritable: true },
    rentDestination: { value: input.rentDestination ?? null, isWritable: true },
    tokenProgram: { value: input.tokenProgram ?? null, isWritable: false },
    associatedTokenProgram: {
      value: input.associatedTokenProgram ?? null,
      isWritable: false
    },
    marketplaceProgram: {
      value: input.marketplaceProgram ?? null,
      isWritable: false
    },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false },
    cosigner: { value: input.cosigner ?? null, isWritable: false }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  if (!accounts.buyer.value) {
    accounts.buyer.value = expectTransactionSigner(
      accounts.payer.value
    ).address;
  }
  if (!accounts.tokenProgram.value) {
    accounts.tokenProgram.value = "TokenkegQfeZyiNwAJbNbGKPFXCWuBvf9Ss623VQ5DA";
  }
  if (!accounts.rentDestination.value) {
    accounts.rentDestination.value = expectSome(accounts.owner.value);
  }
  if (!accounts.associatedTokenProgram.value) {
    accounts.associatedTokenProgram.value = "ATokenGPvbdGVxr1b2hvZbsiqW5xWH25efTNsLJA8knL";
  }
  if (!accounts.marketplaceProgram.value) {
    accounts.marketplaceProgram.value = "TCMPhJdwDryooaGtiocG1u3xcYbRpiJzb283XfCZsDp";
  }
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  if (!accounts.cosigner.value) {
    accounts.cosigner.value = "TCMPhJdwDryooaGtiocG1u3xcYbRpiJzb283XfCZsDp";
  }
  const remainingAccounts = (args.creators ?? []).map(
    (address3) => ({ address: address3, role: web3_js.AccountRole.WRITABLE })
  );
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.feeVault),
      getAccountMeta(accounts.buyer),
      getAccountMeta(accounts.buyerTa),
      getAccountMeta(accounts.listState),
      getAccountMeta(accounts.listTa),
      getAccountMeta(accounts.mint),
      getAccountMeta(accounts.owner),
      getAccountMeta(accounts.payer),
      getAccountMeta(accounts.takerBroker),
      getAccountMeta(accounts.makerBroker),
      getAccountMeta(accounts.rentDestination),
      getAccountMeta(accounts.tokenProgram),
      getAccountMeta(accounts.associatedTokenProgram),
      getAccountMeta(accounts.marketplaceProgram),
      getAccountMeta(accounts.systemProgram),
      getAccountMeta(accounts.cosigner),
      ...remainingAccounts
    ],
    programAddress,
    data: getBuyT22InstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function parseBuyT22Instruction(instruction) {
  if (instruction.accounts.length < 16) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  const getNextOptionalAccount = () => {
    const accountMeta = getNextAccount();
    return accountMeta.address === TENSOR_MARKETPLACE_PROGRAM_ADDRESS ? void 0 : accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      feeVault: getNextAccount(),
      buyer: getNextAccount(),
      buyerTa: getNextAccount(),
      listState: getNextAccount(),
      listTa: getNextAccount(),
      mint: getNextAccount(),
      owner: getNextAccount(),
      payer: getNextAccount(),
      takerBroker: getNextOptionalAccount(),
      makerBroker: getNextOptionalAccount(),
      rentDestination: getNextAccount(),
      tokenProgram: getNextAccount(),
      associatedTokenProgram: getNextAccount(),
      marketplaceProgram: getNextAccount(),
      systemProgram: getNextAccount(),
      cosigner: getNextOptionalAccount()
    },
    data: getBuyT22InstructionDataDecoder().decode(instruction.data)
  };
}
function getBuyT22SplInstructionDataEncoder() {
  return web3_js.transformEncoder(
    web3_js.getStructEncoder([
      ["discriminator", web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 8)],
      ["maxAmount", web3_js.getU64Encoder()]
    ]),
    (value) => ({
      ...value,
      discriminator: new Uint8Array([102, 21, 163, 39, 94, 39, 122, 94])
    })
  );
}
function getBuyT22SplInstructionDataDecoder() {
  return web3_js.getStructDecoder([
    ["discriminator", web3_js.fixDecoderSize(web3_js.getBytesDecoder(), 8)],
    ["maxAmount", web3_js.getU64Decoder()]
  ]);
}
function getBuyT22SplInstructionDataCodec() {
  return web3_js.combineCodec(
    getBuyT22SplInstructionDataEncoder(),
    getBuyT22SplInstructionDataDecoder()
  );
}
async function getBuyT22SplInstructionAsync(input) {
  const programAddress = TENSOR_MARKETPLACE_PROGRAM_ADDRESS;
  const originalAccounts = {
    feeVault: { value: input.feeVault ?? null, isWritable: true },
    feeVaultCurrencyTa: {
      value: input.feeVaultCurrencyTa ?? null,
      isWritable: true
    },
    buyer: { value: input.buyer ?? null, isWritable: false },
    buyerTa: { value: input.buyerTa ?? null, isWritable: true },
    listTa: { value: input.listTa ?? null, isWritable: true },
    listState: { value: input.listState ?? null, isWritable: true },
    mint: { value: input.mint ?? null, isWritable: false },
    currency: { value: input.currency ?? null, isWritable: false },
    owner: { value: input.owner ?? null, isWritable: true },
    ownerCurrencyTa: { value: input.ownerCurrencyTa ?? null, isWritable: true },
    payer: { value: input.payer ?? null, isWritable: true },
    payerCurrencyTa: { value: input.payerCurrencyTa ?? null, isWritable: true },
    takerBroker: { value: input.takerBroker ?? null, isWritable: true },
    takerBrokerCurrencyTa: {
      value: input.takerBrokerCurrencyTa ?? null,
      isWritable: true
    },
    makerBroker: { value: input.makerBroker ?? null, isWritable: true },
    makerBrokerCurrencyTa: {
      value: input.makerBrokerCurrencyTa ?? null,
      isWritable: true
    },
    rentDestination: { value: input.rentDestination ?? null, isWritable: true },
    tokenProgram: { value: input.tokenProgram ?? null, isWritable: false },
    currencyTokenProgram: {
      value: input.currencyTokenProgram ?? null,
      isWritable: false
    },
    associatedTokenProgram: {
      value: input.associatedTokenProgram ?? null,
      isWritable: false
    },
    marketplaceProgram: {
      value: input.marketplaceProgram ?? null,
      isWritable: false
    },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false },
    cosigner: { value: input.cosigner ?? null, isWritable: false }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  if (!accounts.buyer.value) {
    accounts.buyer.value = expectTransactionSigner(
      accounts.payer.value
    ).address;
  }
  if (!accounts.listState.value) {
    accounts.listState.value = await findListStatePda({
      mint: expectAddress(accounts.mint.value)
    });
  }
  if (!accounts.rentDestination.value) {
    accounts.rentDestination.value = expectSome(accounts.owner.value);
  }
  if (!accounts.tokenProgram.value) {
    accounts.tokenProgram.value = "TokenkegQfeZyiNwAJbNbGKPFXCWuBvf9Ss623VQ5DA";
  }
  if (!accounts.associatedTokenProgram.value) {
    accounts.associatedTokenProgram.value = "ATokenGPvbdGVxr1b2hvZbsiqW5xWH25efTNsLJA8knL";
  }
  if (!accounts.marketplaceProgram.value) {
    accounts.marketplaceProgram.value = "TCMPhJdwDryooaGtiocG1u3xcYbRpiJzb283XfCZsDp";
  }
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  const remainingAccounts = (args.creators ?? []).map(
    (address3) => ({ address: address3, role: web3_js.AccountRole.WRITABLE })
  );
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.feeVault),
      getAccountMeta(accounts.feeVaultCurrencyTa),
      getAccountMeta(accounts.buyer),
      getAccountMeta(accounts.buyerTa),
      getAccountMeta(accounts.listTa),
      getAccountMeta(accounts.listState),
      getAccountMeta(accounts.mint),
      getAccountMeta(accounts.currency),
      getAccountMeta(accounts.owner),
      getAccountMeta(accounts.ownerCurrencyTa),
      getAccountMeta(accounts.payer),
      getAccountMeta(accounts.payerCurrencyTa),
      getAccountMeta(accounts.takerBroker),
      getAccountMeta(accounts.takerBrokerCurrencyTa),
      getAccountMeta(accounts.makerBroker),
      getAccountMeta(accounts.makerBrokerCurrencyTa),
      getAccountMeta(accounts.rentDestination),
      getAccountMeta(accounts.tokenProgram),
      getAccountMeta(accounts.currencyTokenProgram),
      getAccountMeta(accounts.associatedTokenProgram),
      getAccountMeta(accounts.marketplaceProgram),
      getAccountMeta(accounts.systemProgram),
      getAccountMeta(accounts.cosigner),
      ...remainingAccounts
    ],
    programAddress,
    data: getBuyT22SplInstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function getBuyT22SplInstruction(input) {
  const programAddress = TENSOR_MARKETPLACE_PROGRAM_ADDRESS;
  const originalAccounts = {
    feeVault: { value: input.feeVault ?? null, isWritable: true },
    feeVaultCurrencyTa: {
      value: input.feeVaultCurrencyTa ?? null,
      isWritable: true
    },
    buyer: { value: input.buyer ?? null, isWritable: false },
    buyerTa: { value: input.buyerTa ?? null, isWritable: true },
    listTa: { value: input.listTa ?? null, isWritable: true },
    listState: { value: input.listState ?? null, isWritable: true },
    mint: { value: input.mint ?? null, isWritable: false },
    currency: { value: input.currency ?? null, isWritable: false },
    owner: { value: input.owner ?? null, isWritable: true },
    ownerCurrencyTa: { value: input.ownerCurrencyTa ?? null, isWritable: true },
    payer: { value: input.payer ?? null, isWritable: true },
    payerCurrencyTa: { value: input.payerCurrencyTa ?? null, isWritable: true },
    takerBroker: { value: input.takerBroker ?? null, isWritable: true },
    takerBrokerCurrencyTa: {
      value: input.takerBrokerCurrencyTa ?? null,
      isWritable: true
    },
    makerBroker: { value: input.makerBroker ?? null, isWritable: true },
    makerBrokerCurrencyTa: {
      value: input.makerBrokerCurrencyTa ?? null,
      isWritable: true
    },
    rentDestination: { value: input.rentDestination ?? null, isWritable: true },
    tokenProgram: { value: input.tokenProgram ?? null, isWritable: false },
    currencyTokenProgram: {
      value: input.currencyTokenProgram ?? null,
      isWritable: false
    },
    associatedTokenProgram: {
      value: input.associatedTokenProgram ?? null,
      isWritable: false
    },
    marketplaceProgram: {
      value: input.marketplaceProgram ?? null,
      isWritable: false
    },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false },
    cosigner: { value: input.cosigner ?? null, isWritable: false }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  if (!accounts.buyer.value) {
    accounts.buyer.value = expectTransactionSigner(
      accounts.payer.value
    ).address;
  }
  if (!accounts.rentDestination.value) {
    accounts.rentDestination.value = expectSome(accounts.owner.value);
  }
  if (!accounts.tokenProgram.value) {
    accounts.tokenProgram.value = "TokenkegQfeZyiNwAJbNbGKPFXCWuBvf9Ss623VQ5DA";
  }
  if (!accounts.associatedTokenProgram.value) {
    accounts.associatedTokenProgram.value = "ATokenGPvbdGVxr1b2hvZbsiqW5xWH25efTNsLJA8knL";
  }
  if (!accounts.marketplaceProgram.value) {
    accounts.marketplaceProgram.value = "TCMPhJdwDryooaGtiocG1u3xcYbRpiJzb283XfCZsDp";
  }
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  const remainingAccounts = (args.creators ?? []).map(
    (address3) => ({ address: address3, role: web3_js.AccountRole.WRITABLE })
  );
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.feeVault),
      getAccountMeta(accounts.feeVaultCurrencyTa),
      getAccountMeta(accounts.buyer),
      getAccountMeta(accounts.buyerTa),
      getAccountMeta(accounts.listTa),
      getAccountMeta(accounts.listState),
      getAccountMeta(accounts.mint),
      getAccountMeta(accounts.currency),
      getAccountMeta(accounts.owner),
      getAccountMeta(accounts.ownerCurrencyTa),
      getAccountMeta(accounts.payer),
      getAccountMeta(accounts.payerCurrencyTa),
      getAccountMeta(accounts.takerBroker),
      getAccountMeta(accounts.takerBrokerCurrencyTa),
      getAccountMeta(accounts.makerBroker),
      getAccountMeta(accounts.makerBrokerCurrencyTa),
      getAccountMeta(accounts.rentDestination),
      getAccountMeta(accounts.tokenProgram),
      getAccountMeta(accounts.currencyTokenProgram),
      getAccountMeta(accounts.associatedTokenProgram),
      getAccountMeta(accounts.marketplaceProgram),
      getAccountMeta(accounts.systemProgram),
      getAccountMeta(accounts.cosigner),
      ...remainingAccounts
    ],
    programAddress,
    data: getBuyT22SplInstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function parseBuyT22SplInstruction(instruction) {
  if (instruction.accounts.length < 23) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  const getNextOptionalAccount = () => {
    const accountMeta = getNextAccount();
    return accountMeta.address === TENSOR_MARKETPLACE_PROGRAM_ADDRESS ? void 0 : accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      feeVault: getNextAccount(),
      feeVaultCurrencyTa: getNextAccount(),
      buyer: getNextAccount(),
      buyerTa: getNextAccount(),
      listTa: getNextAccount(),
      listState: getNextAccount(),
      mint: getNextAccount(),
      currency: getNextAccount(),
      owner: getNextAccount(),
      ownerCurrencyTa: getNextAccount(),
      payer: getNextAccount(),
      payerCurrencyTa: getNextAccount(),
      takerBroker: getNextOptionalAccount(),
      takerBrokerCurrencyTa: getNextOptionalAccount(),
      makerBroker: getNextOptionalAccount(),
      makerBrokerCurrencyTa: getNextOptionalAccount(),
      rentDestination: getNextAccount(),
      tokenProgram: getNextAccount(),
      currencyTokenProgram: getNextAccount(),
      associatedTokenProgram: getNextAccount(),
      marketplaceProgram: getNextAccount(),
      systemProgram: getNextAccount(),
      cosigner: getNextOptionalAccount()
    },
    data: getBuyT22SplInstructionDataDecoder().decode(instruction.data)
  };
}
function getBuyWnsInstructionDataEncoder() {
  return web3_js.transformEncoder(
    web3_js.getStructEncoder([
      ["discriminator", web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 8)],
      ["maxAmount", web3_js.getU64Encoder()]
    ]),
    (value) => ({
      ...value,
      discriminator: new Uint8Array([168, 43, 179, 217, 44, 59, 35, 244])
    })
  );
}
function getBuyWnsInstructionDataDecoder() {
  return web3_js.getStructDecoder([
    ["discriminator", web3_js.fixDecoderSize(web3_js.getBytesDecoder(), 8)],
    ["maxAmount", web3_js.getU64Decoder()]
  ]);
}
function getBuyWnsInstructionDataCodec() {
  return web3_js.combineCodec(
    getBuyWnsInstructionDataEncoder(),
    getBuyWnsInstructionDataDecoder()
  );
}
async function getBuyWnsInstructionAsync(input) {
  const programAddress = TENSOR_MARKETPLACE_PROGRAM_ADDRESS;
  const originalAccounts = {
    feeVault: { value: input.feeVault ?? null, isWritable: true },
    buyer: { value: input.buyer ?? null, isWritable: false },
    buyerTa: { value: input.buyerTa ?? null, isWritable: true },
    listState: { value: input.listState ?? null, isWritable: true },
    listTa: { value: input.listTa ?? null, isWritable: true },
    mint: { value: input.mint ?? null, isWritable: false },
    owner: { value: input.owner ?? null, isWritable: true },
    payer: { value: input.payer ?? null, isWritable: true },
    takerBroker: { value: input.takerBroker ?? null, isWritable: true },
    makerBroker: { value: input.makerBroker ?? null, isWritable: true },
    rentDestination: { value: input.rentDestination ?? null, isWritable: true },
    tokenProgram: { value: input.tokenProgram ?? null, isWritable: false },
    associatedTokenProgram: {
      value: input.associatedTokenProgram ?? null,
      isWritable: false
    },
    marketplaceProgram: {
      value: input.marketplaceProgram ?? null,
      isWritable: false
    },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false },
    approve: { value: input.approve ?? null, isWritable: true },
    distribution: { value: input.distribution ?? null, isWritable: true },
    wnsProgram: { value: input.wnsProgram ?? null, isWritable: false },
    wnsDistributionProgram: {
      value: input.wnsDistributionProgram ?? null,
      isWritable: false
    },
    extraMetas: { value: input.extraMetas ?? null, isWritable: false },
    cosigner: { value: input.cosigner ?? null, isWritable: false }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  const resolverScope = { programAddress, accounts, args };
  if (!accounts.buyer.value) {
    accounts.buyer.value = expectTransactionSigner(
      accounts.payer.value
    ).address;
  }
  if (!accounts.tokenProgram.value) {
    accounts.tokenProgram.value = "TokenkegQfeZyiNwAJbNbGKPFXCWuBvf9Ss623VQ5DA";
  }
  if (!accounts.buyerTa.value) {
    accounts.buyerTa = {
      ...accounts.buyerTa,
      ...await resolvers.resolveBuyerAta(resolverScope)
    };
  }
  if (!accounts.listState.value) {
    accounts.listState.value = await findListStatePda({
      mint: expectAddress(accounts.mint.value)
    });
  }
  if (!accounts.listTa.value) {
    accounts.listTa = {
      ...accounts.listTa,
      ...await resolvers.resolveListAta(resolverScope)
    };
  }
  if (!accounts.rentDestination.value) {
    accounts.rentDestination.value = expectSome(accounts.owner.value);
  }
  if (!accounts.associatedTokenProgram.value) {
    accounts.associatedTokenProgram.value = "ATokenGPvbdGVxr1b2hvZbsiqW5xWH25efTNsLJA8knL";
  }
  if (!accounts.marketplaceProgram.value) {
    accounts.marketplaceProgram.value = "TCMPhJdwDryooaGtiocG1u3xcYbRpiJzb283XfCZsDp";
  }
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  if (!accounts.approve.value) {
    accounts.approve = {
      ...accounts.approve,
      ...await resolvers.resolveWnsApprovePda(resolverScope)
    };
  }
  if (!args.paymentMint) {
    args.paymentMint = "11111111111111111111111111111111";
  }
  if (!accounts.distribution.value) {
    accounts.distribution = {
      ...accounts.distribution,
      ...await resolvers.resolveWnsDistributionPda(resolverScope)
    };
  }
  if (!accounts.wnsProgram.value) {
    accounts.wnsProgram.value = "wns1gDLt8fgLcGhWi5MqAqgXpwEP1JftKE9eZnXS1HM";
  }
  if (!accounts.wnsDistributionProgram.value) {
    accounts.wnsDistributionProgram.value = "diste3nXmK7ddDTs1zb6uday6j4etCa9RChD8fJ1xay";
  }
  if (!accounts.extraMetas.value) {
    accounts.extraMetas = {
      ...accounts.extraMetas,
      ...await resolvers.resolveWnsExtraAccountMetasPda(resolverScope)
    };
  }
  if (!accounts.cosigner.value) {
    accounts.cosigner.value = "TCMPhJdwDryooaGtiocG1u3xcYbRpiJzb283XfCZsDp";
  }
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.feeVault),
      getAccountMeta(accounts.buyer),
      getAccountMeta(accounts.buyerTa),
      getAccountMeta(accounts.listState),
      getAccountMeta(accounts.listTa),
      getAccountMeta(accounts.mint),
      getAccountMeta(accounts.owner),
      getAccountMeta(accounts.payer),
      getAccountMeta(accounts.takerBroker),
      getAccountMeta(accounts.makerBroker),
      getAccountMeta(accounts.rentDestination),
      getAccountMeta(accounts.tokenProgram),
      getAccountMeta(accounts.associatedTokenProgram),
      getAccountMeta(accounts.marketplaceProgram),
      getAccountMeta(accounts.systemProgram),
      getAccountMeta(accounts.approve),
      getAccountMeta(accounts.distribution),
      getAccountMeta(accounts.wnsProgram),
      getAccountMeta(accounts.wnsDistributionProgram),
      getAccountMeta(accounts.extraMetas),
      getAccountMeta(accounts.cosigner)
    ],
    programAddress,
    data: getBuyWnsInstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function getBuyWnsInstruction(input) {
  const programAddress = TENSOR_MARKETPLACE_PROGRAM_ADDRESS;
  const originalAccounts = {
    feeVault: { value: input.feeVault ?? null, isWritable: true },
    buyer: { value: input.buyer ?? null, isWritable: false },
    buyerTa: { value: input.buyerTa ?? null, isWritable: true },
    listState: { value: input.listState ?? null, isWritable: true },
    listTa: { value: input.listTa ?? null, isWritable: true },
    mint: { value: input.mint ?? null, isWritable: false },
    owner: { value: input.owner ?? null, isWritable: true },
    payer: { value: input.payer ?? null, isWritable: true },
    takerBroker: { value: input.takerBroker ?? null, isWritable: true },
    makerBroker: { value: input.makerBroker ?? null, isWritable: true },
    rentDestination: { value: input.rentDestination ?? null, isWritable: true },
    tokenProgram: { value: input.tokenProgram ?? null, isWritable: false },
    associatedTokenProgram: {
      value: input.associatedTokenProgram ?? null,
      isWritable: false
    },
    marketplaceProgram: {
      value: input.marketplaceProgram ?? null,
      isWritable: false
    },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false },
    approve: { value: input.approve ?? null, isWritable: true },
    distribution: { value: input.distribution ?? null, isWritable: true },
    wnsProgram: { value: input.wnsProgram ?? null, isWritable: false },
    wnsDistributionProgram: {
      value: input.wnsDistributionProgram ?? null,
      isWritable: false
    },
    extraMetas: { value: input.extraMetas ?? null, isWritable: false },
    cosigner: { value: input.cosigner ?? null, isWritable: false }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  if (!accounts.buyer.value) {
    accounts.buyer.value = expectTransactionSigner(
      accounts.payer.value
    ).address;
  }
  if (!accounts.tokenProgram.value) {
    accounts.tokenProgram.value = "TokenkegQfeZyiNwAJbNbGKPFXCWuBvf9Ss623VQ5DA";
  }
  if (!accounts.rentDestination.value) {
    accounts.rentDestination.value = expectSome(accounts.owner.value);
  }
  if (!accounts.associatedTokenProgram.value) {
    accounts.associatedTokenProgram.value = "ATokenGPvbdGVxr1b2hvZbsiqW5xWH25efTNsLJA8knL";
  }
  if (!accounts.marketplaceProgram.value) {
    accounts.marketplaceProgram.value = "TCMPhJdwDryooaGtiocG1u3xcYbRpiJzb283XfCZsDp";
  }
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  if (!args.paymentMint) {
    args.paymentMint = "11111111111111111111111111111111";
  }
  if (!accounts.wnsProgram.value) {
    accounts.wnsProgram.value = "wns1gDLt8fgLcGhWi5MqAqgXpwEP1JftKE9eZnXS1HM";
  }
  if (!accounts.wnsDistributionProgram.value) {
    accounts.wnsDistributionProgram.value = "diste3nXmK7ddDTs1zb6uday6j4etCa9RChD8fJ1xay";
  }
  if (!accounts.cosigner.value) {
    accounts.cosigner.value = "TCMPhJdwDryooaGtiocG1u3xcYbRpiJzb283XfCZsDp";
  }
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.feeVault),
      getAccountMeta(accounts.buyer),
      getAccountMeta(accounts.buyerTa),
      getAccountMeta(accounts.listState),
      getAccountMeta(accounts.listTa),
      getAccountMeta(accounts.mint),
      getAccountMeta(accounts.owner),
      getAccountMeta(accounts.payer),
      getAccountMeta(accounts.takerBroker),
      getAccountMeta(accounts.makerBroker),
      getAccountMeta(accounts.rentDestination),
      getAccountMeta(accounts.tokenProgram),
      getAccountMeta(accounts.associatedTokenProgram),
      getAccountMeta(accounts.marketplaceProgram),
      getAccountMeta(accounts.systemProgram),
      getAccountMeta(accounts.approve),
      getAccountMeta(accounts.distribution),
      getAccountMeta(accounts.wnsProgram),
      getAccountMeta(accounts.wnsDistributionProgram),
      getAccountMeta(accounts.extraMetas),
      getAccountMeta(accounts.cosigner)
    ],
    programAddress,
    data: getBuyWnsInstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function parseBuyWnsInstruction(instruction) {
  if (instruction.accounts.length < 21) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  const getNextOptionalAccount = () => {
    const accountMeta = getNextAccount();
    return accountMeta.address === TENSOR_MARKETPLACE_PROGRAM_ADDRESS ? void 0 : accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      feeVault: getNextAccount(),
      buyer: getNextAccount(),
      buyerTa: getNextAccount(),
      listState: getNextAccount(),
      listTa: getNextAccount(),
      mint: getNextAccount(),
      owner: getNextAccount(),
      payer: getNextAccount(),
      takerBroker: getNextOptionalAccount(),
      makerBroker: getNextOptionalAccount(),
      rentDestination: getNextAccount(),
      tokenProgram: getNextAccount(),
      associatedTokenProgram: getNextAccount(),
      marketplaceProgram: getNextAccount(),
      systemProgram: getNextAccount(),
      approve: getNextAccount(),
      distribution: getNextAccount(),
      wnsProgram: getNextAccount(),
      wnsDistributionProgram: getNextAccount(),
      extraMetas: getNextAccount(),
      cosigner: getNextOptionalAccount()
    },
    data: getBuyWnsInstructionDataDecoder().decode(instruction.data)
  };
}
function getBuyWnsSplInstructionDataEncoder() {
  return web3_js.transformEncoder(
    web3_js.getStructEncoder([
      ["discriminator", web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 8)],
      ["maxAmount", web3_js.getU64Encoder()]
    ]),
    (value) => ({
      ...value,
      discriminator: new Uint8Array([113, 137, 57, 23, 186, 196, 217, 210])
    })
  );
}
function getBuyWnsSplInstructionDataDecoder() {
  return web3_js.getStructDecoder([
    ["discriminator", web3_js.fixDecoderSize(web3_js.getBytesDecoder(), 8)],
    ["maxAmount", web3_js.getU64Decoder()]
  ]);
}
function getBuyWnsSplInstructionDataCodec() {
  return web3_js.combineCodec(
    getBuyWnsSplInstructionDataEncoder(),
    getBuyWnsSplInstructionDataDecoder()
  );
}
function getBuyWnsSplInstruction(input) {
  const programAddress = TENSOR_MARKETPLACE_PROGRAM_ADDRESS;
  const originalAccounts = {
    feeVault: { value: input.feeVault ?? null, isWritable: true },
    feeVaultCurrencyTa: {
      value: input.feeVaultCurrencyTa ?? null,
      isWritable: true
    },
    buyer: { value: input.buyer ?? null, isWritable: false },
    buyerTa: { value: input.buyerTa ?? null, isWritable: true },
    listTa: { value: input.listTa ?? null, isWritable: true },
    listState: { value: input.listState ?? null, isWritable: true },
    mint: { value: input.mint ?? null, isWritable: false },
    currency: { value: input.currency ?? null, isWritable: false },
    owner: { value: input.owner ?? null, isWritable: true },
    ownerCurrencyTa: { value: input.ownerCurrencyTa ?? null, isWritable: true },
    payer: { value: input.payer ?? null, isWritable: true },
    payerCurrencyTa: { value: input.payerCurrencyTa ?? null, isWritable: true },
    takerBroker: { value: input.takerBroker ?? null, isWritable: true },
    takerBrokerCurrencyTa: {
      value: input.takerBrokerCurrencyTa ?? null,
      isWritable: true
    },
    makerBroker: { value: input.makerBroker ?? null, isWritable: true },
    makerBrokerCurrencyTa: {
      value: input.makerBrokerCurrencyTa ?? null,
      isWritable: true
    },
    rentDestination: { value: input.rentDestination ?? null, isWritable: true },
    tokenProgram: { value: input.tokenProgram ?? null, isWritable: false },
    currencyTokenProgram: {
      value: input.currencyTokenProgram ?? null,
      isWritable: false
    },
    associatedTokenProgram: {
      value: input.associatedTokenProgram ?? null,
      isWritable: false
    },
    marketplaceProgram: {
      value: input.marketplaceProgram ?? null,
      isWritable: false
    },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false },
    approve: { value: input.approve ?? null, isWritable: true },
    distribution: { value: input.distribution ?? null, isWritable: true },
    distributionCurrencyTa: {
      value: input.distributionCurrencyTa ?? null,
      isWritable: true
    },
    wnsProgram: { value: input.wnsProgram ?? null, isWritable: false },
    wnsDistributionProgram: {
      value: input.wnsDistributionProgram ?? null,
      isWritable: false
    },
    extraMetas: { value: input.extraMetas ?? null, isWritable: false },
    cosigner: { value: input.cosigner ?? null, isWritable: false }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  if (!accounts.tokenProgram.value) {
    accounts.tokenProgram.value = "TokenkegQfeZyiNwAJbNbGKPFXCWuBvf9Ss623VQ5DA";
  }
  if (!accounts.associatedTokenProgram.value) {
    accounts.associatedTokenProgram.value = "ATokenGPvbdGVxr1b2hvZbsiqW5xWH25efTNsLJA8knL";
  }
  if (!accounts.marketplaceProgram.value) {
    accounts.marketplaceProgram.value = "TCMPhJdwDryooaGtiocG1u3xcYbRpiJzb283XfCZsDp";
  }
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  if (!accounts.wnsProgram.value) {
    accounts.wnsProgram.value = "wns1gDLt8fgLcGhWi5MqAqgXpwEP1JftKE9eZnXS1HM";
  }
  if (!accounts.wnsDistributionProgram.value) {
    accounts.wnsDistributionProgram.value = "diste3nXmK7ddDTs1zb6uday6j4etCa9RChD8fJ1xay";
  }
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.feeVault),
      getAccountMeta(accounts.feeVaultCurrencyTa),
      getAccountMeta(accounts.buyer),
      getAccountMeta(accounts.buyerTa),
      getAccountMeta(accounts.listTa),
      getAccountMeta(accounts.listState),
      getAccountMeta(accounts.mint),
      getAccountMeta(accounts.currency),
      getAccountMeta(accounts.owner),
      getAccountMeta(accounts.ownerCurrencyTa),
      getAccountMeta(accounts.payer),
      getAccountMeta(accounts.payerCurrencyTa),
      getAccountMeta(accounts.takerBroker),
      getAccountMeta(accounts.takerBrokerCurrencyTa),
      getAccountMeta(accounts.makerBroker),
      getAccountMeta(accounts.makerBrokerCurrencyTa),
      getAccountMeta(accounts.rentDestination),
      getAccountMeta(accounts.tokenProgram),
      getAccountMeta(accounts.currencyTokenProgram),
      getAccountMeta(accounts.associatedTokenProgram),
      getAccountMeta(accounts.marketplaceProgram),
      getAccountMeta(accounts.systemProgram),
      getAccountMeta(accounts.approve),
      getAccountMeta(accounts.distribution),
      getAccountMeta(accounts.distributionCurrencyTa),
      getAccountMeta(accounts.wnsProgram),
      getAccountMeta(accounts.wnsDistributionProgram),
      getAccountMeta(accounts.extraMetas),
      getAccountMeta(accounts.cosigner)
    ],
    programAddress,
    data: getBuyWnsSplInstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function parseBuyWnsSplInstruction(instruction) {
  if (instruction.accounts.length < 29) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  const getNextOptionalAccount = () => {
    const accountMeta = getNextAccount();
    return accountMeta.address === TENSOR_MARKETPLACE_PROGRAM_ADDRESS ? void 0 : accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      feeVault: getNextAccount(),
      feeVaultCurrencyTa: getNextAccount(),
      buyer: getNextAccount(),
      buyerTa: getNextAccount(),
      listTa: getNextAccount(),
      listState: getNextAccount(),
      mint: getNextAccount(),
      currency: getNextAccount(),
      owner: getNextAccount(),
      ownerCurrencyTa: getNextAccount(),
      payer: getNextAccount(),
      payerCurrencyTa: getNextAccount(),
      takerBroker: getNextOptionalAccount(),
      takerBrokerCurrencyTa: getNextOptionalAccount(),
      makerBroker: getNextOptionalAccount(),
      makerBrokerCurrencyTa: getNextOptionalAccount(),
      rentDestination: getNextAccount(),
      tokenProgram: getNextAccount(),
      currencyTokenProgram: getNextAccount(),
      associatedTokenProgram: getNextAccount(),
      marketplaceProgram: getNextAccount(),
      systemProgram: getNextAccount(),
      approve: getNextAccount(),
      distribution: getNextAccount(),
      distributionCurrencyTa: getNextAccount(),
      wnsProgram: getNextAccount(),
      wnsDistributionProgram: getNextAccount(),
      extraMetas: getNextAccount(),
      cosigner: getNextOptionalAccount()
    },
    data: getBuyWnsSplInstructionDataDecoder().decode(instruction.data)
  };
}
function getCancelBidInstructionDataEncoder() {
  return web3_js.transformEncoder(
    web3_js.getStructEncoder([["discriminator", web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 8)]]),
    (value) => ({
      ...value,
      discriminator: new Uint8Array([40, 243, 190, 217, 208, 253, 86, 206])
    })
  );
}
function getCancelBidInstructionDataDecoder() {
  return web3_js.getStructDecoder([
    ["discriminator", web3_js.fixDecoderSize(web3_js.getBytesDecoder(), 8)]
  ]);
}
function getCancelBidInstructionDataCodec() {
  return web3_js.combineCodec(
    getCancelBidInstructionDataEncoder(),
    getCancelBidInstructionDataDecoder()
  );
}
async function getCancelBidInstructionAsync(input) {
  const programAddress = TENSOR_MARKETPLACE_PROGRAM_ADDRESS;
  const originalAccounts = {
    bidState: { value: input.bidState ?? null, isWritable: true },
    owner: { value: input.owner ?? null, isWritable: true },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false },
    marketplaceProgram: {
      value: input.marketplaceProgram ?? null,
      isWritable: false
    },
    rentDestination: { value: input.rentDestination ?? null, isWritable: true }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  if (!args.bidId) {
    args.bidId = "11111111111111111111111111111111";
  }
  if (!accounts.bidState.value) {
    accounts.bidState.value = await findBidStatePda({
      bidId: expectSome(args.bidId),
      owner: expectAddress(accounts.owner.value)
    });
  }
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  if (!accounts.marketplaceProgram.value) {
    accounts.marketplaceProgram.value = "TCMPhJdwDryooaGtiocG1u3xcYbRpiJzb283XfCZsDp";
  }
  if (!accounts.rentDestination.value) {
    accounts.rentDestination.value = expectTransactionSigner(
      accounts.owner.value
    ).address;
  }
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.bidState),
      getAccountMeta(accounts.owner),
      getAccountMeta(accounts.systemProgram),
      getAccountMeta(accounts.marketplaceProgram),
      getAccountMeta(accounts.rentDestination)
    ],
    programAddress,
    data: getCancelBidInstructionDataEncoder().encode({})
  };
  return instruction;
}
function getCancelBidInstruction(input) {
  const programAddress = TENSOR_MARKETPLACE_PROGRAM_ADDRESS;
  const originalAccounts = {
    bidState: { value: input.bidState ?? null, isWritable: true },
    owner: { value: input.owner ?? null, isWritable: true },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false },
    marketplaceProgram: {
      value: input.marketplaceProgram ?? null,
      isWritable: false
    },
    rentDestination: { value: input.rentDestination ?? null, isWritable: true }
  };
  const accounts = originalAccounts;
  ({ ...input });
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  if (!accounts.marketplaceProgram.value) {
    accounts.marketplaceProgram.value = "TCMPhJdwDryooaGtiocG1u3xcYbRpiJzb283XfCZsDp";
  }
  if (!accounts.rentDestination.value) {
    accounts.rentDestination.value = expectTransactionSigner(
      accounts.owner.value
    ).address;
  }
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.bidState),
      getAccountMeta(accounts.owner),
      getAccountMeta(accounts.systemProgram),
      getAccountMeta(accounts.marketplaceProgram),
      getAccountMeta(accounts.rentDestination)
    ],
    programAddress,
    data: getCancelBidInstructionDataEncoder().encode({})
  };
  return instruction;
}
function parseCancelBidInstruction(instruction) {
  if (instruction.accounts.length < 5) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      bidState: getNextAccount(),
      owner: getNextAccount(),
      systemProgram: getNextAccount(),
      marketplaceProgram: getNextAccount(),
      rentDestination: getNextAccount()
    },
    data: getCancelBidInstructionDataDecoder().decode(instruction.data)
  };
}
function getCloseExpiredBidInstructionDataEncoder() {
  return web3_js.transformEncoder(
    web3_js.getStructEncoder([["discriminator", web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 8)]]),
    (value) => ({
      ...value,
      discriminator: new Uint8Array([83, 20, 105, 67, 248, 68, 104, 190])
    })
  );
}
function getCloseExpiredBidInstructionDataDecoder() {
  return web3_js.getStructDecoder([
    ["discriminator", web3_js.fixDecoderSize(web3_js.getBytesDecoder(), 8)]
  ]);
}
function getCloseExpiredBidInstructionDataCodec() {
  return web3_js.combineCodec(
    getCloseExpiredBidInstructionDataEncoder(),
    getCloseExpiredBidInstructionDataDecoder()
  );
}
async function getCloseExpiredBidInstructionAsync(input) {
  const programAddress = TENSOR_MARKETPLACE_PROGRAM_ADDRESS;
  const originalAccounts = {
    bidState: { value: input.bidState ?? null, isWritable: true },
    owner: { value: input.owner ?? null, isWritable: true },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false },
    marketplaceProgram: {
      value: input.marketplaceProgram ?? null,
      isWritable: false
    },
    rentDestination: { value: input.rentDestination ?? null, isWritable: true }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  if (!args.bidId) {
    args.bidId = "11111111111111111111111111111111";
  }
  if (!accounts.bidState.value) {
    accounts.bidState.value = await findBidStatePda({
      bidId: expectSome(args.bidId),
      owner: expectAddress(accounts.owner.value)
    });
  }
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  if (!accounts.marketplaceProgram.value) {
    accounts.marketplaceProgram.value = "TCMPhJdwDryooaGtiocG1u3xcYbRpiJzb283XfCZsDp";
  }
  if (!accounts.rentDestination.value) {
    accounts.rentDestination.value = expectSome(accounts.owner.value);
  }
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.bidState),
      getAccountMeta(accounts.owner),
      getAccountMeta(accounts.systemProgram),
      getAccountMeta(accounts.marketplaceProgram),
      getAccountMeta(accounts.rentDestination)
    ],
    programAddress,
    data: getCloseExpiredBidInstructionDataEncoder().encode({})
  };
  return instruction;
}
function getCloseExpiredBidInstruction(input) {
  const programAddress = TENSOR_MARKETPLACE_PROGRAM_ADDRESS;
  const originalAccounts = {
    bidState: { value: input.bidState ?? null, isWritable: true },
    owner: { value: input.owner ?? null, isWritable: true },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false },
    marketplaceProgram: {
      value: input.marketplaceProgram ?? null,
      isWritable: false
    },
    rentDestination: { value: input.rentDestination ?? null, isWritable: true }
  };
  const accounts = originalAccounts;
  ({ ...input });
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  if (!accounts.marketplaceProgram.value) {
    accounts.marketplaceProgram.value = "TCMPhJdwDryooaGtiocG1u3xcYbRpiJzb283XfCZsDp";
  }
  if (!accounts.rentDestination.value) {
    accounts.rentDestination.value = expectSome(accounts.owner.value);
  }
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.bidState),
      getAccountMeta(accounts.owner),
      getAccountMeta(accounts.systemProgram),
      getAccountMeta(accounts.marketplaceProgram),
      getAccountMeta(accounts.rentDestination)
    ],
    programAddress,
    data: getCloseExpiredBidInstructionDataEncoder().encode({})
  };
  return instruction;
}
function parseCloseExpiredBidInstruction(instruction) {
  if (instruction.accounts.length < 5) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      bidState: getNextAccount(),
      owner: getNextAccount(),
      systemProgram: getNextAccount(),
      marketplaceProgram: getNextAccount(),
      rentDestination: getNextAccount()
    },
    data: getCloseExpiredBidInstructionDataDecoder().decode(instruction.data)
  };
}
function getCloseExpiredListingCompressedInstructionDataEncoder() {
  return web3_js.transformEncoder(
    web3_js.getStructEncoder([
      ["discriminator", web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 8)],
      ["nonce", web3_js.getU64Encoder()],
      ["index", web3_js.getU32Encoder()],
      ["root", web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 32)],
      ["dataHash", web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 32)],
      ["creatorHash", web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 32)]
    ]),
    (value) => ({
      ...value,
      discriminator: new Uint8Array([150, 70, 13, 135, 9, 204, 75, 4])
    })
  );
}
function getCloseExpiredListingCompressedInstructionDataDecoder() {
  return web3_js.getStructDecoder([
    ["discriminator", web3_js.fixDecoderSize(web3_js.getBytesDecoder(), 8)],
    ["nonce", web3_js.getU64Decoder()],
    ["index", web3_js.getU32Decoder()],
    ["root", web3_js.fixDecoderSize(web3_js.getBytesDecoder(), 32)],
    ["dataHash", web3_js.fixDecoderSize(web3_js.getBytesDecoder(), 32)],
    ["creatorHash", web3_js.fixDecoderSize(web3_js.getBytesDecoder(), 32)]
  ]);
}
function getCloseExpiredListingCompressedInstructionDataCodec() {
  return web3_js.combineCodec(
    getCloseExpiredListingCompressedInstructionDataEncoder(),
    getCloseExpiredListingCompressedInstructionDataDecoder()
  );
}
async function getCloseExpiredListingCompressedInstructionAsync(input) {
  const programAddress = TENSOR_MARKETPLACE_PROGRAM_ADDRESS;
  const originalAccounts = {
    listState: { value: input.listState ?? null, isWritable: true },
    owner: { value: input.owner ?? null, isWritable: false },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false },
    marketplaceProgram: {
      value: input.marketplaceProgram ?? null,
      isWritable: false
    },
    treeAuthority: { value: input.treeAuthority ?? null, isWritable: false },
    merkleTree: { value: input.merkleTree ?? null, isWritable: true },
    logWrapper: { value: input.logWrapper ?? null, isWritable: false },
    compressionProgram: {
      value: input.compressionProgram ?? null,
      isWritable: false
    },
    bubblegumProgram: {
      value: input.bubblegumProgram ?? null,
      isWritable: false
    },
    rentDestination: { value: input.rentDestination ?? null, isWritable: true }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  const resolverScope = { programAddress, accounts, args };
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  if (!accounts.marketplaceProgram.value) {
    accounts.marketplaceProgram.value = "TCMPhJdwDryooaGtiocG1u3xcYbRpiJzb283XfCZsDp";
  }
  if (!accounts.bubblegumProgram.value) {
    accounts.bubblegumProgram.value = "BGUMAp9Gq7iTEuizy4pqaxsTyUCBK68MDfK752saRPUY";
  }
  if (!accounts.treeAuthority.value) {
    accounts.treeAuthority = {
      ...accounts.treeAuthority,
      ...await resolveTreeAuthorityPda(resolverScope)
    };
  }
  if (!accounts.logWrapper.value) {
    accounts.logWrapper.value = "noopb9bkMVfRPU8AsbpTUg8AQkHtKwMYZiFUjNRtMmV";
  }
  if (!accounts.compressionProgram.value) {
    accounts.compressionProgram.value = "cmtDvXumGCrqC1Age74AVPhSRVXJMd8PJS91L8KbNCK";
  }
  if (!accounts.rentDestination.value) {
    accounts.rentDestination.value = expectSome(accounts.owner.value);
  }
  if (!args.nonce) {
    args.nonce = expectSome(args.index);
  }
  if (!args.creators) {
    args.creators = [];
  }
  if (!args.proof) {
    args.proof = [];
  }
  if (!args.canopyDepth) {
    args.canopyDepth = 0;
  }
  const remainingAccounts = [
    ...resolveCreatorPath(resolverScope),
    ...resolveProofPath(resolverScope)
  ];
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.listState),
      getAccountMeta(accounts.owner),
      getAccountMeta(accounts.systemProgram),
      getAccountMeta(accounts.marketplaceProgram),
      getAccountMeta(accounts.treeAuthority),
      getAccountMeta(accounts.merkleTree),
      getAccountMeta(accounts.logWrapper),
      getAccountMeta(accounts.compressionProgram),
      getAccountMeta(accounts.bubblegumProgram),
      getAccountMeta(accounts.rentDestination),
      ...remainingAccounts
    ],
    programAddress,
    data: getCloseExpiredListingCompressedInstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function getCloseExpiredListingCompressedInstruction(input) {
  const programAddress = TENSOR_MARKETPLACE_PROGRAM_ADDRESS;
  const originalAccounts = {
    listState: { value: input.listState ?? null, isWritable: true },
    owner: { value: input.owner ?? null, isWritable: false },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false },
    marketplaceProgram: {
      value: input.marketplaceProgram ?? null,
      isWritable: false
    },
    treeAuthority: { value: input.treeAuthority ?? null, isWritable: false },
    merkleTree: { value: input.merkleTree ?? null, isWritable: true },
    logWrapper: { value: input.logWrapper ?? null, isWritable: false },
    compressionProgram: {
      value: input.compressionProgram ?? null,
      isWritable: false
    },
    bubblegumProgram: {
      value: input.bubblegumProgram ?? null,
      isWritable: false
    },
    rentDestination: { value: input.rentDestination ?? null, isWritable: true }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  const resolverScope = { programAddress, accounts, args };
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  if (!accounts.marketplaceProgram.value) {
    accounts.marketplaceProgram.value = "TCMPhJdwDryooaGtiocG1u3xcYbRpiJzb283XfCZsDp";
  }
  if (!accounts.bubblegumProgram.value) {
    accounts.bubblegumProgram.value = "BGUMAp9Gq7iTEuizy4pqaxsTyUCBK68MDfK752saRPUY";
  }
  if (!accounts.logWrapper.value) {
    accounts.logWrapper.value = "noopb9bkMVfRPU8AsbpTUg8AQkHtKwMYZiFUjNRtMmV";
  }
  if (!accounts.compressionProgram.value) {
    accounts.compressionProgram.value = "cmtDvXumGCrqC1Age74AVPhSRVXJMd8PJS91L8KbNCK";
  }
  if (!accounts.rentDestination.value) {
    accounts.rentDestination.value = expectSome(accounts.owner.value);
  }
  if (!args.nonce) {
    args.nonce = expectSome(args.index);
  }
  if (!args.creators) {
    args.creators = [];
  }
  if (!args.proof) {
    args.proof = [];
  }
  if (!args.canopyDepth) {
    args.canopyDepth = 0;
  }
  const remainingAccounts = [
    ...resolveCreatorPath(resolverScope),
    ...resolveProofPath(resolverScope)
  ];
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.listState),
      getAccountMeta(accounts.owner),
      getAccountMeta(accounts.systemProgram),
      getAccountMeta(accounts.marketplaceProgram),
      getAccountMeta(accounts.treeAuthority),
      getAccountMeta(accounts.merkleTree),
      getAccountMeta(accounts.logWrapper),
      getAccountMeta(accounts.compressionProgram),
      getAccountMeta(accounts.bubblegumProgram),
      getAccountMeta(accounts.rentDestination),
      ...remainingAccounts
    ],
    programAddress,
    data: getCloseExpiredListingCompressedInstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function parseCloseExpiredListingCompressedInstruction(instruction) {
  if (instruction.accounts.length < 10) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      listState: getNextAccount(),
      owner: getNextAccount(),
      systemProgram: getNextAccount(),
      marketplaceProgram: getNextAccount(),
      treeAuthority: getNextAccount(),
      merkleTree: getNextAccount(),
      logWrapper: getNextAccount(),
      compressionProgram: getNextAccount(),
      bubblegumProgram: getNextAccount(),
      rentDestination: getNextAccount()
    },
    data: getCloseExpiredListingCompressedInstructionDataDecoder().decode(
      instruction.data
    )
  };
}
function getCloseExpiredListingCoreInstructionDataEncoder() {
  return web3_js.transformEncoder(
    web3_js.getStructEncoder([["discriminator", web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 8)]]),
    (value) => ({
      ...value,
      discriminator: new Uint8Array([89, 171, 78, 80, 74, 188, 63, 58])
    })
  );
}
function getCloseExpiredListingCoreInstructionDataDecoder() {
  return web3_js.getStructDecoder([
    ["discriminator", web3_js.fixDecoderSize(web3_js.getBytesDecoder(), 8)]
  ]);
}
function getCloseExpiredListingCoreInstructionDataCodec() {
  return web3_js.combineCodec(
    getCloseExpiredListingCoreInstructionDataEncoder(),
    getCloseExpiredListingCoreInstructionDataDecoder()
  );
}
function getCloseExpiredListingCoreInstruction(input) {
  const programAddress = TENSOR_MARKETPLACE_PROGRAM_ADDRESS;
  const originalAccounts = {
    listState: { value: input.listState ?? null, isWritable: true },
    asset: { value: input.asset ?? null, isWritable: true },
    collection: { value: input.collection ?? null, isWritable: false },
    owner: { value: input.owner ?? null, isWritable: false },
    mplCoreProgram: { value: input.mplCoreProgram ?? null, isWritable: false },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false },
    marketplaceProgram: {
      value: input.marketplaceProgram ?? null,
      isWritable: false
    },
    rentDestination: { value: input.rentDestination ?? null, isWritable: true }
  };
  const accounts = originalAccounts;
  if (!accounts.mplCoreProgram.value) {
    accounts.mplCoreProgram.value = "CoREENxT6tW1HoK8ypY1SxRMZTcVPm7R94rH4PZNhX7d";
  }
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  if (!accounts.marketplaceProgram.value) {
    accounts.marketplaceProgram.value = "TCMPhJdwDryooaGtiocG1u3xcYbRpiJzb283XfCZsDp";
  }
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.listState),
      getAccountMeta(accounts.asset),
      getAccountMeta(accounts.collection),
      getAccountMeta(accounts.owner),
      getAccountMeta(accounts.mplCoreProgram),
      getAccountMeta(accounts.systemProgram),
      getAccountMeta(accounts.marketplaceProgram),
      getAccountMeta(accounts.rentDestination)
    ],
    programAddress,
    data: getCloseExpiredListingCoreInstructionDataEncoder().encode({})
  };
  return instruction;
}
function parseCloseExpiredListingCoreInstruction(instruction) {
  if (instruction.accounts.length < 8) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  const getNextOptionalAccount = () => {
    const accountMeta = getNextAccount();
    return accountMeta.address === TENSOR_MARKETPLACE_PROGRAM_ADDRESS ? void 0 : accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      listState: getNextAccount(),
      asset: getNextAccount(),
      collection: getNextOptionalAccount(),
      owner: getNextAccount(),
      mplCoreProgram: getNextAccount(),
      systemProgram: getNextAccount(),
      marketplaceProgram: getNextAccount(),
      rentDestination: getNextAccount()
    },
    data: getCloseExpiredListingCoreInstructionDataDecoder().decode(
      instruction.data
    )
  };
}
function getCloseExpiredListingLegacyInstructionDataEncoder() {
  return web3_js.transformEncoder(
    web3_js.getStructEncoder([
      ["discriminator", web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 8)],
      [
        "authorizationData",
        web3_js.getOptionEncoder(getAuthorizationDataLocalEncoder())
      ]
    ]),
    (value) => ({
      ...value,
      discriminator: new Uint8Array([56, 16, 96, 188, 55, 68, 250, 58]),
      authorizationData: value.authorizationData ?? web3_js.none()
    })
  );
}
function getCloseExpiredListingLegacyInstructionDataDecoder() {
  return web3_js.getStructDecoder([
    ["discriminator", web3_js.fixDecoderSize(web3_js.getBytesDecoder(), 8)],
    ["authorizationData", web3_js.getOptionDecoder(getAuthorizationDataLocalDecoder())]
  ]);
}
function getCloseExpiredListingLegacyInstructionDataCodec() {
  return web3_js.combineCodec(
    getCloseExpiredListingLegacyInstructionDataEncoder(),
    getCloseExpiredListingLegacyInstructionDataDecoder()
  );
}
async function getCloseExpiredListingLegacyInstructionAsync(input) {
  const programAddress = TENSOR_MARKETPLACE_PROGRAM_ADDRESS;
  const originalAccounts = {
    owner: { value: input.owner ?? null, isWritable: false },
    ownerTa: { value: input.ownerTa ?? null, isWritable: true },
    listState: { value: input.listState ?? null, isWritable: true },
    listTa: { value: input.listTa ?? null, isWritable: true },
    mint: { value: input.mint ?? null, isWritable: false },
    payer: { value: input.payer ?? null, isWritable: true },
    rentDestination: { value: input.rentDestination ?? null, isWritable: true },
    tokenProgram: { value: input.tokenProgram ?? null, isWritable: false },
    associatedTokenProgram: {
      value: input.associatedTokenProgram ?? null,
      isWritable: false
    },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false },
    marketplaceProgram: {
      value: input.marketplaceProgram ?? null,
      isWritable: false
    },
    metadata: { value: input.metadata ?? null, isWritable: true },
    edition: { value: input.edition ?? null, isWritable: false },
    ownerTokenRecord: {
      value: input.ownerTokenRecord ?? null,
      isWritable: true
    },
    listTokenRecord: { value: input.listTokenRecord ?? null, isWritable: true },
    authorizationRules: {
      value: input.authorizationRules ?? null,
      isWritable: false
    },
    authorizationRulesProgram: {
      value: input.authorizationRulesProgram ?? null,
      isWritable: false
    },
    tokenMetadataProgram: {
      value: input.tokenMetadataProgram ?? null,
      isWritable: false
    },
    sysvarInstructions: {
      value: input.sysvarInstructions ?? null,
      isWritable: false
    }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  const resolverScope = { programAddress, accounts, args };
  if (!accounts.owner.value) {
    accounts.owner.value = expectTransactionSigner(
      accounts.payer.value
    ).address;
  }
  if (!accounts.tokenProgram.value) {
    accounts.tokenProgram.value = "TokenkegQfeZyiNwAJbNbGKPFXCWuBvf9Ss623VQ5DA";
  }
  if (!accounts.ownerTa.value) {
    accounts.ownerTa = {
      ...accounts.ownerTa,
      ...await resolvers.resolveOwnerAta(resolverScope)
    };
  }
  if (!accounts.listState.value) {
    accounts.listState.value = await findListStatePda({
      mint: expectAddress(accounts.mint.value)
    });
  }
  if (!accounts.listTa.value) {
    accounts.listTa = {
      ...accounts.listTa,
      ...await resolvers.resolveListAta(resolverScope)
    };
  }
  if (!accounts.rentDestination.value) {
    accounts.rentDestination.value = expectSome(accounts.owner.value);
  }
  if (!accounts.associatedTokenProgram.value) {
    accounts.associatedTokenProgram.value = "ATokenGPvbdGVxr1b2hvZbsiqW5xWH25efTNsLJA8knL";
  }
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  if (!accounts.marketplaceProgram.value) {
    accounts.marketplaceProgram.value = "TCMPhJdwDryooaGtiocG1u3xcYbRpiJzb283XfCZsDp";
  }
  if (!accounts.metadata.value) {
    accounts.metadata = {
      ...accounts.metadata,
      ...await resolvers.resolveMetadata(resolverScope)
    };
  }
  if (!args.tokenStandard) {
    args.tokenStandard = resolvers.TokenStandard.ProgrammableNonFungible;
  }
  if (!accounts.edition.value) {
    accounts.edition = {
      ...accounts.edition,
      ...await resolvers.resolveEditionFromTokenStandard(resolverScope)
    };
  }
  if (!accounts.ownerTokenRecord.value) {
    accounts.ownerTokenRecord = {
      ...accounts.ownerTokenRecord,
      ...await resolvers.resolveOwnerTokenRecordFromTokenStandard(resolverScope)
    };
  }
  if (!accounts.listTokenRecord.value) {
    accounts.listTokenRecord = {
      ...accounts.listTokenRecord,
      ...await resolvers.resolveListTokenRecordFromTokenStandard(resolverScope)
    };
  }
  if (!accounts.authorizationRulesProgram.value) {
    accounts.authorizationRulesProgram = {
      ...accounts.authorizationRulesProgram,
      ...resolvers.resolveAuthorizationRulesProgramFromTokenStandard(resolverScope)
    };
  }
  if (!accounts.tokenMetadataProgram.value) {
    accounts.tokenMetadataProgram = {
      ...accounts.tokenMetadataProgram,
      ...resolvers.resolveTokenMetadataProgramFromTokenStandard(resolverScope)
    };
  }
  if (!accounts.sysvarInstructions.value) {
    accounts.sysvarInstructions = {
      ...accounts.sysvarInstructions,
      ...resolvers.resolveSysvarInstructionsFromTokenStandard(resolverScope)
    };
  }
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.owner),
      getAccountMeta(accounts.ownerTa),
      getAccountMeta(accounts.listState),
      getAccountMeta(accounts.listTa),
      getAccountMeta(accounts.mint),
      getAccountMeta(accounts.payer),
      getAccountMeta(accounts.rentDestination),
      getAccountMeta(accounts.tokenProgram),
      getAccountMeta(accounts.associatedTokenProgram),
      getAccountMeta(accounts.systemProgram),
      getAccountMeta(accounts.marketplaceProgram),
      getAccountMeta(accounts.metadata),
      getAccountMeta(accounts.edition),
      getAccountMeta(accounts.ownerTokenRecord),
      getAccountMeta(accounts.listTokenRecord),
      getAccountMeta(accounts.authorizationRules),
      getAccountMeta(accounts.authorizationRulesProgram),
      getAccountMeta(accounts.tokenMetadataProgram),
      getAccountMeta(accounts.sysvarInstructions)
    ],
    programAddress,
    data: getCloseExpiredListingLegacyInstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function getCloseExpiredListingLegacyInstruction(input) {
  const programAddress = TENSOR_MARKETPLACE_PROGRAM_ADDRESS;
  const originalAccounts = {
    owner: { value: input.owner ?? null, isWritable: false },
    ownerTa: { value: input.ownerTa ?? null, isWritable: true },
    listState: { value: input.listState ?? null, isWritable: true },
    listTa: { value: input.listTa ?? null, isWritable: true },
    mint: { value: input.mint ?? null, isWritable: false },
    payer: { value: input.payer ?? null, isWritable: true },
    rentDestination: { value: input.rentDestination ?? null, isWritable: true },
    tokenProgram: { value: input.tokenProgram ?? null, isWritable: false },
    associatedTokenProgram: {
      value: input.associatedTokenProgram ?? null,
      isWritable: false
    },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false },
    marketplaceProgram: {
      value: input.marketplaceProgram ?? null,
      isWritable: false
    },
    metadata: { value: input.metadata ?? null, isWritable: true },
    edition: { value: input.edition ?? null, isWritable: false },
    ownerTokenRecord: {
      value: input.ownerTokenRecord ?? null,
      isWritable: true
    },
    listTokenRecord: { value: input.listTokenRecord ?? null, isWritable: true },
    authorizationRules: {
      value: input.authorizationRules ?? null,
      isWritable: false
    },
    authorizationRulesProgram: {
      value: input.authorizationRulesProgram ?? null,
      isWritable: false
    },
    tokenMetadataProgram: {
      value: input.tokenMetadataProgram ?? null,
      isWritable: false
    },
    sysvarInstructions: {
      value: input.sysvarInstructions ?? null,
      isWritable: false
    }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  const resolverScope = { programAddress, accounts, args };
  if (!accounts.owner.value) {
    accounts.owner.value = expectTransactionSigner(
      accounts.payer.value
    ).address;
  }
  if (!accounts.tokenProgram.value) {
    accounts.tokenProgram.value = "TokenkegQfeZyiNwAJbNbGKPFXCWuBvf9Ss623VQ5DA";
  }
  if (!accounts.rentDestination.value) {
    accounts.rentDestination.value = expectSome(accounts.owner.value);
  }
  if (!accounts.associatedTokenProgram.value) {
    accounts.associatedTokenProgram.value = "ATokenGPvbdGVxr1b2hvZbsiqW5xWH25efTNsLJA8knL";
  }
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  if (!accounts.marketplaceProgram.value) {
    accounts.marketplaceProgram.value = "TCMPhJdwDryooaGtiocG1u3xcYbRpiJzb283XfCZsDp";
  }
  if (!args.tokenStandard) {
    args.tokenStandard = resolvers.TokenStandard.ProgrammableNonFungible;
  }
  if (!accounts.authorizationRulesProgram.value) {
    accounts.authorizationRulesProgram = {
      ...accounts.authorizationRulesProgram,
      ...resolvers.resolveAuthorizationRulesProgramFromTokenStandard(resolverScope)
    };
  }
  if (!accounts.tokenMetadataProgram.value) {
    accounts.tokenMetadataProgram = {
      ...accounts.tokenMetadataProgram,
      ...resolvers.resolveTokenMetadataProgramFromTokenStandard(resolverScope)
    };
  }
  if (!accounts.sysvarInstructions.value) {
    accounts.sysvarInstructions = {
      ...accounts.sysvarInstructions,
      ...resolvers.resolveSysvarInstructionsFromTokenStandard(resolverScope)
    };
  }
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.owner),
      getAccountMeta(accounts.ownerTa),
      getAccountMeta(accounts.listState),
      getAccountMeta(accounts.listTa),
      getAccountMeta(accounts.mint),
      getAccountMeta(accounts.payer),
      getAccountMeta(accounts.rentDestination),
      getAccountMeta(accounts.tokenProgram),
      getAccountMeta(accounts.associatedTokenProgram),
      getAccountMeta(accounts.systemProgram),
      getAccountMeta(accounts.marketplaceProgram),
      getAccountMeta(accounts.metadata),
      getAccountMeta(accounts.edition),
      getAccountMeta(accounts.ownerTokenRecord),
      getAccountMeta(accounts.listTokenRecord),
      getAccountMeta(accounts.authorizationRules),
      getAccountMeta(accounts.authorizationRulesProgram),
      getAccountMeta(accounts.tokenMetadataProgram),
      getAccountMeta(accounts.sysvarInstructions)
    ],
    programAddress,
    data: getCloseExpiredListingLegacyInstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function parseCloseExpiredListingLegacyInstruction(instruction) {
  if (instruction.accounts.length < 19) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  const getNextOptionalAccount = () => {
    const accountMeta = getNextAccount();
    return accountMeta.address === TENSOR_MARKETPLACE_PROGRAM_ADDRESS ? void 0 : accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      owner: getNextAccount(),
      ownerTa: getNextAccount(),
      listState: getNextAccount(),
      listTa: getNextAccount(),
      mint: getNextAccount(),
      payer: getNextAccount(),
      rentDestination: getNextAccount(),
      tokenProgram: getNextAccount(),
      associatedTokenProgram: getNextAccount(),
      systemProgram: getNextAccount(),
      marketplaceProgram: getNextAccount(),
      metadata: getNextAccount(),
      edition: getNextAccount(),
      ownerTokenRecord: getNextOptionalAccount(),
      listTokenRecord: getNextOptionalAccount(),
      authorizationRules: getNextOptionalAccount(),
      authorizationRulesProgram: getNextOptionalAccount(),
      tokenMetadataProgram: getNextOptionalAccount(),
      sysvarInstructions: getNextOptionalAccount()
    },
    data: getCloseExpiredListingLegacyInstructionDataDecoder().decode(
      instruction.data
    )
  };
}
function getCloseExpiredListingT22InstructionDataEncoder() {
  return web3_js.transformEncoder(
    web3_js.getStructEncoder([["discriminator", web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 8)]]),
    (value) => ({
      ...value,
      discriminator: new Uint8Array([69, 2, 190, 122, 144, 119, 122, 220])
    })
  );
}
function getCloseExpiredListingT22InstructionDataDecoder() {
  return web3_js.getStructDecoder([
    ["discriminator", web3_js.fixDecoderSize(web3_js.getBytesDecoder(), 8)]
  ]);
}
function getCloseExpiredListingT22InstructionDataCodec() {
  return web3_js.combineCodec(
    getCloseExpiredListingT22InstructionDataEncoder(),
    getCloseExpiredListingT22InstructionDataDecoder()
  );
}
async function getCloseExpiredListingT22InstructionAsync(input) {
  const programAddress = TENSOR_MARKETPLACE_PROGRAM_ADDRESS;
  const originalAccounts = {
    owner: { value: input.owner ?? null, isWritable: false },
    ownerTa: { value: input.ownerTa ?? null, isWritable: true },
    listState: { value: input.listState ?? null, isWritable: true },
    listTa: { value: input.listTa ?? null, isWritable: true },
    mint: { value: input.mint ?? null, isWritable: false },
    rentDestination: { value: input.rentDestination ?? null, isWritable: true },
    payer: { value: input.payer ?? null, isWritable: true },
    tokenProgram: { value: input.tokenProgram ?? null, isWritable: false },
    associatedTokenProgram: {
      value: input.associatedTokenProgram ?? null,
      isWritable: false
    },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false },
    marketplaceProgram: {
      value: input.marketplaceProgram ?? null,
      isWritable: false
    }
  };
  const accounts = originalAccounts;
  const resolverScope = { programAddress, accounts };
  if (!accounts.owner.value) {
    accounts.owner.value = expectTransactionSigner(
      accounts.payer.value
    ).address;
  }
  if (!accounts.tokenProgram.value) {
    accounts.tokenProgram.value = "TokenkegQfeZyiNwAJbNbGKPFXCWuBvf9Ss623VQ5DA";
  }
  if (!accounts.ownerTa.value) {
    accounts.ownerTa = {
      ...accounts.ownerTa,
      ...await resolvers.resolveOwnerAta(resolverScope)
    };
  }
  if (!accounts.listState.value) {
    accounts.listState.value = await findListStatePda({
      mint: expectAddress(accounts.mint.value)
    });
  }
  if (!accounts.listTa.value) {
    accounts.listTa = {
      ...accounts.listTa,
      ...await resolvers.resolveListAta(resolverScope)
    };
  }
  if (!accounts.rentDestination.value) {
    accounts.rentDestination.value = expectSome(accounts.owner.value);
  }
  if (!accounts.associatedTokenProgram.value) {
    accounts.associatedTokenProgram.value = "ATokenGPvbdGVxr1b2hvZbsiqW5xWH25efTNsLJA8knL";
  }
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  if (!accounts.marketplaceProgram.value) {
    accounts.marketplaceProgram.value = "TCMPhJdwDryooaGtiocG1u3xcYbRpiJzb283XfCZsDp";
  }
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.owner),
      getAccountMeta(accounts.ownerTa),
      getAccountMeta(accounts.listState),
      getAccountMeta(accounts.listTa),
      getAccountMeta(accounts.mint),
      getAccountMeta(accounts.rentDestination),
      getAccountMeta(accounts.payer),
      getAccountMeta(accounts.tokenProgram),
      getAccountMeta(accounts.associatedTokenProgram),
      getAccountMeta(accounts.systemProgram),
      getAccountMeta(accounts.marketplaceProgram)
    ],
    programAddress,
    data: getCloseExpiredListingT22InstructionDataEncoder().encode({})
  };
  return instruction;
}
function getCloseExpiredListingT22Instruction(input) {
  const programAddress = TENSOR_MARKETPLACE_PROGRAM_ADDRESS;
  const originalAccounts = {
    owner: { value: input.owner ?? null, isWritable: false },
    ownerTa: { value: input.ownerTa ?? null, isWritable: true },
    listState: { value: input.listState ?? null, isWritable: true },
    listTa: { value: input.listTa ?? null, isWritable: true },
    mint: { value: input.mint ?? null, isWritable: false },
    rentDestination: { value: input.rentDestination ?? null, isWritable: true },
    payer: { value: input.payer ?? null, isWritable: true },
    tokenProgram: { value: input.tokenProgram ?? null, isWritable: false },
    associatedTokenProgram: {
      value: input.associatedTokenProgram ?? null,
      isWritable: false
    },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false },
    marketplaceProgram: {
      value: input.marketplaceProgram ?? null,
      isWritable: false
    }
  };
  const accounts = originalAccounts;
  if (!accounts.owner.value) {
    accounts.owner.value = expectTransactionSigner(
      accounts.payer.value
    ).address;
  }
  if (!accounts.tokenProgram.value) {
    accounts.tokenProgram.value = "TokenkegQfeZyiNwAJbNbGKPFXCWuBvf9Ss623VQ5DA";
  }
  if (!accounts.rentDestination.value) {
    accounts.rentDestination.value = expectSome(accounts.owner.value);
  }
  if (!accounts.associatedTokenProgram.value) {
    accounts.associatedTokenProgram.value = "ATokenGPvbdGVxr1b2hvZbsiqW5xWH25efTNsLJA8knL";
  }
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  if (!accounts.marketplaceProgram.value) {
    accounts.marketplaceProgram.value = "TCMPhJdwDryooaGtiocG1u3xcYbRpiJzb283XfCZsDp";
  }
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.owner),
      getAccountMeta(accounts.ownerTa),
      getAccountMeta(accounts.listState),
      getAccountMeta(accounts.listTa),
      getAccountMeta(accounts.mint),
      getAccountMeta(accounts.rentDestination),
      getAccountMeta(accounts.payer),
      getAccountMeta(accounts.tokenProgram),
      getAccountMeta(accounts.associatedTokenProgram),
      getAccountMeta(accounts.systemProgram),
      getAccountMeta(accounts.marketplaceProgram)
    ],
    programAddress,
    data: getCloseExpiredListingT22InstructionDataEncoder().encode({})
  };
  return instruction;
}
function parseCloseExpiredListingT22Instruction(instruction) {
  if (instruction.accounts.length < 11) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      owner: getNextAccount(),
      ownerTa: getNextAccount(),
      listState: getNextAccount(),
      listTa: getNextAccount(),
      mint: getNextAccount(),
      rentDestination: getNextAccount(),
      payer: getNextAccount(),
      tokenProgram: getNextAccount(),
      associatedTokenProgram: getNextAccount(),
      systemProgram: getNextAccount(),
      marketplaceProgram: getNextAccount()
    },
    data: getCloseExpiredListingT22InstructionDataDecoder().decode(
      instruction.data
    )
  };
}
function getCloseExpiredListingWnsInstructionDataEncoder() {
  return web3_js.transformEncoder(
    web3_js.getStructEncoder([["discriminator", web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 8)]]),
    (value) => ({
      ...value,
      discriminator: new Uint8Array([222, 31, 183, 134, 230, 207, 7, 132])
    })
  );
}
function getCloseExpiredListingWnsInstructionDataDecoder() {
  return web3_js.getStructDecoder([
    ["discriminator", web3_js.fixDecoderSize(web3_js.getBytesDecoder(), 8)]
  ]);
}
function getCloseExpiredListingWnsInstructionDataCodec() {
  return web3_js.combineCodec(
    getCloseExpiredListingWnsInstructionDataEncoder(),
    getCloseExpiredListingWnsInstructionDataDecoder()
  );
}
async function getCloseExpiredListingWnsInstructionAsync(input) {
  const programAddress = TENSOR_MARKETPLACE_PROGRAM_ADDRESS;
  const originalAccounts = {
    owner: { value: input.owner ?? null, isWritable: false },
    ownerTa: { value: input.ownerTa ?? null, isWritable: true },
    listState: { value: input.listState ?? null, isWritable: true },
    listTa: { value: input.listTa ?? null, isWritable: true },
    mint: { value: input.mint ?? null, isWritable: false },
    rentDestination: { value: input.rentDestination ?? null, isWritable: true },
    payer: { value: input.payer ?? null, isWritable: true },
    tokenProgram: { value: input.tokenProgram ?? null, isWritable: false },
    associatedTokenProgram: {
      value: input.associatedTokenProgram ?? null,
      isWritable: false
    },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false },
    marketplaceProgram: {
      value: input.marketplaceProgram ?? null,
      isWritable: false
    },
    approve: { value: input.approve ?? null, isWritable: true },
    distribution: { value: input.distribution ?? null, isWritable: true },
    wnsProgram: { value: input.wnsProgram ?? null, isWritable: false },
    wnsDistributionProgram: {
      value: input.wnsDistributionProgram ?? null,
      isWritable: false
    },
    extraMetas: { value: input.extraMetas ?? null, isWritable: false }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  const resolverScope = { programAddress, accounts, args };
  if (!accounts.owner.value) {
    accounts.owner.value = expectTransactionSigner(
      accounts.payer.value
    ).address;
  }
  if (!accounts.tokenProgram.value) {
    accounts.tokenProgram.value = "TokenkegQfeZyiNwAJbNbGKPFXCWuBvf9Ss623VQ5DA";
  }
  if (!accounts.ownerTa.value) {
    accounts.ownerTa = {
      ...accounts.ownerTa,
      ...await resolvers.resolveOwnerAta(resolverScope)
    };
  }
  if (!accounts.listState.value) {
    accounts.listState.value = await findListStatePda({
      mint: expectAddress(accounts.mint.value)
    });
  }
  if (!accounts.listTa.value) {
    accounts.listTa = {
      ...accounts.listTa,
      ...await resolvers.resolveListAta(resolverScope)
    };
  }
  if (!accounts.rentDestination.value) {
    accounts.rentDestination.value = expectSome(accounts.owner.value);
  }
  if (!accounts.associatedTokenProgram.value) {
    accounts.associatedTokenProgram.value = "ATokenGPvbdGVxr1b2hvZbsiqW5xWH25efTNsLJA8knL";
  }
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  if (!accounts.marketplaceProgram.value) {
    accounts.marketplaceProgram.value = "TCMPhJdwDryooaGtiocG1u3xcYbRpiJzb283XfCZsDp";
  }
  if (!accounts.approve.value) {
    accounts.approve = {
      ...accounts.approve,
      ...await resolvers.resolveWnsApprovePda(resolverScope)
    };
  }
  if (!args.paymentMint) {
    args.paymentMint = "11111111111111111111111111111111";
  }
  if (!accounts.distribution.value) {
    accounts.distribution = {
      ...accounts.distribution,
      ...await resolvers.resolveWnsDistributionPda(resolverScope)
    };
  }
  if (!accounts.wnsProgram.value) {
    accounts.wnsProgram.value = "wns1gDLt8fgLcGhWi5MqAqgXpwEP1JftKE9eZnXS1HM";
  }
  if (!accounts.wnsDistributionProgram.value) {
    accounts.wnsDistributionProgram.value = "diste3nXmK7ddDTs1zb6uday6j4etCa9RChD8fJ1xay";
  }
  if (!accounts.extraMetas.value) {
    accounts.extraMetas = {
      ...accounts.extraMetas,
      ...await resolvers.resolveWnsExtraAccountMetasPda(resolverScope)
    };
  }
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.owner),
      getAccountMeta(accounts.ownerTa),
      getAccountMeta(accounts.listState),
      getAccountMeta(accounts.listTa),
      getAccountMeta(accounts.mint),
      getAccountMeta(accounts.rentDestination),
      getAccountMeta(accounts.payer),
      getAccountMeta(accounts.tokenProgram),
      getAccountMeta(accounts.associatedTokenProgram),
      getAccountMeta(accounts.systemProgram),
      getAccountMeta(accounts.marketplaceProgram),
      getAccountMeta(accounts.approve),
      getAccountMeta(accounts.distribution),
      getAccountMeta(accounts.wnsProgram),
      getAccountMeta(accounts.wnsDistributionProgram),
      getAccountMeta(accounts.extraMetas)
    ],
    programAddress,
    data: getCloseExpiredListingWnsInstructionDataEncoder().encode({})
  };
  return instruction;
}
function getCloseExpiredListingWnsInstruction(input) {
  const programAddress = TENSOR_MARKETPLACE_PROGRAM_ADDRESS;
  const originalAccounts = {
    owner: { value: input.owner ?? null, isWritable: false },
    ownerTa: { value: input.ownerTa ?? null, isWritable: true },
    listState: { value: input.listState ?? null, isWritable: true },
    listTa: { value: input.listTa ?? null, isWritable: true },
    mint: { value: input.mint ?? null, isWritable: false },
    rentDestination: { value: input.rentDestination ?? null, isWritable: true },
    payer: { value: input.payer ?? null, isWritable: true },
    tokenProgram: { value: input.tokenProgram ?? null, isWritable: false },
    associatedTokenProgram: {
      value: input.associatedTokenProgram ?? null,
      isWritable: false
    },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false },
    marketplaceProgram: {
      value: input.marketplaceProgram ?? null,
      isWritable: false
    },
    approve: { value: input.approve ?? null, isWritable: true },
    distribution: { value: input.distribution ?? null, isWritable: true },
    wnsProgram: { value: input.wnsProgram ?? null, isWritable: false },
    wnsDistributionProgram: {
      value: input.wnsDistributionProgram ?? null,
      isWritable: false
    },
    extraMetas: { value: input.extraMetas ?? null, isWritable: false }
  };
  const accounts = originalAccounts;
  ({ ...input });
  if (!accounts.owner.value) {
    accounts.owner.value = expectTransactionSigner(
      accounts.payer.value
    ).address;
  }
  if (!accounts.tokenProgram.value) {
    accounts.tokenProgram.value = "TokenkegQfeZyiNwAJbNbGKPFXCWuBvf9Ss623VQ5DA";
  }
  if (!accounts.rentDestination.value) {
    accounts.rentDestination.value = expectSome(accounts.owner.value);
  }
  if (!accounts.associatedTokenProgram.value) {
    accounts.associatedTokenProgram.value = "ATokenGPvbdGVxr1b2hvZbsiqW5xWH25efTNsLJA8knL";
  }
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  if (!accounts.marketplaceProgram.value) {
    accounts.marketplaceProgram.value = "TCMPhJdwDryooaGtiocG1u3xcYbRpiJzb283XfCZsDp";
  }
  if (!accounts.wnsProgram.value) {
    accounts.wnsProgram.value = "wns1gDLt8fgLcGhWi5MqAqgXpwEP1JftKE9eZnXS1HM";
  }
  if (!accounts.wnsDistributionProgram.value) {
    accounts.wnsDistributionProgram.value = "diste3nXmK7ddDTs1zb6uday6j4etCa9RChD8fJ1xay";
  }
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.owner),
      getAccountMeta(accounts.ownerTa),
      getAccountMeta(accounts.listState),
      getAccountMeta(accounts.listTa),
      getAccountMeta(accounts.mint),
      getAccountMeta(accounts.rentDestination),
      getAccountMeta(accounts.payer),
      getAccountMeta(accounts.tokenProgram),
      getAccountMeta(accounts.associatedTokenProgram),
      getAccountMeta(accounts.systemProgram),
      getAccountMeta(accounts.marketplaceProgram),
      getAccountMeta(accounts.approve),
      getAccountMeta(accounts.distribution),
      getAccountMeta(accounts.wnsProgram),
      getAccountMeta(accounts.wnsDistributionProgram),
      getAccountMeta(accounts.extraMetas)
    ],
    programAddress,
    data: getCloseExpiredListingWnsInstructionDataEncoder().encode({})
  };
  return instruction;
}
function parseCloseExpiredListingWnsInstruction(instruction) {
  if (instruction.accounts.length < 16) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      owner: getNextAccount(),
      ownerTa: getNextAccount(),
      listState: getNextAccount(),
      listTa: getNextAccount(),
      mint: getNextAccount(),
      rentDestination: getNextAccount(),
      payer: getNextAccount(),
      tokenProgram: getNextAccount(),
      associatedTokenProgram: getNextAccount(),
      systemProgram: getNextAccount(),
      marketplaceProgram: getNextAccount(),
      approve: getNextAccount(),
      distribution: getNextAccount(),
      wnsProgram: getNextAccount(),
      wnsDistributionProgram: getNextAccount(),
      extraMetas: getNextAccount()
    },
    data: getCloseExpiredListingWnsInstructionDataDecoder().decode(
      instruction.data
    )
  };
}
function getDelistCompressedInstructionDataEncoder() {
  return web3_js.transformEncoder(
    web3_js.getStructEncoder([
      ["discriminator", web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 8)],
      ["nonce", web3_js.getU64Encoder()],
      ["index", web3_js.getU32Encoder()],
      ["root", web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 32)],
      ["dataHash", web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 32)],
      ["creatorHash", web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 32)]
    ]),
    (value) => ({
      ...value,
      discriminator: new Uint8Array([55, 136, 205, 107, 107, 173, 4, 31])
    })
  );
}
function getDelistCompressedInstructionDataDecoder() {
  return web3_js.getStructDecoder([
    ["discriminator", web3_js.fixDecoderSize(web3_js.getBytesDecoder(), 8)],
    ["nonce", web3_js.getU64Decoder()],
    ["index", web3_js.getU32Decoder()],
    ["root", web3_js.fixDecoderSize(web3_js.getBytesDecoder(), 32)],
    ["dataHash", web3_js.fixDecoderSize(web3_js.getBytesDecoder(), 32)],
    ["creatorHash", web3_js.fixDecoderSize(web3_js.getBytesDecoder(), 32)]
  ]);
}
function getDelistCompressedInstructionDataCodec() {
  return web3_js.combineCodec(
    getDelistCompressedInstructionDataEncoder(),
    getDelistCompressedInstructionDataDecoder()
  );
}
async function getDelistCompressedInstructionAsync(input) {
  const programAddress = TENSOR_MARKETPLACE_PROGRAM_ADDRESS;
  const originalAccounts = {
    treeAuthority: { value: input.treeAuthority ?? null, isWritable: false },
    merkleTree: { value: input.merkleTree ?? null, isWritable: true },
    logWrapper: { value: input.logWrapper ?? null, isWritable: false },
    compressionProgram: {
      value: input.compressionProgram ?? null,
      isWritable: false
    },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false },
    bubblegumProgram: {
      value: input.bubblegumProgram ?? null,
      isWritable: false
    },
    listState: { value: input.listState ?? null, isWritable: true },
    owner: { value: input.owner ?? null, isWritable: false },
    marketplaceProgram: {
      value: input.marketplaceProgram ?? null,
      isWritable: false
    },
    rentDestination: { value: input.rentDestination ?? null, isWritable: true }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  const resolverScope = { programAddress, accounts, args };
  if (!accounts.bubblegumProgram.value) {
    accounts.bubblegumProgram.value = "BGUMAp9Gq7iTEuizy4pqaxsTyUCBK68MDfK752saRPUY";
  }
  if (!accounts.treeAuthority.value) {
    accounts.treeAuthority = {
      ...accounts.treeAuthority,
      ...await resolveTreeAuthorityPda(resolverScope)
    };
  }
  if (!accounts.logWrapper.value) {
    accounts.logWrapper.value = "noopb9bkMVfRPU8AsbpTUg8AQkHtKwMYZiFUjNRtMmV";
  }
  if (!accounts.compressionProgram.value) {
    accounts.compressionProgram.value = "cmtDvXumGCrqC1Age74AVPhSRVXJMd8PJS91L8KbNCK";
  }
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  if (!accounts.marketplaceProgram.value) {
    accounts.marketplaceProgram.value = "TCMPhJdwDryooaGtiocG1u3xcYbRpiJzb283XfCZsDp";
  }
  if (!accounts.rentDestination.value) {
    accounts.rentDestination.value = expectTransactionSigner(
      accounts.owner.value
    ).address;
  }
  if (!args.nonce) {
    args.nonce = expectSome(args.index);
  }
  if (!args.proof) {
    args.proof = [];
  }
  if (!args.canopyDepth) {
    args.canopyDepth = 0;
  }
  const remainingAccounts = resolveProofPath(resolverScope);
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.treeAuthority),
      getAccountMeta(accounts.merkleTree),
      getAccountMeta(accounts.logWrapper),
      getAccountMeta(accounts.compressionProgram),
      getAccountMeta(accounts.systemProgram),
      getAccountMeta(accounts.bubblegumProgram),
      getAccountMeta(accounts.listState),
      getAccountMeta(accounts.owner),
      getAccountMeta(accounts.marketplaceProgram),
      getAccountMeta(accounts.rentDestination),
      ...remainingAccounts
    ],
    programAddress,
    data: getDelistCompressedInstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function getDelistCompressedInstruction(input) {
  const programAddress = TENSOR_MARKETPLACE_PROGRAM_ADDRESS;
  const originalAccounts = {
    treeAuthority: { value: input.treeAuthority ?? null, isWritable: false },
    merkleTree: { value: input.merkleTree ?? null, isWritable: true },
    logWrapper: { value: input.logWrapper ?? null, isWritable: false },
    compressionProgram: {
      value: input.compressionProgram ?? null,
      isWritable: false
    },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false },
    bubblegumProgram: {
      value: input.bubblegumProgram ?? null,
      isWritable: false
    },
    listState: { value: input.listState ?? null, isWritable: true },
    owner: { value: input.owner ?? null, isWritable: false },
    marketplaceProgram: {
      value: input.marketplaceProgram ?? null,
      isWritable: false
    },
    rentDestination: { value: input.rentDestination ?? null, isWritable: true }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  const resolverScope = { programAddress, accounts, args };
  if (!accounts.bubblegumProgram.value) {
    accounts.bubblegumProgram.value = "BGUMAp9Gq7iTEuizy4pqaxsTyUCBK68MDfK752saRPUY";
  }
  if (!accounts.logWrapper.value) {
    accounts.logWrapper.value = "noopb9bkMVfRPU8AsbpTUg8AQkHtKwMYZiFUjNRtMmV";
  }
  if (!accounts.compressionProgram.value) {
    accounts.compressionProgram.value = "cmtDvXumGCrqC1Age74AVPhSRVXJMd8PJS91L8KbNCK";
  }
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  if (!accounts.marketplaceProgram.value) {
    accounts.marketplaceProgram.value = "TCMPhJdwDryooaGtiocG1u3xcYbRpiJzb283XfCZsDp";
  }
  if (!accounts.rentDestination.value) {
    accounts.rentDestination.value = expectTransactionSigner(
      accounts.owner.value
    ).address;
  }
  if (!args.nonce) {
    args.nonce = expectSome(args.index);
  }
  if (!args.proof) {
    args.proof = [];
  }
  if (!args.canopyDepth) {
    args.canopyDepth = 0;
  }
  const remainingAccounts = resolveProofPath(resolverScope);
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.treeAuthority),
      getAccountMeta(accounts.merkleTree),
      getAccountMeta(accounts.logWrapper),
      getAccountMeta(accounts.compressionProgram),
      getAccountMeta(accounts.systemProgram),
      getAccountMeta(accounts.bubblegumProgram),
      getAccountMeta(accounts.listState),
      getAccountMeta(accounts.owner),
      getAccountMeta(accounts.marketplaceProgram),
      getAccountMeta(accounts.rentDestination),
      ...remainingAccounts
    ],
    programAddress,
    data: getDelistCompressedInstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function parseDelistCompressedInstruction(instruction) {
  if (instruction.accounts.length < 10) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      treeAuthority: getNextAccount(),
      merkleTree: getNextAccount(),
      logWrapper: getNextAccount(),
      compressionProgram: getNextAccount(),
      systemProgram: getNextAccount(),
      bubblegumProgram: getNextAccount(),
      listState: getNextAccount(),
      owner: getNextAccount(),
      marketplaceProgram: getNextAccount(),
      rentDestination: getNextAccount()
    },
    data: getDelistCompressedInstructionDataDecoder().decode(instruction.data)
  };
}
function getDelistCoreInstructionDataEncoder() {
  return web3_js.transformEncoder(
    web3_js.getStructEncoder([["discriminator", web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 8)]]),
    (value) => ({
      ...value,
      discriminator: new Uint8Array([56, 24, 231, 2, 227, 19, 14, 68])
    })
  );
}
function getDelistCoreInstructionDataDecoder() {
  return web3_js.getStructDecoder([
    ["discriminator", web3_js.fixDecoderSize(web3_js.getBytesDecoder(), 8)]
  ]);
}
function getDelistCoreInstructionDataCodec() {
  return web3_js.combineCodec(
    getDelistCoreInstructionDataEncoder(),
    getDelistCoreInstructionDataDecoder()
  );
}
function getDelistCoreInstruction(input) {
  const programAddress = TENSOR_MARKETPLACE_PROGRAM_ADDRESS;
  const originalAccounts = {
    asset: { value: input.asset ?? null, isWritable: true },
    collection: { value: input.collection ?? null, isWritable: false },
    owner: { value: input.owner ?? null, isWritable: true },
    listState: { value: input.listState ?? null, isWritable: true },
    mplCoreProgram: { value: input.mplCoreProgram ?? null, isWritable: false },
    marketplaceProgram: {
      value: input.marketplaceProgram ?? null,
      isWritable: false
    },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false },
    rentDestination: { value: input.rentDestination ?? null, isWritable: true }
  };
  const accounts = originalAccounts;
  if (!accounts.mplCoreProgram.value) {
    accounts.mplCoreProgram.value = "CoREENxT6tW1HoK8ypY1SxRMZTcVPm7R94rH4PZNhX7d";
  }
  if (!accounts.marketplaceProgram.value) {
    accounts.marketplaceProgram.value = "TCMPhJdwDryooaGtiocG1u3xcYbRpiJzb283XfCZsDp";
  }
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.asset),
      getAccountMeta(accounts.collection),
      getAccountMeta(accounts.owner),
      getAccountMeta(accounts.listState),
      getAccountMeta(accounts.mplCoreProgram),
      getAccountMeta(accounts.marketplaceProgram),
      getAccountMeta(accounts.systemProgram),
      getAccountMeta(accounts.rentDestination)
    ],
    programAddress,
    data: getDelistCoreInstructionDataEncoder().encode({})
  };
  return instruction;
}
function parseDelistCoreInstruction(instruction) {
  if (instruction.accounts.length < 8) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  const getNextOptionalAccount = () => {
    const accountMeta = getNextAccount();
    return accountMeta.address === TENSOR_MARKETPLACE_PROGRAM_ADDRESS ? void 0 : accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      asset: getNextAccount(),
      collection: getNextOptionalAccount(),
      owner: getNextAccount(),
      listState: getNextAccount(),
      mplCoreProgram: getNextAccount(),
      marketplaceProgram: getNextAccount(),
      systemProgram: getNextAccount(),
      rentDestination: getNextAccount()
    },
    data: getDelistCoreInstructionDataDecoder().decode(instruction.data)
  };
}
function getDelistLegacyInstructionDataEncoder() {
  return web3_js.transformEncoder(
    web3_js.getStructEncoder([
      ["discriminator", web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 8)],
      [
        "authorizationData",
        web3_js.getOptionEncoder(getAuthorizationDataLocalEncoder())
      ]
    ]),
    (value) => ({
      ...value,
      discriminator: new Uint8Array([88, 35, 231, 184, 110, 218, 149, 23]),
      authorizationData: value.authorizationData ?? web3_js.none()
    })
  );
}
function getDelistLegacyInstructionDataDecoder() {
  return web3_js.getStructDecoder([
    ["discriminator", web3_js.fixDecoderSize(web3_js.getBytesDecoder(), 8)],
    ["authorizationData", web3_js.getOptionDecoder(getAuthorizationDataLocalDecoder())]
  ]);
}
function getDelistLegacyInstructionDataCodec() {
  return web3_js.combineCodec(
    getDelistLegacyInstructionDataEncoder(),
    getDelistLegacyInstructionDataDecoder()
  );
}
async function getDelistLegacyInstructionAsync(input) {
  const programAddress = TENSOR_MARKETPLACE_PROGRAM_ADDRESS;
  const originalAccounts = {
    owner: { value: input.owner ?? null, isWritable: true },
    ownerTa: { value: input.ownerTa ?? null, isWritable: true },
    listState: { value: input.listState ?? null, isWritable: true },
    listTa: { value: input.listTa ?? null, isWritable: true },
    mint: { value: input.mint ?? null, isWritable: false },
    rentDestination: { value: input.rentDestination ?? null, isWritable: true },
    payer: { value: input.payer ?? null, isWritable: true },
    tokenProgram: { value: input.tokenProgram ?? null, isWritable: false },
    associatedTokenProgram: {
      value: input.associatedTokenProgram ?? null,
      isWritable: false
    },
    marketplaceProgram: {
      value: input.marketplaceProgram ?? null,
      isWritable: false
    },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false },
    metadata: { value: input.metadata ?? null, isWritable: true },
    edition: { value: input.edition ?? null, isWritable: false },
    ownerTokenRecord: {
      value: input.ownerTokenRecord ?? null,
      isWritable: true
    },
    listTokenRecord: { value: input.listTokenRecord ?? null, isWritable: true },
    authorizationRules: {
      value: input.authorizationRules ?? null,
      isWritable: false
    },
    authorizationRulesProgram: {
      value: input.authorizationRulesProgram ?? null,
      isWritable: false
    },
    tokenMetadataProgram: {
      value: input.tokenMetadataProgram ?? null,
      isWritable: false
    },
    sysvarInstructions: {
      value: input.sysvarInstructions ?? null,
      isWritable: false
    }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  const resolverScope = { programAddress, accounts, args };
  if (!accounts.tokenProgram.value) {
    accounts.tokenProgram.value = "TokenkegQfeZyiNwAJbNbGKPFXCWuBvf9Ss623VQ5DA";
  }
  if (!accounts.ownerTa.value) {
    accounts.ownerTa = {
      ...accounts.ownerTa,
      ...await resolvers.resolveOwnerAta(resolverScope)
    };
  }
  if (!accounts.listState.value) {
    accounts.listState.value = await findListStatePda({
      mint: expectAddress(accounts.mint.value)
    });
  }
  if (!accounts.listTa.value) {
    accounts.listTa = {
      ...accounts.listTa,
      ...await resolvers.resolveListAta(resolverScope)
    };
  }
  if (!accounts.rentDestination.value) {
    accounts.rentDestination.value = expectTransactionSigner(
      accounts.owner.value
    ).address;
  }
  if (!accounts.payer.value) {
    accounts.payer.value = expectSome(accounts.owner.value);
  }
  if (!accounts.associatedTokenProgram.value) {
    accounts.associatedTokenProgram.value = "ATokenGPvbdGVxr1b2hvZbsiqW5xWH25efTNsLJA8knL";
  }
  if (!accounts.marketplaceProgram.value) {
    accounts.marketplaceProgram.value = "TCMPhJdwDryooaGtiocG1u3xcYbRpiJzb283XfCZsDp";
  }
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  if (!accounts.metadata.value) {
    accounts.metadata = {
      ...accounts.metadata,
      ...await resolvers.resolveMetadata(resolverScope)
    };
  }
  if (!args.tokenStandard) {
    args.tokenStandard = resolvers.TokenStandard.ProgrammableNonFungible;
  }
  if (!accounts.edition.value) {
    accounts.edition = {
      ...accounts.edition,
      ...await resolvers.resolveEditionFromTokenStandard(resolverScope)
    };
  }
  if (!accounts.ownerTokenRecord.value) {
    accounts.ownerTokenRecord = {
      ...accounts.ownerTokenRecord,
      ...await resolvers.resolveOwnerTokenRecordFromTokenStandard(resolverScope)
    };
  }
  if (!accounts.listTokenRecord.value) {
    accounts.listTokenRecord = {
      ...accounts.listTokenRecord,
      ...await resolvers.resolveListTokenRecordFromTokenStandard(resolverScope)
    };
  }
  if (!accounts.authorizationRulesProgram.value) {
    accounts.authorizationRulesProgram = {
      ...accounts.authorizationRulesProgram,
      ...resolvers.resolveAuthorizationRulesProgramFromTokenStandard(resolverScope)
    };
  }
  if (!accounts.tokenMetadataProgram.value) {
    accounts.tokenMetadataProgram = {
      ...accounts.tokenMetadataProgram,
      ...resolvers.resolveTokenMetadataProgramFromTokenStandard(resolverScope)
    };
  }
  if (!accounts.sysvarInstructions.value) {
    accounts.sysvarInstructions = {
      ...accounts.sysvarInstructions,
      ...resolvers.resolveSysvarInstructionsFromTokenStandard(resolverScope)
    };
  }
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.owner),
      getAccountMeta(accounts.ownerTa),
      getAccountMeta(accounts.listState),
      getAccountMeta(accounts.listTa),
      getAccountMeta(accounts.mint),
      getAccountMeta(accounts.rentDestination),
      getAccountMeta(accounts.payer),
      getAccountMeta(accounts.tokenProgram),
      getAccountMeta(accounts.associatedTokenProgram),
      getAccountMeta(accounts.marketplaceProgram),
      getAccountMeta(accounts.systemProgram),
      getAccountMeta(accounts.metadata),
      getAccountMeta(accounts.edition),
      getAccountMeta(accounts.ownerTokenRecord),
      getAccountMeta(accounts.listTokenRecord),
      getAccountMeta(accounts.authorizationRules),
      getAccountMeta(accounts.authorizationRulesProgram),
      getAccountMeta(accounts.tokenMetadataProgram),
      getAccountMeta(accounts.sysvarInstructions)
    ],
    programAddress,
    data: getDelistLegacyInstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function getDelistLegacyInstruction(input) {
  const programAddress = TENSOR_MARKETPLACE_PROGRAM_ADDRESS;
  const originalAccounts = {
    owner: { value: input.owner ?? null, isWritable: true },
    ownerTa: { value: input.ownerTa ?? null, isWritable: true },
    listState: { value: input.listState ?? null, isWritable: true },
    listTa: { value: input.listTa ?? null, isWritable: true },
    mint: { value: input.mint ?? null, isWritable: false },
    rentDestination: { value: input.rentDestination ?? null, isWritable: true },
    payer: { value: input.payer ?? null, isWritable: true },
    tokenProgram: { value: input.tokenProgram ?? null, isWritable: false },
    associatedTokenProgram: {
      value: input.associatedTokenProgram ?? null,
      isWritable: false
    },
    marketplaceProgram: {
      value: input.marketplaceProgram ?? null,
      isWritable: false
    },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false },
    metadata: { value: input.metadata ?? null, isWritable: true },
    edition: { value: input.edition ?? null, isWritable: false },
    ownerTokenRecord: {
      value: input.ownerTokenRecord ?? null,
      isWritable: true
    },
    listTokenRecord: { value: input.listTokenRecord ?? null, isWritable: true },
    authorizationRules: {
      value: input.authorizationRules ?? null,
      isWritable: false
    },
    authorizationRulesProgram: {
      value: input.authorizationRulesProgram ?? null,
      isWritable: false
    },
    tokenMetadataProgram: {
      value: input.tokenMetadataProgram ?? null,
      isWritable: false
    },
    sysvarInstructions: {
      value: input.sysvarInstructions ?? null,
      isWritable: false
    }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  const resolverScope = { programAddress, accounts, args };
  if (!accounts.tokenProgram.value) {
    accounts.tokenProgram.value = "TokenkegQfeZyiNwAJbNbGKPFXCWuBvf9Ss623VQ5DA";
  }
  if (!accounts.rentDestination.value) {
    accounts.rentDestination.value = expectTransactionSigner(
      accounts.owner.value
    ).address;
  }
  if (!accounts.payer.value) {
    accounts.payer.value = expectSome(accounts.owner.value);
  }
  if (!accounts.associatedTokenProgram.value) {
    accounts.associatedTokenProgram.value = "ATokenGPvbdGVxr1b2hvZbsiqW5xWH25efTNsLJA8knL";
  }
  if (!accounts.marketplaceProgram.value) {
    accounts.marketplaceProgram.value = "TCMPhJdwDryooaGtiocG1u3xcYbRpiJzb283XfCZsDp";
  }
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  if (!args.tokenStandard) {
    args.tokenStandard = resolvers.TokenStandard.ProgrammableNonFungible;
  }
  if (!accounts.authorizationRulesProgram.value) {
    accounts.authorizationRulesProgram = {
      ...accounts.authorizationRulesProgram,
      ...resolvers.resolveAuthorizationRulesProgramFromTokenStandard(resolverScope)
    };
  }
  if (!accounts.tokenMetadataProgram.value) {
    accounts.tokenMetadataProgram = {
      ...accounts.tokenMetadataProgram,
      ...resolvers.resolveTokenMetadataProgramFromTokenStandard(resolverScope)
    };
  }
  if (!accounts.sysvarInstructions.value) {
    accounts.sysvarInstructions = {
      ...accounts.sysvarInstructions,
      ...resolvers.resolveSysvarInstructionsFromTokenStandard(resolverScope)
    };
  }
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.owner),
      getAccountMeta(accounts.ownerTa),
      getAccountMeta(accounts.listState),
      getAccountMeta(accounts.listTa),
      getAccountMeta(accounts.mint),
      getAccountMeta(accounts.rentDestination),
      getAccountMeta(accounts.payer),
      getAccountMeta(accounts.tokenProgram),
      getAccountMeta(accounts.associatedTokenProgram),
      getAccountMeta(accounts.marketplaceProgram),
      getAccountMeta(accounts.systemProgram),
      getAccountMeta(accounts.metadata),
      getAccountMeta(accounts.edition),
      getAccountMeta(accounts.ownerTokenRecord),
      getAccountMeta(accounts.listTokenRecord),
      getAccountMeta(accounts.authorizationRules),
      getAccountMeta(accounts.authorizationRulesProgram),
      getAccountMeta(accounts.tokenMetadataProgram),
      getAccountMeta(accounts.sysvarInstructions)
    ],
    programAddress,
    data: getDelistLegacyInstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function parseDelistLegacyInstruction(instruction) {
  if (instruction.accounts.length < 19) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  const getNextOptionalAccount = () => {
    const accountMeta = getNextAccount();
    return accountMeta.address === TENSOR_MARKETPLACE_PROGRAM_ADDRESS ? void 0 : accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      owner: getNextAccount(),
      ownerTa: getNextAccount(),
      listState: getNextAccount(),
      listTa: getNextAccount(),
      mint: getNextAccount(),
      rentDestination: getNextAccount(),
      payer: getNextAccount(),
      tokenProgram: getNextAccount(),
      associatedTokenProgram: getNextAccount(),
      marketplaceProgram: getNextAccount(),
      systemProgram: getNextAccount(),
      metadata: getNextAccount(),
      edition: getNextAccount(),
      ownerTokenRecord: getNextOptionalAccount(),
      listTokenRecord: getNextOptionalAccount(),
      authorizationRules: getNextOptionalAccount(),
      authorizationRulesProgram: getNextOptionalAccount(),
      tokenMetadataProgram: getNextOptionalAccount(),
      sysvarInstructions: getNextOptionalAccount()
    },
    data: getDelistLegacyInstructionDataDecoder().decode(instruction.data)
  };
}
function getDelistT22InstructionDataEncoder() {
  return web3_js.transformEncoder(
    web3_js.getStructEncoder([["discriminator", web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 8)]]),
    (value) => ({
      ...value,
      discriminator: new Uint8Array([216, 72, 73, 18, 204, 82, 123, 26])
    })
  );
}
function getDelistT22InstructionDataDecoder() {
  return web3_js.getStructDecoder([
    ["discriminator", web3_js.fixDecoderSize(web3_js.getBytesDecoder(), 8)]
  ]);
}
function getDelistT22InstructionDataCodec() {
  return web3_js.combineCodec(
    getDelistT22InstructionDataEncoder(),
    getDelistT22InstructionDataDecoder()
  );
}
async function getDelistT22InstructionAsync(input) {
  const programAddress = TENSOR_MARKETPLACE_PROGRAM_ADDRESS;
  const originalAccounts = {
    owner: { value: input.owner ?? null, isWritable: true },
    ownerTa: { value: input.ownerTa ?? null, isWritable: true },
    listState: { value: input.listState ?? null, isWritable: true },
    listTa: { value: input.listTa ?? null, isWritable: true },
    mint: { value: input.mint ?? null, isWritable: false },
    rentDestination: { value: input.rentDestination ?? null, isWritable: true },
    payer: { value: input.payer ?? null, isWritable: true },
    tokenProgram: { value: input.tokenProgram ?? null, isWritable: false },
    associatedTokenProgram: {
      value: input.associatedTokenProgram ?? null,
      isWritable: false
    },
    marketplaceProgram: {
      value: input.marketplaceProgram ?? null,
      isWritable: false
    },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false }
  };
  const accounts = originalAccounts;
  const resolverScope = { programAddress, accounts };
  if (!accounts.tokenProgram.value) {
    accounts.tokenProgram.value = "TokenkegQfeZyiNwAJbNbGKPFXCWuBvf9Ss623VQ5DA";
  }
  if (!accounts.ownerTa.value) {
    accounts.ownerTa = {
      ...accounts.ownerTa,
      ...await resolvers.resolveOwnerAta(resolverScope)
    };
  }
  if (!accounts.listState.value) {
    accounts.listState.value = await findListStatePda({
      mint: expectAddress(accounts.mint.value)
    });
  }
  if (!accounts.listTa.value) {
    accounts.listTa = {
      ...accounts.listTa,
      ...await resolvers.resolveListAta(resolverScope)
    };
  }
  if (!accounts.rentDestination.value) {
    accounts.rentDestination.value = expectTransactionSigner(
      accounts.owner.value
    ).address;
  }
  if (!accounts.payer.value) {
    accounts.payer.value = expectSome(accounts.owner.value);
  }
  if (!accounts.associatedTokenProgram.value) {
    accounts.associatedTokenProgram.value = "ATokenGPvbdGVxr1b2hvZbsiqW5xWH25efTNsLJA8knL";
  }
  if (!accounts.marketplaceProgram.value) {
    accounts.marketplaceProgram.value = "TCMPhJdwDryooaGtiocG1u3xcYbRpiJzb283XfCZsDp";
  }
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.owner),
      getAccountMeta(accounts.ownerTa),
      getAccountMeta(accounts.listState),
      getAccountMeta(accounts.listTa),
      getAccountMeta(accounts.mint),
      getAccountMeta(accounts.rentDestination),
      getAccountMeta(accounts.payer),
      getAccountMeta(accounts.tokenProgram),
      getAccountMeta(accounts.associatedTokenProgram),
      getAccountMeta(accounts.marketplaceProgram),
      getAccountMeta(accounts.systemProgram)
    ],
    programAddress,
    data: getDelistT22InstructionDataEncoder().encode({})
  };
  return instruction;
}
function getDelistT22Instruction(input) {
  const programAddress = TENSOR_MARKETPLACE_PROGRAM_ADDRESS;
  const originalAccounts = {
    owner: { value: input.owner ?? null, isWritable: true },
    ownerTa: { value: input.ownerTa ?? null, isWritable: true },
    listState: { value: input.listState ?? null, isWritable: true },
    listTa: { value: input.listTa ?? null, isWritable: true },
    mint: { value: input.mint ?? null, isWritable: false },
    rentDestination: { value: input.rentDestination ?? null, isWritable: true },
    payer: { value: input.payer ?? null, isWritable: true },
    tokenProgram: { value: input.tokenProgram ?? null, isWritable: false },
    associatedTokenProgram: {
      value: input.associatedTokenProgram ?? null,
      isWritable: false
    },
    marketplaceProgram: {
      value: input.marketplaceProgram ?? null,
      isWritable: false
    },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false }
  };
  const accounts = originalAccounts;
  if (!accounts.tokenProgram.value) {
    accounts.tokenProgram.value = "TokenkegQfeZyiNwAJbNbGKPFXCWuBvf9Ss623VQ5DA";
  }
  if (!accounts.rentDestination.value) {
    accounts.rentDestination.value = expectTransactionSigner(
      accounts.owner.value
    ).address;
  }
  if (!accounts.payer.value) {
    accounts.payer.value = expectSome(accounts.owner.value);
  }
  if (!accounts.associatedTokenProgram.value) {
    accounts.associatedTokenProgram.value = "ATokenGPvbdGVxr1b2hvZbsiqW5xWH25efTNsLJA8knL";
  }
  if (!accounts.marketplaceProgram.value) {
    accounts.marketplaceProgram.value = "TCMPhJdwDryooaGtiocG1u3xcYbRpiJzb283XfCZsDp";
  }
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.owner),
      getAccountMeta(accounts.ownerTa),
      getAccountMeta(accounts.listState),
      getAccountMeta(accounts.listTa),
      getAccountMeta(accounts.mint),
      getAccountMeta(accounts.rentDestination),
      getAccountMeta(accounts.payer),
      getAccountMeta(accounts.tokenProgram),
      getAccountMeta(accounts.associatedTokenProgram),
      getAccountMeta(accounts.marketplaceProgram),
      getAccountMeta(accounts.systemProgram)
    ],
    programAddress,
    data: getDelistT22InstructionDataEncoder().encode({})
  };
  return instruction;
}
function parseDelistT22Instruction(instruction) {
  if (instruction.accounts.length < 11) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      owner: getNextAccount(),
      ownerTa: getNextAccount(),
      listState: getNextAccount(),
      listTa: getNextAccount(),
      mint: getNextAccount(),
      rentDestination: getNextAccount(),
      payer: getNextAccount(),
      tokenProgram: getNextAccount(),
      associatedTokenProgram: getNextAccount(),
      marketplaceProgram: getNextAccount(),
      systemProgram: getNextAccount()
    },
    data: getDelistT22InstructionDataDecoder().decode(instruction.data)
  };
}
function getDelistWnsInstructionDataEncoder() {
  return web3_js.transformEncoder(
    web3_js.getStructEncoder([["discriminator", web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 8)]]),
    (value) => ({
      ...value,
      discriminator: new Uint8Array([172, 171, 57, 16, 74, 158, 32, 57])
    })
  );
}
function getDelistWnsInstructionDataDecoder() {
  return web3_js.getStructDecoder([
    ["discriminator", web3_js.fixDecoderSize(web3_js.getBytesDecoder(), 8)]
  ]);
}
function getDelistWnsInstructionDataCodec() {
  return web3_js.combineCodec(
    getDelistWnsInstructionDataEncoder(),
    getDelistWnsInstructionDataDecoder()
  );
}
async function getDelistWnsInstructionAsync(input) {
  const programAddress = TENSOR_MARKETPLACE_PROGRAM_ADDRESS;
  const originalAccounts = {
    owner: { value: input.owner ?? null, isWritable: false },
    ownerTa: { value: input.ownerTa ?? null, isWritable: true },
    listState: { value: input.listState ?? null, isWritable: true },
    listTa: { value: input.listTa ?? null, isWritable: true },
    mint: { value: input.mint ?? null, isWritable: false },
    rentDestination: { value: input.rentDestination ?? null, isWritable: true },
    payer: { value: input.payer ?? null, isWritable: true },
    tokenProgram: { value: input.tokenProgram ?? null, isWritable: false },
    associatedTokenProgram: {
      value: input.associatedTokenProgram ?? null,
      isWritable: false
    },
    marketplaceProgram: {
      value: input.marketplaceProgram ?? null,
      isWritable: false
    },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false },
    approve: { value: input.approve ?? null, isWritable: true },
    distribution: { value: input.distribution ?? null, isWritable: true },
    wnsProgram: { value: input.wnsProgram ?? null, isWritable: false },
    wnsDistributionProgram: {
      value: input.wnsDistributionProgram ?? null,
      isWritable: false
    },
    extraMetas: { value: input.extraMetas ?? null, isWritable: false }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  const resolverScope = { programAddress, accounts, args };
  if (!accounts.tokenProgram.value) {
    accounts.tokenProgram.value = "TokenkegQfeZyiNwAJbNbGKPFXCWuBvf9Ss623VQ5DA";
  }
  if (!accounts.ownerTa.value) {
    accounts.ownerTa = {
      ...accounts.ownerTa,
      ...await resolvers.resolveOwnerAta(resolverScope)
    };
  }
  if (!accounts.listState.value) {
    accounts.listState.value = await findListStatePda({
      mint: expectAddress(accounts.mint.value)
    });
  }
  if (!accounts.listTa.value) {
    accounts.listTa = {
      ...accounts.listTa,
      ...await resolvers.resolveListAta(resolverScope)
    };
  }
  if (!accounts.rentDestination.value) {
    accounts.rentDestination.value = expectSome(accounts.owner.value);
  }
  if (!accounts.payer.value) {
    accounts.payer.value = expectSome(accounts.owner.value);
  }
  if (!accounts.associatedTokenProgram.value) {
    accounts.associatedTokenProgram.value = "ATokenGPvbdGVxr1b2hvZbsiqW5xWH25efTNsLJA8knL";
  }
  if (!accounts.marketplaceProgram.value) {
    accounts.marketplaceProgram.value = "TCMPhJdwDryooaGtiocG1u3xcYbRpiJzb283XfCZsDp";
  }
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  if (!accounts.approve.value) {
    accounts.approve = {
      ...accounts.approve,
      ...await resolvers.resolveWnsApprovePda(resolverScope)
    };
  }
  if (!args.paymentMint) {
    args.paymentMint = "11111111111111111111111111111111";
  }
  if (!accounts.distribution.value) {
    accounts.distribution = {
      ...accounts.distribution,
      ...await resolvers.resolveWnsDistributionPda(resolverScope)
    };
  }
  if (!accounts.wnsProgram.value) {
    accounts.wnsProgram.value = "wns1gDLt8fgLcGhWi5MqAqgXpwEP1JftKE9eZnXS1HM";
  }
  if (!accounts.wnsDistributionProgram.value) {
    accounts.wnsDistributionProgram.value = "diste3nXmK7ddDTs1zb6uday6j4etCa9RChD8fJ1xay";
  }
  if (!accounts.extraMetas.value) {
    accounts.extraMetas = {
      ...accounts.extraMetas,
      ...await resolvers.resolveWnsExtraAccountMetasPda(resolverScope)
    };
  }
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.owner),
      getAccountMeta(accounts.ownerTa),
      getAccountMeta(accounts.listState),
      getAccountMeta(accounts.listTa),
      getAccountMeta(accounts.mint),
      getAccountMeta(accounts.rentDestination),
      getAccountMeta(accounts.payer),
      getAccountMeta(accounts.tokenProgram),
      getAccountMeta(accounts.associatedTokenProgram),
      getAccountMeta(accounts.marketplaceProgram),
      getAccountMeta(accounts.systemProgram),
      getAccountMeta(accounts.approve),
      getAccountMeta(accounts.distribution),
      getAccountMeta(accounts.wnsProgram),
      getAccountMeta(accounts.wnsDistributionProgram),
      getAccountMeta(accounts.extraMetas)
    ],
    programAddress,
    data: getDelistWnsInstructionDataEncoder().encode({})
  };
  return instruction;
}
function getDelistWnsInstruction(input) {
  const programAddress = TENSOR_MARKETPLACE_PROGRAM_ADDRESS;
  const originalAccounts = {
    owner: { value: input.owner ?? null, isWritable: false },
    ownerTa: { value: input.ownerTa ?? null, isWritable: true },
    listState: { value: input.listState ?? null, isWritable: true },
    listTa: { value: input.listTa ?? null, isWritable: true },
    mint: { value: input.mint ?? null, isWritable: false },
    rentDestination: { value: input.rentDestination ?? null, isWritable: true },
    payer: { value: input.payer ?? null, isWritable: true },
    tokenProgram: { value: input.tokenProgram ?? null, isWritable: false },
    associatedTokenProgram: {
      value: input.associatedTokenProgram ?? null,
      isWritable: false
    },
    marketplaceProgram: {
      value: input.marketplaceProgram ?? null,
      isWritable: false
    },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false },
    approve: { value: input.approve ?? null, isWritable: true },
    distribution: { value: input.distribution ?? null, isWritable: true },
    wnsProgram: { value: input.wnsProgram ?? null, isWritable: false },
    wnsDistributionProgram: {
      value: input.wnsDistributionProgram ?? null,
      isWritable: false
    },
    extraMetas: { value: input.extraMetas ?? null, isWritable: false }
  };
  const accounts = originalAccounts;
  ({ ...input });
  if (!accounts.tokenProgram.value) {
    accounts.tokenProgram.value = "TokenkegQfeZyiNwAJbNbGKPFXCWuBvf9Ss623VQ5DA";
  }
  if (!accounts.rentDestination.value) {
    accounts.rentDestination.value = expectSome(accounts.owner.value);
  }
  if (!accounts.payer.value) {
    accounts.payer.value = expectSome(accounts.owner.value);
  }
  if (!accounts.associatedTokenProgram.value) {
    accounts.associatedTokenProgram.value = "ATokenGPvbdGVxr1b2hvZbsiqW5xWH25efTNsLJA8knL";
  }
  if (!accounts.marketplaceProgram.value) {
    accounts.marketplaceProgram.value = "TCMPhJdwDryooaGtiocG1u3xcYbRpiJzb283XfCZsDp";
  }
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  if (!accounts.wnsProgram.value) {
    accounts.wnsProgram.value = "wns1gDLt8fgLcGhWi5MqAqgXpwEP1JftKE9eZnXS1HM";
  }
  if (!accounts.wnsDistributionProgram.value) {
    accounts.wnsDistributionProgram.value = "diste3nXmK7ddDTs1zb6uday6j4etCa9RChD8fJ1xay";
  }
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.owner),
      getAccountMeta(accounts.ownerTa),
      getAccountMeta(accounts.listState),
      getAccountMeta(accounts.listTa),
      getAccountMeta(accounts.mint),
      getAccountMeta(accounts.rentDestination),
      getAccountMeta(accounts.payer),
      getAccountMeta(accounts.tokenProgram),
      getAccountMeta(accounts.associatedTokenProgram),
      getAccountMeta(accounts.marketplaceProgram),
      getAccountMeta(accounts.systemProgram),
      getAccountMeta(accounts.approve),
      getAccountMeta(accounts.distribution),
      getAccountMeta(accounts.wnsProgram),
      getAccountMeta(accounts.wnsDistributionProgram),
      getAccountMeta(accounts.extraMetas)
    ],
    programAddress,
    data: getDelistWnsInstructionDataEncoder().encode({})
  };
  return instruction;
}
function parseDelistWnsInstruction(instruction) {
  if (instruction.accounts.length < 16) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      owner: getNextAccount(),
      ownerTa: getNextAccount(),
      listState: getNextAccount(),
      listTa: getNextAccount(),
      mint: getNextAccount(),
      rentDestination: getNextAccount(),
      payer: getNextAccount(),
      tokenProgram: getNextAccount(),
      associatedTokenProgram: getNextAccount(),
      marketplaceProgram: getNextAccount(),
      systemProgram: getNextAccount(),
      approve: getNextAccount(),
      distribution: getNextAccount(),
      wnsProgram: getNextAccount(),
      wnsDistributionProgram: getNextAccount(),
      extraMetas: getNextAccount()
    },
    data: getDelistWnsInstructionDataDecoder().decode(instruction.data)
  };
}
function getEditInstructionDataEncoder() {
  return web3_js.transformEncoder(
    web3_js.getStructEncoder([
      ["discriminator", web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 8)],
      ["amount", web3_js.getU64Encoder()],
      ["expireInSec", web3_js.getOptionEncoder(web3_js.getU64Encoder())],
      ["currency", web3_js.getOptionEncoder(web3_js.getAddressEncoder())],
      ["privateTaker", web3_js.getOptionEncoder(web3_js.getAddressEncoder())],
      ["makerBroker", web3_js.getOptionEncoder(web3_js.getAddressEncoder())]
    ]),
    (value) => ({
      ...value,
      discriminator: new Uint8Array([15, 183, 33, 86, 87, 28, 151, 145]),
      expireInSec: value.expireInSec ?? web3_js.none(),
      currency: value.currency ?? web3_js.none(),
      privateTaker: value.privateTaker ?? web3_js.none(),
      makerBroker: value.makerBroker ?? web3_js.none()
    })
  );
}
function getEditInstructionDataDecoder() {
  return web3_js.getStructDecoder([
    ["discriminator", web3_js.fixDecoderSize(web3_js.getBytesDecoder(), 8)],
    ["amount", web3_js.getU64Decoder()],
    ["expireInSec", web3_js.getOptionDecoder(web3_js.getU64Decoder())],
    ["currency", web3_js.getOptionDecoder(web3_js.getAddressDecoder())],
    ["privateTaker", web3_js.getOptionDecoder(web3_js.getAddressDecoder())],
    ["makerBroker", web3_js.getOptionDecoder(web3_js.getAddressDecoder())]
  ]);
}
function getEditInstructionDataCodec() {
  return web3_js.combineCodec(
    getEditInstructionDataEncoder(),
    getEditInstructionDataDecoder()
  );
}
function getEditInstruction(input) {
  const programAddress = TENSOR_MARKETPLACE_PROGRAM_ADDRESS;
  const originalAccounts = {
    listState: { value: input.listState ?? null, isWritable: true },
    owner: { value: input.owner ?? null, isWritable: false },
    marketplaceProgram: {
      value: input.marketplaceProgram ?? null,
      isWritable: false
    }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  if (!accounts.marketplaceProgram.value) {
    accounts.marketplaceProgram.value = "TCMPhJdwDryooaGtiocG1u3xcYbRpiJzb283XfCZsDp";
  }
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.listState),
      getAccountMeta(accounts.owner),
      getAccountMeta(accounts.marketplaceProgram)
    ],
    programAddress,
    data: getEditInstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function parseEditInstruction(instruction) {
  if (instruction.accounts.length < 3) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      listState: getNextAccount(),
      owner: getNextAccount(),
      marketplaceProgram: getNextAccount()
    },
    data: getEditInstructionDataDecoder().decode(instruction.data)
  };
}
function getListCompressedInstructionDataEncoder() {
  return web3_js.transformEncoder(
    web3_js.getStructEncoder([
      ["discriminator", web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 8)],
      ["nonce", web3_js.getU64Encoder()],
      ["index", web3_js.getU32Encoder()],
      ["root", web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 32)],
      ["dataHash", web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 32)],
      ["creatorHash", web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 32)],
      ["amount", web3_js.getU64Encoder()],
      ["expireInSec", web3_js.getOptionEncoder(web3_js.getU64Encoder())],
      ["currency", web3_js.getOptionEncoder(web3_js.getAddressEncoder())],
      ["privateTaker", web3_js.getOptionEncoder(web3_js.getAddressEncoder())],
      ["makerBroker", web3_js.getOptionEncoder(web3_js.getAddressEncoder())]
    ]),
    (value) => ({
      ...value,
      discriminator: new Uint8Array([54, 174, 193, 67, 17, 41, 132, 38]),
      expireInSec: value.expireInSec ?? web3_js.none(),
      currency: value.currency ?? web3_js.none(),
      privateTaker: value.privateTaker ?? web3_js.none(),
      makerBroker: value.makerBroker ?? web3_js.none()
    })
  );
}
function getListCompressedInstructionDataDecoder() {
  return web3_js.getStructDecoder([
    ["discriminator", web3_js.fixDecoderSize(web3_js.getBytesDecoder(), 8)],
    ["nonce", web3_js.getU64Decoder()],
    ["index", web3_js.getU32Decoder()],
    ["root", web3_js.fixDecoderSize(web3_js.getBytesDecoder(), 32)],
    ["dataHash", web3_js.fixDecoderSize(web3_js.getBytesDecoder(), 32)],
    ["creatorHash", web3_js.fixDecoderSize(web3_js.getBytesDecoder(), 32)],
    ["amount", web3_js.getU64Decoder()],
    ["expireInSec", web3_js.getOptionDecoder(web3_js.getU64Decoder())],
    ["currency", web3_js.getOptionDecoder(web3_js.getAddressDecoder())],
    ["privateTaker", web3_js.getOptionDecoder(web3_js.getAddressDecoder())],
    ["makerBroker", web3_js.getOptionDecoder(web3_js.getAddressDecoder())]
  ]);
}
function getListCompressedInstructionDataCodec() {
  return web3_js.combineCodec(
    getListCompressedInstructionDataEncoder(),
    getListCompressedInstructionDataDecoder()
  );
}
async function getListCompressedInstructionAsync(input) {
  const programAddress = TENSOR_MARKETPLACE_PROGRAM_ADDRESS;
  const originalAccounts = {
    treeAuthority: { value: input.treeAuthority ?? null, isWritable: false },
    owner: { value: input.owner ?? null, isWritable: false },
    delegate: { value: input.delegate ?? null, isWritable: false },
    merkleTree: { value: input.merkleTree ?? null, isWritable: true },
    logWrapper: { value: input.logWrapper ?? null, isWritable: false },
    compressionProgram: {
      value: input.compressionProgram ?? null,
      isWritable: false
    },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false },
    bubblegumProgram: {
      value: input.bubblegumProgram ?? null,
      isWritable: false
    },
    marketplaceProgram: {
      value: input.marketplaceProgram ?? null,
      isWritable: false
    },
    listState: { value: input.listState ?? null, isWritable: true },
    rentPayer: { value: input.rentPayer ?? null, isWritable: true },
    cosigner: { value: input.cosigner ?? null, isWritable: false }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  const resolverScope = { programAddress, accounts, args };
  if (!accounts.bubblegumProgram.value) {
    accounts.bubblegumProgram.value = "BGUMAp9Gq7iTEuizy4pqaxsTyUCBK68MDfK752saRPUY";
  }
  if (!accounts.treeAuthority.value) {
    accounts.treeAuthority = {
      ...accounts.treeAuthority,
      ...await resolveTreeAuthorityPda(resolverScope)
    };
  }
  if (!accounts.delegate.value) {
    accounts.delegate.value = expectSome(accounts.owner.value);
  }
  if (!accounts.logWrapper.value) {
    accounts.logWrapper.value = "noopb9bkMVfRPU8AsbpTUg8AQkHtKwMYZiFUjNRtMmV";
  }
  if (!accounts.compressionProgram.value) {
    accounts.compressionProgram.value = "cmtDvXumGCrqC1Age74AVPhSRVXJMd8PJS91L8KbNCK";
  }
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  if (!accounts.marketplaceProgram.value) {
    accounts.marketplaceProgram.value = "TCMPhJdwDryooaGtiocG1u3xcYbRpiJzb283XfCZsDp";
  }
  if (!accounts.rentPayer.value) {
    accounts.rentPayer = {
      ...accounts.rentPayer,
      ...resolveRemainingSignerWithOwnerOrDelegate(resolverScope)
    };
  }
  if (!accounts.cosigner.value) {
    accounts.cosigner.value = "TCMPhJdwDryooaGtiocG1u3xcYbRpiJzb283XfCZsDp";
  }
  if (!args.nonce) {
    args.nonce = expectSome(args.index);
  }
  if (!args.proof) {
    args.proof = [];
  }
  if (!args.canopyDepth) {
    args.canopyDepth = 0;
  }
  const remainingAccounts = resolveProofPath(resolverScope);
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.treeAuthority),
      getAccountMeta(accounts.owner),
      getAccountMeta(accounts.delegate),
      getAccountMeta(accounts.merkleTree),
      getAccountMeta(accounts.logWrapper),
      getAccountMeta(accounts.compressionProgram),
      getAccountMeta(accounts.systemProgram),
      getAccountMeta(accounts.bubblegumProgram),
      getAccountMeta(accounts.marketplaceProgram),
      getAccountMeta(accounts.listState),
      getAccountMeta(accounts.rentPayer),
      getAccountMeta(accounts.cosigner),
      ...remainingAccounts
    ],
    programAddress,
    data: getListCompressedInstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function getListCompressedInstruction(input) {
  const programAddress = TENSOR_MARKETPLACE_PROGRAM_ADDRESS;
  const originalAccounts = {
    treeAuthority: { value: input.treeAuthority ?? null, isWritable: false },
    owner: { value: input.owner ?? null, isWritable: false },
    delegate: { value: input.delegate ?? null, isWritable: false },
    merkleTree: { value: input.merkleTree ?? null, isWritable: true },
    logWrapper: { value: input.logWrapper ?? null, isWritable: false },
    compressionProgram: {
      value: input.compressionProgram ?? null,
      isWritable: false
    },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false },
    bubblegumProgram: {
      value: input.bubblegumProgram ?? null,
      isWritable: false
    },
    marketplaceProgram: {
      value: input.marketplaceProgram ?? null,
      isWritable: false
    },
    listState: { value: input.listState ?? null, isWritable: true },
    rentPayer: { value: input.rentPayer ?? null, isWritable: true },
    cosigner: { value: input.cosigner ?? null, isWritable: false }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  const resolverScope = { programAddress, accounts, args };
  if (!accounts.bubblegumProgram.value) {
    accounts.bubblegumProgram.value = "BGUMAp9Gq7iTEuizy4pqaxsTyUCBK68MDfK752saRPUY";
  }
  if (!accounts.delegate.value) {
    accounts.delegate.value = expectSome(accounts.owner.value);
  }
  if (!accounts.logWrapper.value) {
    accounts.logWrapper.value = "noopb9bkMVfRPU8AsbpTUg8AQkHtKwMYZiFUjNRtMmV";
  }
  if (!accounts.compressionProgram.value) {
    accounts.compressionProgram.value = "cmtDvXumGCrqC1Age74AVPhSRVXJMd8PJS91L8KbNCK";
  }
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  if (!accounts.marketplaceProgram.value) {
    accounts.marketplaceProgram.value = "TCMPhJdwDryooaGtiocG1u3xcYbRpiJzb283XfCZsDp";
  }
  if (!accounts.rentPayer.value) {
    accounts.rentPayer = {
      ...accounts.rentPayer,
      ...resolveRemainingSignerWithOwnerOrDelegate(resolverScope)
    };
  }
  if (!accounts.cosigner.value) {
    accounts.cosigner.value = "TCMPhJdwDryooaGtiocG1u3xcYbRpiJzb283XfCZsDp";
  }
  if (!args.nonce) {
    args.nonce = expectSome(args.index);
  }
  if (!args.proof) {
    args.proof = [];
  }
  if (!args.canopyDepth) {
    args.canopyDepth = 0;
  }
  const remainingAccounts = resolveProofPath(resolverScope);
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.treeAuthority),
      getAccountMeta(accounts.owner),
      getAccountMeta(accounts.delegate),
      getAccountMeta(accounts.merkleTree),
      getAccountMeta(accounts.logWrapper),
      getAccountMeta(accounts.compressionProgram),
      getAccountMeta(accounts.systemProgram),
      getAccountMeta(accounts.bubblegumProgram),
      getAccountMeta(accounts.marketplaceProgram),
      getAccountMeta(accounts.listState),
      getAccountMeta(accounts.rentPayer),
      getAccountMeta(accounts.cosigner),
      ...remainingAccounts
    ],
    programAddress,
    data: getListCompressedInstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function parseListCompressedInstruction(instruction) {
  if (instruction.accounts.length < 12) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  const getNextOptionalAccount = () => {
    const accountMeta = getNextAccount();
    return accountMeta.address === TENSOR_MARKETPLACE_PROGRAM_ADDRESS ? void 0 : accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      treeAuthority: getNextAccount(),
      owner: getNextAccount(),
      delegate: getNextAccount(),
      merkleTree: getNextAccount(),
      logWrapper: getNextAccount(),
      compressionProgram: getNextAccount(),
      systemProgram: getNextAccount(),
      bubblegumProgram: getNextAccount(),
      marketplaceProgram: getNextAccount(),
      listState: getNextAccount(),
      rentPayer: getNextAccount(),
      cosigner: getNextOptionalAccount()
    },
    data: getListCompressedInstructionDataDecoder().decode(instruction.data)
  };
}
function getListCoreInstructionDataEncoder() {
  return web3_js.transformEncoder(
    web3_js.getStructEncoder([
      ["discriminator", web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 8)],
      ["amount", web3_js.getU64Encoder()],
      ["expireInSec", web3_js.getOptionEncoder(web3_js.getU64Encoder())],
      ["currency", web3_js.getOptionEncoder(web3_js.getAddressEncoder())],
      ["privateTaker", web3_js.getOptionEncoder(web3_js.getAddressEncoder())],
      ["makerBroker", web3_js.getOptionEncoder(web3_js.getAddressEncoder())]
    ]),
    (value) => ({
      ...value,
      discriminator: new Uint8Array([173, 76, 167, 125, 118, 71, 1, 153]),
      expireInSec: value.expireInSec ?? web3_js.none(),
      currency: value.currency ?? web3_js.none(),
      privateTaker: value.privateTaker ?? web3_js.none(),
      makerBroker: value.makerBroker ?? web3_js.none()
    })
  );
}
function getListCoreInstructionDataDecoder() {
  return web3_js.getStructDecoder([
    ["discriminator", web3_js.fixDecoderSize(web3_js.getBytesDecoder(), 8)],
    ["amount", web3_js.getU64Decoder()],
    ["expireInSec", web3_js.getOptionDecoder(web3_js.getU64Decoder())],
    ["currency", web3_js.getOptionDecoder(web3_js.getAddressDecoder())],
    ["privateTaker", web3_js.getOptionDecoder(web3_js.getAddressDecoder())],
    ["makerBroker", web3_js.getOptionDecoder(web3_js.getAddressDecoder())]
  ]);
}
function getListCoreInstructionDataCodec() {
  return web3_js.combineCodec(
    getListCoreInstructionDataEncoder(),
    getListCoreInstructionDataDecoder()
  );
}
function getListCoreInstruction(input) {
  const programAddress = TENSOR_MARKETPLACE_PROGRAM_ADDRESS;
  const originalAccounts = {
    asset: { value: input.asset ?? null, isWritable: true },
    collection: { value: input.collection ?? null, isWritable: false },
    listState: { value: input.listState ?? null, isWritable: true },
    owner: { value: input.owner ?? null, isWritable: false },
    mplCoreProgram: { value: input.mplCoreProgram ?? null, isWritable: false },
    marketplaceProgram: {
      value: input.marketplaceProgram ?? null,
      isWritable: false
    },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false },
    payer: { value: input.payer ?? null, isWritable: true },
    cosigner: { value: input.cosigner ?? null, isWritable: false }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  if (!accounts.mplCoreProgram.value) {
    accounts.mplCoreProgram.value = "CoREENxT6tW1HoK8ypY1SxRMZTcVPm7R94rH4PZNhX7d";
  }
  if (!accounts.marketplaceProgram.value) {
    accounts.marketplaceProgram.value = "TCMPhJdwDryooaGtiocG1u3xcYbRpiJzb283XfCZsDp";
  }
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.asset),
      getAccountMeta(accounts.collection),
      getAccountMeta(accounts.listState),
      getAccountMeta(accounts.owner),
      getAccountMeta(accounts.mplCoreProgram),
      getAccountMeta(accounts.marketplaceProgram),
      getAccountMeta(accounts.systemProgram),
      getAccountMeta(accounts.payer),
      getAccountMeta(accounts.cosigner)
    ],
    programAddress,
    data: getListCoreInstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function parseListCoreInstruction(instruction) {
  if (instruction.accounts.length < 9) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  const getNextOptionalAccount = () => {
    const accountMeta = getNextAccount();
    return accountMeta.address === TENSOR_MARKETPLACE_PROGRAM_ADDRESS ? void 0 : accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      asset: getNextAccount(),
      collection: getNextOptionalAccount(),
      listState: getNextAccount(),
      owner: getNextAccount(),
      mplCoreProgram: getNextAccount(),
      marketplaceProgram: getNextAccount(),
      systemProgram: getNextAccount(),
      payer: getNextAccount(),
      cosigner: getNextOptionalAccount()
    },
    data: getListCoreInstructionDataDecoder().decode(instruction.data)
  };
}
function getListLegacyInstructionDataEncoder() {
  return web3_js.transformEncoder(
    web3_js.getStructEncoder([
      ["discriminator", web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 8)],
      ["amount", web3_js.getU64Encoder()],
      ["expireInSec", web3_js.getOptionEncoder(web3_js.getU64Encoder())],
      ["currency", web3_js.getOptionEncoder(web3_js.getAddressEncoder())],
      ["privateTaker", web3_js.getOptionEncoder(web3_js.getAddressEncoder())],
      ["makerBroker", web3_js.getOptionEncoder(web3_js.getAddressEncoder())],
      [
        "authorizationData",
        web3_js.getOptionEncoder(getAuthorizationDataLocalEncoder())
      ]
    ]),
    (value) => ({
      ...value,
      discriminator: new Uint8Array([6, 110, 255, 18, 16, 36, 8, 30]),
      expireInSec: value.expireInSec ?? web3_js.none(),
      currency: value.currency ?? web3_js.none(),
      privateTaker: value.privateTaker ?? web3_js.none(),
      makerBroker: value.makerBroker ?? web3_js.none(),
      authorizationData: value.authorizationData ?? web3_js.none()
    })
  );
}
function getListLegacyInstructionDataDecoder() {
  return web3_js.getStructDecoder([
    ["discriminator", web3_js.fixDecoderSize(web3_js.getBytesDecoder(), 8)],
    ["amount", web3_js.getU64Decoder()],
    ["expireInSec", web3_js.getOptionDecoder(web3_js.getU64Decoder())],
    ["currency", web3_js.getOptionDecoder(web3_js.getAddressDecoder())],
    ["privateTaker", web3_js.getOptionDecoder(web3_js.getAddressDecoder())],
    ["makerBroker", web3_js.getOptionDecoder(web3_js.getAddressDecoder())],
    ["authorizationData", web3_js.getOptionDecoder(getAuthorizationDataLocalDecoder())]
  ]);
}
function getListLegacyInstructionDataCodec() {
  return web3_js.combineCodec(
    getListLegacyInstructionDataEncoder(),
    getListLegacyInstructionDataDecoder()
  );
}
async function getListLegacyInstructionAsync(input) {
  const programAddress = TENSOR_MARKETPLACE_PROGRAM_ADDRESS;
  const originalAccounts = {
    owner: { value: input.owner ?? null, isWritable: false },
    ownerTa: { value: input.ownerTa ?? null, isWritable: true },
    listState: { value: input.listState ?? null, isWritable: true },
    listTa: { value: input.listTa ?? null, isWritable: true },
    mint: { value: input.mint ?? null, isWritable: false },
    payer: { value: input.payer ?? null, isWritable: true },
    tokenProgram: { value: input.tokenProgram ?? null, isWritable: false },
    associatedTokenProgram: {
      value: input.associatedTokenProgram ?? null,
      isWritable: false
    },
    marketplaceProgram: {
      value: input.marketplaceProgram ?? null,
      isWritable: false
    },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false },
    metadata: { value: input.metadata ?? null, isWritable: true },
    edition: { value: input.edition ?? null, isWritable: false },
    ownerTokenRecord: {
      value: input.ownerTokenRecord ?? null,
      isWritable: true
    },
    listTokenRecord: { value: input.listTokenRecord ?? null, isWritable: true },
    authorizationRules: {
      value: input.authorizationRules ?? null,
      isWritable: false
    },
    authorizationRulesProgram: {
      value: input.authorizationRulesProgram ?? null,
      isWritable: false
    },
    tokenMetadataProgram: {
      value: input.tokenMetadataProgram ?? null,
      isWritable: false
    },
    sysvarInstructions: {
      value: input.sysvarInstructions ?? null,
      isWritable: false
    },
    cosigner: { value: input.cosigner ?? null, isWritable: false }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  const resolverScope = { programAddress, accounts, args };
  if (!accounts.tokenProgram.value) {
    accounts.tokenProgram.value = "TokenkegQfeZyiNwAJbNbGKPFXCWuBvf9Ss623VQ5DA";
  }
  if (!accounts.ownerTa.value) {
    accounts.ownerTa = {
      ...accounts.ownerTa,
      ...await resolvers.resolveOwnerAta(resolverScope)
    };
  }
  if (!accounts.listState.value) {
    accounts.listState.value = await findListStatePda({
      mint: expectAddress(accounts.mint.value)
    });
  }
  if (!accounts.listTa.value) {
    accounts.listTa = {
      ...accounts.listTa,
      ...await resolvers.resolveListAta(resolverScope)
    };
  }
  if (!accounts.payer.value) {
    accounts.payer.value = expectSome(accounts.owner.value);
  }
  if (!accounts.associatedTokenProgram.value) {
    accounts.associatedTokenProgram.value = "ATokenGPvbdGVxr1b2hvZbsiqW5xWH25efTNsLJA8knL";
  }
  if (!accounts.marketplaceProgram.value) {
    accounts.marketplaceProgram.value = "TCMPhJdwDryooaGtiocG1u3xcYbRpiJzb283XfCZsDp";
  }
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  if (!accounts.metadata.value) {
    accounts.metadata = {
      ...accounts.metadata,
      ...await resolvers.resolveMetadata(resolverScope)
    };
  }
  if (!args.tokenStandard) {
    args.tokenStandard = resolvers.TokenStandard.ProgrammableNonFungible;
  }
  if (!accounts.edition.value) {
    accounts.edition = {
      ...accounts.edition,
      ...await resolvers.resolveEditionFromTokenStandard(resolverScope)
    };
  }
  if (!accounts.ownerTokenRecord.value) {
    accounts.ownerTokenRecord = {
      ...accounts.ownerTokenRecord,
      ...await resolvers.resolveOwnerTokenRecordFromTokenStandard(resolverScope)
    };
  }
  if (!accounts.listTokenRecord.value) {
    accounts.listTokenRecord = {
      ...accounts.listTokenRecord,
      ...await resolvers.resolveListTokenRecordFromTokenStandard(resolverScope)
    };
  }
  if (!accounts.authorizationRulesProgram.value) {
    accounts.authorizationRulesProgram = {
      ...accounts.authorizationRulesProgram,
      ...resolvers.resolveAuthorizationRulesProgramFromTokenStandard(resolverScope)
    };
  }
  if (!accounts.tokenMetadataProgram.value) {
    accounts.tokenMetadataProgram = {
      ...accounts.tokenMetadataProgram,
      ...resolvers.resolveTokenMetadataProgramFromTokenStandard(resolverScope)
    };
  }
  if (!accounts.sysvarInstructions.value) {
    accounts.sysvarInstructions = {
      ...accounts.sysvarInstructions,
      ...resolvers.resolveSysvarInstructionsFromTokenStandard(resolverScope)
    };
  }
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.owner),
      getAccountMeta(accounts.ownerTa),
      getAccountMeta(accounts.listState),
      getAccountMeta(accounts.listTa),
      getAccountMeta(accounts.mint),
      getAccountMeta(accounts.payer),
      getAccountMeta(accounts.tokenProgram),
      getAccountMeta(accounts.associatedTokenProgram),
      getAccountMeta(accounts.marketplaceProgram),
      getAccountMeta(accounts.systemProgram),
      getAccountMeta(accounts.metadata),
      getAccountMeta(accounts.edition),
      getAccountMeta(accounts.ownerTokenRecord),
      getAccountMeta(accounts.listTokenRecord),
      getAccountMeta(accounts.authorizationRules),
      getAccountMeta(accounts.authorizationRulesProgram),
      getAccountMeta(accounts.tokenMetadataProgram),
      getAccountMeta(accounts.sysvarInstructions),
      getAccountMeta(accounts.cosigner)
    ],
    programAddress,
    data: getListLegacyInstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function getListLegacyInstruction(input) {
  const programAddress = TENSOR_MARKETPLACE_PROGRAM_ADDRESS;
  const originalAccounts = {
    owner: { value: input.owner ?? null, isWritable: false },
    ownerTa: { value: input.ownerTa ?? null, isWritable: true },
    listState: { value: input.listState ?? null, isWritable: true },
    listTa: { value: input.listTa ?? null, isWritable: true },
    mint: { value: input.mint ?? null, isWritable: false },
    payer: { value: input.payer ?? null, isWritable: true },
    tokenProgram: { value: input.tokenProgram ?? null, isWritable: false },
    associatedTokenProgram: {
      value: input.associatedTokenProgram ?? null,
      isWritable: false
    },
    marketplaceProgram: {
      value: input.marketplaceProgram ?? null,
      isWritable: false
    },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false },
    metadata: { value: input.metadata ?? null, isWritable: true },
    edition: { value: input.edition ?? null, isWritable: false },
    ownerTokenRecord: {
      value: input.ownerTokenRecord ?? null,
      isWritable: true
    },
    listTokenRecord: { value: input.listTokenRecord ?? null, isWritable: true },
    authorizationRules: {
      value: input.authorizationRules ?? null,
      isWritable: false
    },
    authorizationRulesProgram: {
      value: input.authorizationRulesProgram ?? null,
      isWritable: false
    },
    tokenMetadataProgram: {
      value: input.tokenMetadataProgram ?? null,
      isWritable: false
    },
    sysvarInstructions: {
      value: input.sysvarInstructions ?? null,
      isWritable: false
    },
    cosigner: { value: input.cosigner ?? null, isWritable: false }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  const resolverScope = { programAddress, accounts, args };
  if (!accounts.tokenProgram.value) {
    accounts.tokenProgram.value = "TokenkegQfeZyiNwAJbNbGKPFXCWuBvf9Ss623VQ5DA";
  }
  if (!accounts.payer.value) {
    accounts.payer.value = expectSome(accounts.owner.value);
  }
  if (!accounts.associatedTokenProgram.value) {
    accounts.associatedTokenProgram.value = "ATokenGPvbdGVxr1b2hvZbsiqW5xWH25efTNsLJA8knL";
  }
  if (!accounts.marketplaceProgram.value) {
    accounts.marketplaceProgram.value = "TCMPhJdwDryooaGtiocG1u3xcYbRpiJzb283XfCZsDp";
  }
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  if (!args.tokenStandard) {
    args.tokenStandard = resolvers.TokenStandard.ProgrammableNonFungible;
  }
  if (!accounts.authorizationRulesProgram.value) {
    accounts.authorizationRulesProgram = {
      ...accounts.authorizationRulesProgram,
      ...resolvers.resolveAuthorizationRulesProgramFromTokenStandard(resolverScope)
    };
  }
  if (!accounts.tokenMetadataProgram.value) {
    accounts.tokenMetadataProgram = {
      ...accounts.tokenMetadataProgram,
      ...resolvers.resolveTokenMetadataProgramFromTokenStandard(resolverScope)
    };
  }
  if (!accounts.sysvarInstructions.value) {
    accounts.sysvarInstructions = {
      ...accounts.sysvarInstructions,
      ...resolvers.resolveSysvarInstructionsFromTokenStandard(resolverScope)
    };
  }
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.owner),
      getAccountMeta(accounts.ownerTa),
      getAccountMeta(accounts.listState),
      getAccountMeta(accounts.listTa),
      getAccountMeta(accounts.mint),
      getAccountMeta(accounts.payer),
      getAccountMeta(accounts.tokenProgram),
      getAccountMeta(accounts.associatedTokenProgram),
      getAccountMeta(accounts.marketplaceProgram),
      getAccountMeta(accounts.systemProgram),
      getAccountMeta(accounts.metadata),
      getAccountMeta(accounts.edition),
      getAccountMeta(accounts.ownerTokenRecord),
      getAccountMeta(accounts.listTokenRecord),
      getAccountMeta(accounts.authorizationRules),
      getAccountMeta(accounts.authorizationRulesProgram),
      getAccountMeta(accounts.tokenMetadataProgram),
      getAccountMeta(accounts.sysvarInstructions),
      getAccountMeta(accounts.cosigner)
    ],
    programAddress,
    data: getListLegacyInstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function parseListLegacyInstruction(instruction) {
  if (instruction.accounts.length < 19) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  const getNextOptionalAccount = () => {
    const accountMeta = getNextAccount();
    return accountMeta.address === TENSOR_MARKETPLACE_PROGRAM_ADDRESS ? void 0 : accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      owner: getNextAccount(),
      ownerTa: getNextAccount(),
      listState: getNextAccount(),
      listTa: getNextAccount(),
      mint: getNextAccount(),
      payer: getNextAccount(),
      tokenProgram: getNextAccount(),
      associatedTokenProgram: getNextAccount(),
      marketplaceProgram: getNextAccount(),
      systemProgram: getNextAccount(),
      metadata: getNextAccount(),
      edition: getNextAccount(),
      ownerTokenRecord: getNextOptionalAccount(),
      listTokenRecord: getNextOptionalAccount(),
      authorizationRules: getNextOptionalAccount(),
      authorizationRulesProgram: getNextOptionalAccount(),
      tokenMetadataProgram: getNextOptionalAccount(),
      sysvarInstructions: getNextOptionalAccount(),
      cosigner: getNextOptionalAccount()
    },
    data: getListLegacyInstructionDataDecoder().decode(instruction.data)
  };
}
function getListT22InstructionDataEncoder() {
  return web3_js.transformEncoder(
    web3_js.getStructEncoder([
      ["discriminator", web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 8)],
      ["amount", web3_js.getU64Encoder()],
      ["expireInSec", web3_js.getOptionEncoder(web3_js.getU64Encoder())],
      ["currency", web3_js.getOptionEncoder(web3_js.getAddressEncoder())],
      ["privateTaker", web3_js.getOptionEncoder(web3_js.getAddressEncoder())],
      ["makerBroker", web3_js.getOptionEncoder(web3_js.getAddressEncoder())]
    ]),
    (value) => ({
      ...value,
      discriminator: new Uint8Array([9, 117, 93, 230, 221, 4, 199, 212]),
      expireInSec: value.expireInSec ?? web3_js.none(),
      currency: value.currency ?? web3_js.none(),
      privateTaker: value.privateTaker ?? web3_js.none(),
      makerBroker: value.makerBroker ?? web3_js.none()
    })
  );
}
function getListT22InstructionDataDecoder() {
  return web3_js.getStructDecoder([
    ["discriminator", web3_js.fixDecoderSize(web3_js.getBytesDecoder(), 8)],
    ["amount", web3_js.getU64Decoder()],
    ["expireInSec", web3_js.getOptionDecoder(web3_js.getU64Decoder())],
    ["currency", web3_js.getOptionDecoder(web3_js.getAddressDecoder())],
    ["privateTaker", web3_js.getOptionDecoder(web3_js.getAddressDecoder())],
    ["makerBroker", web3_js.getOptionDecoder(web3_js.getAddressDecoder())]
  ]);
}
function getListT22InstructionDataCodec() {
  return web3_js.combineCodec(
    getListT22InstructionDataEncoder(),
    getListT22InstructionDataDecoder()
  );
}
async function getListT22InstructionAsync(input) {
  const programAddress = TENSOR_MARKETPLACE_PROGRAM_ADDRESS;
  const originalAccounts = {
    owner: { value: input.owner ?? null, isWritable: false },
    ownerTa: { value: input.ownerTa ?? null, isWritable: true },
    listState: { value: input.listState ?? null, isWritable: true },
    listTa: { value: input.listTa ?? null, isWritable: true },
    mint: { value: input.mint ?? null, isWritable: false },
    payer: { value: input.payer ?? null, isWritable: true },
    tokenProgram: { value: input.tokenProgram ?? null, isWritable: false },
    associatedTokenProgram: {
      value: input.associatedTokenProgram ?? null,
      isWritable: false
    },
    marketplaceProgram: {
      value: input.marketplaceProgram ?? null,
      isWritable: false
    },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false },
    cosigner: { value: input.cosigner ?? null, isWritable: false }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  const resolverScope = { programAddress, accounts, args };
  if (!accounts.tokenProgram.value) {
    accounts.tokenProgram.value = "TokenkegQfeZyiNwAJbNbGKPFXCWuBvf9Ss623VQ5DA";
  }
  if (!accounts.ownerTa.value) {
    accounts.ownerTa = {
      ...accounts.ownerTa,
      ...await resolvers.resolveOwnerAta(resolverScope)
    };
  }
  if (!accounts.listState.value) {
    accounts.listState.value = await findListStatePda({
      mint: expectAddress(accounts.mint.value)
    });
  }
  if (!accounts.listTa.value) {
    accounts.listTa = {
      ...accounts.listTa,
      ...await resolvers.resolveListAta(resolverScope)
    };
  }
  if (!accounts.payer.value) {
    accounts.payer.value = expectSome(accounts.owner.value);
  }
  if (!accounts.associatedTokenProgram.value) {
    accounts.associatedTokenProgram.value = "ATokenGPvbdGVxr1b2hvZbsiqW5xWH25efTNsLJA8knL";
  }
  if (!accounts.marketplaceProgram.value) {
    accounts.marketplaceProgram.value = "TCMPhJdwDryooaGtiocG1u3xcYbRpiJzb283XfCZsDp";
  }
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  if (!accounts.cosigner.value) {
    accounts.cosigner.value = "TCMPhJdwDryooaGtiocG1u3xcYbRpiJzb283XfCZsDp";
  }
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.owner),
      getAccountMeta(accounts.ownerTa),
      getAccountMeta(accounts.listState),
      getAccountMeta(accounts.listTa),
      getAccountMeta(accounts.mint),
      getAccountMeta(accounts.payer),
      getAccountMeta(accounts.tokenProgram),
      getAccountMeta(accounts.associatedTokenProgram),
      getAccountMeta(accounts.marketplaceProgram),
      getAccountMeta(accounts.systemProgram),
      getAccountMeta(accounts.cosigner)
    ],
    programAddress,
    data: getListT22InstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function getListT22Instruction(input) {
  const programAddress = TENSOR_MARKETPLACE_PROGRAM_ADDRESS;
  const originalAccounts = {
    owner: { value: input.owner ?? null, isWritable: false },
    ownerTa: { value: input.ownerTa ?? null, isWritable: true },
    listState: { value: input.listState ?? null, isWritable: true },
    listTa: { value: input.listTa ?? null, isWritable: true },
    mint: { value: input.mint ?? null, isWritable: false },
    payer: { value: input.payer ?? null, isWritable: true },
    tokenProgram: { value: input.tokenProgram ?? null, isWritable: false },
    associatedTokenProgram: {
      value: input.associatedTokenProgram ?? null,
      isWritable: false
    },
    marketplaceProgram: {
      value: input.marketplaceProgram ?? null,
      isWritable: false
    },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false },
    cosigner: { value: input.cosigner ?? null, isWritable: false }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  if (!accounts.tokenProgram.value) {
    accounts.tokenProgram.value = "TokenkegQfeZyiNwAJbNbGKPFXCWuBvf9Ss623VQ5DA";
  }
  if (!accounts.payer.value) {
    accounts.payer.value = expectSome(accounts.owner.value);
  }
  if (!accounts.associatedTokenProgram.value) {
    accounts.associatedTokenProgram.value = "ATokenGPvbdGVxr1b2hvZbsiqW5xWH25efTNsLJA8knL";
  }
  if (!accounts.marketplaceProgram.value) {
    accounts.marketplaceProgram.value = "TCMPhJdwDryooaGtiocG1u3xcYbRpiJzb283XfCZsDp";
  }
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  if (!accounts.cosigner.value) {
    accounts.cosigner.value = "TCMPhJdwDryooaGtiocG1u3xcYbRpiJzb283XfCZsDp";
  }
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.owner),
      getAccountMeta(accounts.ownerTa),
      getAccountMeta(accounts.listState),
      getAccountMeta(accounts.listTa),
      getAccountMeta(accounts.mint),
      getAccountMeta(accounts.payer),
      getAccountMeta(accounts.tokenProgram),
      getAccountMeta(accounts.associatedTokenProgram),
      getAccountMeta(accounts.marketplaceProgram),
      getAccountMeta(accounts.systemProgram),
      getAccountMeta(accounts.cosigner)
    ],
    programAddress,
    data: getListT22InstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function parseListT22Instruction(instruction) {
  if (instruction.accounts.length < 11) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  const getNextOptionalAccount = () => {
    const accountMeta = getNextAccount();
    return accountMeta.address === TENSOR_MARKETPLACE_PROGRAM_ADDRESS ? void 0 : accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      owner: getNextAccount(),
      ownerTa: getNextAccount(),
      listState: getNextAccount(),
      listTa: getNextAccount(),
      mint: getNextAccount(),
      payer: getNextAccount(),
      tokenProgram: getNextAccount(),
      associatedTokenProgram: getNextAccount(),
      marketplaceProgram: getNextAccount(),
      systemProgram: getNextAccount(),
      cosigner: getNextOptionalAccount()
    },
    data: getListT22InstructionDataDecoder().decode(instruction.data)
  };
}
function getListWnsInstructionDataEncoder() {
  return web3_js.transformEncoder(
    web3_js.getStructEncoder([
      ["discriminator", web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 8)],
      ["amount", web3_js.getU64Encoder()],
      ["expireInSec", web3_js.getOptionEncoder(web3_js.getU64Encoder())],
      ["currency", web3_js.getOptionEncoder(web3_js.getAddressEncoder())],
      ["privateTaker", web3_js.getOptionEncoder(web3_js.getAddressEncoder())],
      ["makerBroker", web3_js.getOptionEncoder(web3_js.getAddressEncoder())]
    ]),
    (value) => ({
      ...value,
      discriminator: new Uint8Array([23, 202, 102, 138, 255, 190, 39, 196]),
      expireInSec: value.expireInSec ?? web3_js.none(),
      currency: value.currency ?? web3_js.none(),
      privateTaker: value.privateTaker ?? web3_js.none(),
      makerBroker: value.makerBroker ?? web3_js.none()
    })
  );
}
function getListWnsInstructionDataDecoder() {
  return web3_js.getStructDecoder([
    ["discriminator", web3_js.fixDecoderSize(web3_js.getBytesDecoder(), 8)],
    ["amount", web3_js.getU64Decoder()],
    ["expireInSec", web3_js.getOptionDecoder(web3_js.getU64Decoder())],
    ["currency", web3_js.getOptionDecoder(web3_js.getAddressDecoder())],
    ["privateTaker", web3_js.getOptionDecoder(web3_js.getAddressDecoder())],
    ["makerBroker", web3_js.getOptionDecoder(web3_js.getAddressDecoder())]
  ]);
}
function getListWnsInstructionDataCodec() {
  return web3_js.combineCodec(
    getListWnsInstructionDataEncoder(),
    getListWnsInstructionDataDecoder()
  );
}
async function getListWnsInstructionAsync(input) {
  const programAddress = TENSOR_MARKETPLACE_PROGRAM_ADDRESS;
  const originalAccounts = {
    owner: { value: input.owner ?? null, isWritable: false },
    ownerTa: { value: input.ownerTa ?? null, isWritable: true },
    listState: { value: input.listState ?? null, isWritable: true },
    listTa: { value: input.listTa ?? null, isWritable: true },
    mint: { value: input.mint ?? null, isWritable: false },
    payer: { value: input.payer ?? null, isWritable: true },
    tokenProgram: { value: input.tokenProgram ?? null, isWritable: false },
    associatedTokenProgram: {
      value: input.associatedTokenProgram ?? null,
      isWritable: false
    },
    marketplaceProgram: {
      value: input.marketplaceProgram ?? null,
      isWritable: false
    },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false },
    approve: { value: input.approve ?? null, isWritable: true },
    distribution: { value: input.distribution ?? null, isWritable: true },
    wnsProgram: { value: input.wnsProgram ?? null, isWritable: false },
    wnsDistributionProgram: {
      value: input.wnsDistributionProgram ?? null,
      isWritable: false
    },
    extraMetas: { value: input.extraMetas ?? null, isWritable: false },
    cosigner: { value: input.cosigner ?? null, isWritable: false }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  const resolverScope = { programAddress, accounts, args };
  if (!accounts.tokenProgram.value) {
    accounts.tokenProgram.value = "TokenkegQfeZyiNwAJbNbGKPFXCWuBvf9Ss623VQ5DA";
  }
  if (!accounts.ownerTa.value) {
    accounts.ownerTa = {
      ...accounts.ownerTa,
      ...await resolvers.resolveOwnerAta(resolverScope)
    };
  }
  if (!accounts.listState.value) {
    accounts.listState.value = await findListStatePda({
      mint: expectAddress(accounts.mint.value)
    });
  }
  if (!accounts.listTa.value) {
    accounts.listTa = {
      ...accounts.listTa,
      ...await resolvers.resolveListAta(resolverScope)
    };
  }
  if (!accounts.payer.value) {
    accounts.payer.value = expectSome(accounts.owner.value);
  }
  if (!accounts.associatedTokenProgram.value) {
    accounts.associatedTokenProgram.value = "ATokenGPvbdGVxr1b2hvZbsiqW5xWH25efTNsLJA8knL";
  }
  if (!accounts.marketplaceProgram.value) {
    accounts.marketplaceProgram.value = "TCMPhJdwDryooaGtiocG1u3xcYbRpiJzb283XfCZsDp";
  }
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  if (!accounts.approve.value) {
    accounts.approve = {
      ...accounts.approve,
      ...await resolvers.resolveWnsApprovePda(resolverScope)
    };
  }
  if (!args.paymentMint) {
    args.paymentMint = "11111111111111111111111111111111";
  }
  if (!accounts.distribution.value) {
    accounts.distribution = {
      ...accounts.distribution,
      ...await resolvers.resolveWnsDistributionPda(resolverScope)
    };
  }
  if (!accounts.wnsProgram.value) {
    accounts.wnsProgram.value = "wns1gDLt8fgLcGhWi5MqAqgXpwEP1JftKE9eZnXS1HM";
  }
  if (!accounts.wnsDistributionProgram.value) {
    accounts.wnsDistributionProgram.value = "diste3nXmK7ddDTs1zb6uday6j4etCa9RChD8fJ1xay";
  }
  if (!accounts.extraMetas.value) {
    accounts.extraMetas = {
      ...accounts.extraMetas,
      ...await resolvers.resolveWnsExtraAccountMetasPda(resolverScope)
    };
  }
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.owner),
      getAccountMeta(accounts.ownerTa),
      getAccountMeta(accounts.listState),
      getAccountMeta(accounts.listTa),
      getAccountMeta(accounts.mint),
      getAccountMeta(accounts.payer),
      getAccountMeta(accounts.tokenProgram),
      getAccountMeta(accounts.associatedTokenProgram),
      getAccountMeta(accounts.marketplaceProgram),
      getAccountMeta(accounts.systemProgram),
      getAccountMeta(accounts.approve),
      getAccountMeta(accounts.distribution),
      getAccountMeta(accounts.wnsProgram),
      getAccountMeta(accounts.wnsDistributionProgram),
      getAccountMeta(accounts.extraMetas),
      getAccountMeta(accounts.cosigner)
    ],
    programAddress,
    data: getListWnsInstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function getListWnsInstruction(input) {
  const programAddress = TENSOR_MARKETPLACE_PROGRAM_ADDRESS;
  const originalAccounts = {
    owner: { value: input.owner ?? null, isWritable: false },
    ownerTa: { value: input.ownerTa ?? null, isWritable: true },
    listState: { value: input.listState ?? null, isWritable: true },
    listTa: { value: input.listTa ?? null, isWritable: true },
    mint: { value: input.mint ?? null, isWritable: false },
    payer: { value: input.payer ?? null, isWritable: true },
    tokenProgram: { value: input.tokenProgram ?? null, isWritable: false },
    associatedTokenProgram: {
      value: input.associatedTokenProgram ?? null,
      isWritable: false
    },
    marketplaceProgram: {
      value: input.marketplaceProgram ?? null,
      isWritable: false
    },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false },
    approve: { value: input.approve ?? null, isWritable: true },
    distribution: { value: input.distribution ?? null, isWritable: true },
    wnsProgram: { value: input.wnsProgram ?? null, isWritable: false },
    wnsDistributionProgram: {
      value: input.wnsDistributionProgram ?? null,
      isWritable: false
    },
    extraMetas: { value: input.extraMetas ?? null, isWritable: false },
    cosigner: { value: input.cosigner ?? null, isWritable: false }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  if (!accounts.tokenProgram.value) {
    accounts.tokenProgram.value = "TokenkegQfeZyiNwAJbNbGKPFXCWuBvf9Ss623VQ5DA";
  }
  if (!accounts.payer.value) {
    accounts.payer.value = expectSome(accounts.owner.value);
  }
  if (!accounts.associatedTokenProgram.value) {
    accounts.associatedTokenProgram.value = "ATokenGPvbdGVxr1b2hvZbsiqW5xWH25efTNsLJA8knL";
  }
  if (!accounts.marketplaceProgram.value) {
    accounts.marketplaceProgram.value = "TCMPhJdwDryooaGtiocG1u3xcYbRpiJzb283XfCZsDp";
  }
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  if (!args.paymentMint) {
    args.paymentMint = "11111111111111111111111111111111";
  }
  if (!accounts.wnsProgram.value) {
    accounts.wnsProgram.value = "wns1gDLt8fgLcGhWi5MqAqgXpwEP1JftKE9eZnXS1HM";
  }
  if (!accounts.wnsDistributionProgram.value) {
    accounts.wnsDistributionProgram.value = "diste3nXmK7ddDTs1zb6uday6j4etCa9RChD8fJ1xay";
  }
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.owner),
      getAccountMeta(accounts.ownerTa),
      getAccountMeta(accounts.listState),
      getAccountMeta(accounts.listTa),
      getAccountMeta(accounts.mint),
      getAccountMeta(accounts.payer),
      getAccountMeta(accounts.tokenProgram),
      getAccountMeta(accounts.associatedTokenProgram),
      getAccountMeta(accounts.marketplaceProgram),
      getAccountMeta(accounts.systemProgram),
      getAccountMeta(accounts.approve),
      getAccountMeta(accounts.distribution),
      getAccountMeta(accounts.wnsProgram),
      getAccountMeta(accounts.wnsDistributionProgram),
      getAccountMeta(accounts.extraMetas),
      getAccountMeta(accounts.cosigner)
    ],
    programAddress,
    data: getListWnsInstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function parseListWnsInstruction(instruction) {
  if (instruction.accounts.length < 16) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  const getNextOptionalAccount = () => {
    const accountMeta = getNextAccount();
    return accountMeta.address === TENSOR_MARKETPLACE_PROGRAM_ADDRESS ? void 0 : accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      owner: getNextAccount(),
      ownerTa: getNextAccount(),
      listState: getNextAccount(),
      listTa: getNextAccount(),
      mint: getNextAccount(),
      payer: getNextAccount(),
      tokenProgram: getNextAccount(),
      associatedTokenProgram: getNextAccount(),
      marketplaceProgram: getNextAccount(),
      systemProgram: getNextAccount(),
      approve: getNextAccount(),
      distribution: getNextAccount(),
      wnsProgram: getNextAccount(),
      wnsDistributionProgram: getNextAccount(),
      extraMetas: getNextAccount(),
      cosigner: getNextOptionalAccount()
    },
    data: getListWnsInstructionDataDecoder().decode(instruction.data)
  };
}
function getTakeBidCompressedFullMetaInstructionDataEncoder() {
  return web3_js.transformEncoder(
    web3_js.getStructEncoder([
      ["discriminator", web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 8)],
      ["nonce", web3_js.getU64Encoder()],
      ["index", web3_js.getU32Encoder()],
      ["root", web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 32)],
      ["name", web3_js.addEncoderSizePrefix(web3_js.getUtf8Encoder(), web3_js.getU32Encoder())],
      ["symbol", web3_js.addEncoderSizePrefix(web3_js.getUtf8Encoder(), web3_js.getU32Encoder())],
      ["uri", web3_js.addEncoderSizePrefix(web3_js.getUtf8Encoder(), web3_js.getU32Encoder())],
      ["sellerFeeBasisPoints", web3_js.getU16Encoder()],
      ["primarySaleHappened", web3_js.getBooleanEncoder()],
      ["isMutable", web3_js.getBooleanEncoder()],
      ["editionNonce", web3_js.getOptionEncoder(web3_js.getU8Encoder())],
      ["tokenStandard", web3_js.getOptionEncoder(getTTokenStandardEncoder())],
      ["collection", web3_js.getOptionEncoder(getTCollectionEncoder())],
      ["uses", web3_js.getOptionEncoder(getTUsesEncoder())],
      ["tokenProgramVersion", getTTokenProgramVersionEncoder()],
      [
        "creatorShares",
        web3_js.addEncoderSizePrefix(web3_js.getBytesEncoder(), web3_js.getU32Encoder())
      ],
      ["creatorVerified", web3_js.getArrayEncoder(web3_js.getBooleanEncoder())],
      ["minAmount", web3_js.getU64Encoder()],
      ["optionalRoyaltyPct", web3_js.getOptionEncoder(web3_js.getU16Encoder())]
    ]),
    (value) => ({
      ...value,
      discriminator: new Uint8Array([242, 194, 203, 225, 234, 53, 10, 96]),
      optionalRoyaltyPct: value.optionalRoyaltyPct ?? 100
    })
  );
}
function getTakeBidCompressedFullMetaInstructionDataDecoder() {
  return web3_js.getStructDecoder([
    ["discriminator", web3_js.fixDecoderSize(web3_js.getBytesDecoder(), 8)],
    ["nonce", web3_js.getU64Decoder()],
    ["index", web3_js.getU32Decoder()],
    ["root", web3_js.fixDecoderSize(web3_js.getBytesDecoder(), 32)],
    ["name", web3_js.addDecoderSizePrefix(web3_js.getUtf8Decoder(), web3_js.getU32Decoder())],
    ["symbol", web3_js.addDecoderSizePrefix(web3_js.getUtf8Decoder(), web3_js.getU32Decoder())],
    ["uri", web3_js.addDecoderSizePrefix(web3_js.getUtf8Decoder(), web3_js.getU32Decoder())],
    ["sellerFeeBasisPoints", web3_js.getU16Decoder()],
    ["primarySaleHappened", web3_js.getBooleanDecoder()],
    ["isMutable", web3_js.getBooleanDecoder()],
    ["editionNonce", web3_js.getOptionDecoder(web3_js.getU8Decoder())],
    ["tokenStandard", web3_js.getOptionDecoder(getTTokenStandardDecoder())],
    ["collection", web3_js.getOptionDecoder(getTCollectionDecoder())],
    ["uses", web3_js.getOptionDecoder(getTUsesDecoder())],
    ["tokenProgramVersion", getTTokenProgramVersionDecoder()],
    ["creatorShares", web3_js.addDecoderSizePrefix(web3_js.getBytesDecoder(), web3_js.getU32Decoder())],
    ["creatorVerified", web3_js.getArrayDecoder(web3_js.getBooleanDecoder())],
    ["minAmount", web3_js.getU64Decoder()],
    ["optionalRoyaltyPct", web3_js.getOptionDecoder(web3_js.getU16Decoder())]
  ]);
}
function getTakeBidCompressedFullMetaInstructionDataCodec() {
  return web3_js.combineCodec(
    getTakeBidCompressedFullMetaInstructionDataEncoder(),
    getTakeBidCompressedFullMetaInstructionDataDecoder()
  );
}
async function getTakeBidCompressedFullMetaInstructionAsync(input) {
  const programAddress = TENSOR_MARKETPLACE_PROGRAM_ADDRESS;
  const originalAccounts = {
    feeVault: { value: input.feeVault ?? null, isWritable: true },
    treeAuthority: { value: input.treeAuthority ?? null, isWritable: false },
    seller: { value: input.seller ?? null, isWritable: true },
    delegate: { value: input.delegate ?? null, isWritable: false },
    merkleTree: { value: input.merkleTree ?? null, isWritable: true },
    logWrapper: { value: input.logWrapper ?? null, isWritable: false },
    compressionProgram: {
      value: input.compressionProgram ?? null,
      isWritable: false
    },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false },
    bubblegumProgram: {
      value: input.bubblegumProgram ?? null,
      isWritable: false
    },
    marketplaceProgram: {
      value: input.marketplaceProgram ?? null,
      isWritable: false
    },
    tensorswapProgram: {
      value: input.tensorswapProgram ?? null,
      isWritable: false
    },
    bidState: { value: input.bidState ?? null, isWritable: true },
    owner: { value: input.owner ?? null, isWritable: true },
    takerBroker: { value: input.takerBroker ?? null, isWritable: true },
    makerBroker: { value: input.makerBroker ?? null, isWritable: true },
    marginAccount: { value: input.marginAccount ?? null, isWritable: true },
    whitelist: { value: input.whitelist ?? null, isWritable: false },
    cosigner: { value: input.cosigner ?? null, isWritable: false },
    rentDestination: { value: input.rentDestination ?? null, isWritable: true }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  const resolverScope = { programAddress, accounts, args };
  if (!accounts.feeVault.value) {
    accounts.feeVault = {
      ...accounts.feeVault,
      ...await resolveFeeVaultPdaFromBidState(resolverScope)
    };
  }
  if (!accounts.bubblegumProgram.value) {
    accounts.bubblegumProgram.value = "BGUMAp9Gq7iTEuizy4pqaxsTyUCBK68MDfK752saRPUY";
  }
  if (!accounts.treeAuthority.value) {
    accounts.treeAuthority = {
      ...accounts.treeAuthority,
      ...await resolveTreeAuthorityPda(resolverScope)
    };
  }
  if (!accounts.delegate.value) {
    accounts.delegate.value = expectSome(accounts.seller.value);
  }
  if (!accounts.logWrapper.value) {
    accounts.logWrapper.value = "noopb9bkMVfRPU8AsbpTUg8AQkHtKwMYZiFUjNRtMmV";
  }
  if (!accounts.compressionProgram.value) {
    accounts.compressionProgram.value = "cmtDvXumGCrqC1Age74AVPhSRVXJMd8PJS91L8KbNCK";
  }
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  if (!accounts.marketplaceProgram.value) {
    accounts.marketplaceProgram.value = "TCMPhJdwDryooaGtiocG1u3xcYbRpiJzb283XfCZsDp";
  }
  if (!accounts.tensorswapProgram.value) {
    accounts.tensorswapProgram.value = "TSWAPaqyCSx2KABk68Shruf4rp7CxcNi8hAsbdwmHbN";
  }
  if (!accounts.marginAccount.value) {
    accounts.marginAccount.value = expectSome(accounts.tensorswapProgram.value);
  }
  if (!accounts.rentDestination.value) {
    accounts.rentDestination.value = expectSome(accounts.owner.value);
  }
  if (!args.nonce) {
    args.nonce = expectSome(args.index);
  }
  if (!args.creators) {
    args.creators = [];
  }
  if (!args.proof) {
    args.proof = [];
  }
  if (!args.canopyDepth) {
    args.canopyDepth = 0;
  }
  const remainingAccounts = [
    ...resolveCreatorPath(resolverScope),
    ...resolveProofPath(resolverScope)
  ];
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.feeVault),
      getAccountMeta(accounts.treeAuthority),
      getAccountMeta(accounts.seller),
      getAccountMeta(accounts.delegate),
      getAccountMeta(accounts.merkleTree),
      getAccountMeta(accounts.logWrapper),
      getAccountMeta(accounts.compressionProgram),
      getAccountMeta(accounts.systemProgram),
      getAccountMeta(accounts.bubblegumProgram),
      getAccountMeta(accounts.marketplaceProgram),
      getAccountMeta(accounts.tensorswapProgram),
      getAccountMeta(accounts.bidState),
      getAccountMeta(accounts.owner),
      getAccountMeta(accounts.takerBroker),
      getAccountMeta(accounts.makerBroker),
      getAccountMeta(accounts.marginAccount),
      getAccountMeta(accounts.whitelist),
      getAccountMeta(accounts.cosigner),
      getAccountMeta(accounts.rentDestination),
      ...remainingAccounts
    ],
    programAddress,
    data: getTakeBidCompressedFullMetaInstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function getTakeBidCompressedFullMetaInstruction(input) {
  const programAddress = TENSOR_MARKETPLACE_PROGRAM_ADDRESS;
  const originalAccounts = {
    feeVault: { value: input.feeVault ?? null, isWritable: true },
    treeAuthority: { value: input.treeAuthority ?? null, isWritable: false },
    seller: { value: input.seller ?? null, isWritable: true },
    delegate: { value: input.delegate ?? null, isWritable: false },
    merkleTree: { value: input.merkleTree ?? null, isWritable: true },
    logWrapper: { value: input.logWrapper ?? null, isWritable: false },
    compressionProgram: {
      value: input.compressionProgram ?? null,
      isWritable: false
    },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false },
    bubblegumProgram: {
      value: input.bubblegumProgram ?? null,
      isWritable: false
    },
    marketplaceProgram: {
      value: input.marketplaceProgram ?? null,
      isWritable: false
    },
    tensorswapProgram: {
      value: input.tensorswapProgram ?? null,
      isWritable: false
    },
    bidState: { value: input.bidState ?? null, isWritable: true },
    owner: { value: input.owner ?? null, isWritable: true },
    takerBroker: { value: input.takerBroker ?? null, isWritable: true },
    makerBroker: { value: input.makerBroker ?? null, isWritable: true },
    marginAccount: { value: input.marginAccount ?? null, isWritable: true },
    whitelist: { value: input.whitelist ?? null, isWritable: false },
    cosigner: { value: input.cosigner ?? null, isWritable: false },
    rentDestination: { value: input.rentDestination ?? null, isWritable: true }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  const resolverScope = { programAddress, accounts, args };
  if (!accounts.bubblegumProgram.value) {
    accounts.bubblegumProgram.value = "BGUMAp9Gq7iTEuizy4pqaxsTyUCBK68MDfK752saRPUY";
  }
  if (!accounts.delegate.value) {
    accounts.delegate.value = expectSome(accounts.seller.value);
  }
  if (!accounts.logWrapper.value) {
    accounts.logWrapper.value = "noopb9bkMVfRPU8AsbpTUg8AQkHtKwMYZiFUjNRtMmV";
  }
  if (!accounts.compressionProgram.value) {
    accounts.compressionProgram.value = "cmtDvXumGCrqC1Age74AVPhSRVXJMd8PJS91L8KbNCK";
  }
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  if (!accounts.marketplaceProgram.value) {
    accounts.marketplaceProgram.value = "TCMPhJdwDryooaGtiocG1u3xcYbRpiJzb283XfCZsDp";
  }
  if (!accounts.tensorswapProgram.value) {
    accounts.tensorswapProgram.value = "TSWAPaqyCSx2KABk68Shruf4rp7CxcNi8hAsbdwmHbN";
  }
  if (!accounts.marginAccount.value) {
    accounts.marginAccount.value = expectSome(accounts.tensorswapProgram.value);
  }
  if (!accounts.rentDestination.value) {
    accounts.rentDestination.value = expectSome(accounts.owner.value);
  }
  if (!args.nonce) {
    args.nonce = expectSome(args.index);
  }
  if (!args.creators) {
    args.creators = [];
  }
  if (!args.proof) {
    args.proof = [];
  }
  if (!args.canopyDepth) {
    args.canopyDepth = 0;
  }
  const remainingAccounts = [
    ...resolveCreatorPath(resolverScope),
    ...resolveProofPath(resolverScope)
  ];
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.feeVault),
      getAccountMeta(accounts.treeAuthority),
      getAccountMeta(accounts.seller),
      getAccountMeta(accounts.delegate),
      getAccountMeta(accounts.merkleTree),
      getAccountMeta(accounts.logWrapper),
      getAccountMeta(accounts.compressionProgram),
      getAccountMeta(accounts.systemProgram),
      getAccountMeta(accounts.bubblegumProgram),
      getAccountMeta(accounts.marketplaceProgram),
      getAccountMeta(accounts.tensorswapProgram),
      getAccountMeta(accounts.bidState),
      getAccountMeta(accounts.owner),
      getAccountMeta(accounts.takerBroker),
      getAccountMeta(accounts.makerBroker),
      getAccountMeta(accounts.marginAccount),
      getAccountMeta(accounts.whitelist),
      getAccountMeta(accounts.cosigner),
      getAccountMeta(accounts.rentDestination),
      ...remainingAccounts
    ],
    programAddress,
    data: getTakeBidCompressedFullMetaInstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function parseTakeBidCompressedFullMetaInstruction(instruction) {
  if (instruction.accounts.length < 19) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  const getNextOptionalAccount = () => {
    const accountMeta = getNextAccount();
    return accountMeta.address === TENSOR_MARKETPLACE_PROGRAM_ADDRESS ? void 0 : accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      feeVault: getNextAccount(),
      treeAuthority: getNextAccount(),
      seller: getNextAccount(),
      delegate: getNextAccount(),
      merkleTree: getNextAccount(),
      logWrapper: getNextAccount(),
      compressionProgram: getNextAccount(),
      systemProgram: getNextAccount(),
      bubblegumProgram: getNextAccount(),
      marketplaceProgram: getNextAccount(),
      tensorswapProgram: getNextAccount(),
      bidState: getNextAccount(),
      owner: getNextAccount(),
      takerBroker: getNextOptionalAccount(),
      makerBroker: getNextOptionalAccount(),
      marginAccount: getNextAccount(),
      whitelist: getNextAccount(),
      cosigner: getNextOptionalAccount(),
      rentDestination: getNextAccount()
    },
    data: getTakeBidCompressedFullMetaInstructionDataDecoder().decode(
      instruction.data
    )
  };
}
function getTakeBidCompressedMetaHashInstructionDataEncoder() {
  return web3_js.transformEncoder(
    web3_js.getStructEncoder([
      ["discriminator", web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 8)],
      ["nonce", web3_js.getU64Encoder()],
      ["index", web3_js.getU32Encoder()],
      ["root", web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 32)],
      ["metaHash", web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 32)],
      [
        "creatorShares",
        web3_js.addEncoderSizePrefix(web3_js.getBytesEncoder(), web3_js.getU32Encoder())
      ],
      ["creatorVerified", web3_js.getArrayEncoder(web3_js.getBooleanEncoder())],
      ["sellerFeeBasisPoints", web3_js.getU16Encoder()],
      ["minAmount", web3_js.getU64Encoder()],
      ["optionalRoyaltyPct", web3_js.getOptionEncoder(web3_js.getU16Encoder())]
    ]),
    (value) => ({
      ...value,
      discriminator: new Uint8Array([85, 227, 202, 70, 45, 215, 10, 193]),
      optionalRoyaltyPct: value.optionalRoyaltyPct ?? 100
    })
  );
}
function getTakeBidCompressedMetaHashInstructionDataDecoder() {
  return web3_js.getStructDecoder([
    ["discriminator", web3_js.fixDecoderSize(web3_js.getBytesDecoder(), 8)],
    ["nonce", web3_js.getU64Decoder()],
    ["index", web3_js.getU32Decoder()],
    ["root", web3_js.fixDecoderSize(web3_js.getBytesDecoder(), 32)],
    ["metaHash", web3_js.fixDecoderSize(web3_js.getBytesDecoder(), 32)],
    ["creatorShares", web3_js.addDecoderSizePrefix(web3_js.getBytesDecoder(), web3_js.getU32Decoder())],
    ["creatorVerified", web3_js.getArrayDecoder(web3_js.getBooleanDecoder())],
    ["sellerFeeBasisPoints", web3_js.getU16Decoder()],
    ["minAmount", web3_js.getU64Decoder()],
    ["optionalRoyaltyPct", web3_js.getOptionDecoder(web3_js.getU16Decoder())]
  ]);
}
function getTakeBidCompressedMetaHashInstructionDataCodec() {
  return web3_js.combineCodec(
    getTakeBidCompressedMetaHashInstructionDataEncoder(),
    getTakeBidCompressedMetaHashInstructionDataDecoder()
  );
}
async function getTakeBidCompressedMetaHashInstructionAsync(input) {
  const programAddress = TENSOR_MARKETPLACE_PROGRAM_ADDRESS;
  const originalAccounts = {
    feeVault: { value: input.feeVault ?? null, isWritable: true },
    treeAuthority: { value: input.treeAuthority ?? null, isWritable: false },
    seller: { value: input.seller ?? null, isWritable: true },
    delegate: { value: input.delegate ?? null, isWritable: false },
    merkleTree: { value: input.merkleTree ?? null, isWritable: true },
    logWrapper: { value: input.logWrapper ?? null, isWritable: false },
    compressionProgram: {
      value: input.compressionProgram ?? null,
      isWritable: false
    },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false },
    bubblegumProgram: {
      value: input.bubblegumProgram ?? null,
      isWritable: false
    },
    marketplaceProgram: {
      value: input.marketplaceProgram ?? null,
      isWritable: false
    },
    tensorswapProgram: {
      value: input.tensorswapProgram ?? null,
      isWritable: false
    },
    bidState: { value: input.bidState ?? null, isWritable: true },
    owner: { value: input.owner ?? null, isWritable: true },
    takerBroker: { value: input.takerBroker ?? null, isWritable: true },
    makerBroker: { value: input.makerBroker ?? null, isWritable: true },
    marginAccount: { value: input.marginAccount ?? null, isWritable: true },
    whitelist: { value: input.whitelist ?? null, isWritable: false },
    cosigner: { value: input.cosigner ?? null, isWritable: false },
    rentDestination: { value: input.rentDestination ?? null, isWritable: true }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  const resolverScope = { programAddress, accounts, args };
  if (!accounts.feeVault.value) {
    accounts.feeVault = {
      ...accounts.feeVault,
      ...await resolveFeeVaultPdaFromBidState(resolverScope)
    };
  }
  if (!accounts.bubblegumProgram.value) {
    accounts.bubblegumProgram.value = "BGUMAp9Gq7iTEuizy4pqaxsTyUCBK68MDfK752saRPUY";
  }
  if (!accounts.treeAuthority.value) {
    accounts.treeAuthority = {
      ...accounts.treeAuthority,
      ...await resolveTreeAuthorityPda(resolverScope)
    };
  }
  if (!accounts.delegate.value) {
    accounts.delegate.value = expectSome(accounts.seller.value);
  }
  if (!accounts.logWrapper.value) {
    accounts.logWrapper.value = "noopb9bkMVfRPU8AsbpTUg8AQkHtKwMYZiFUjNRtMmV";
  }
  if (!accounts.compressionProgram.value) {
    accounts.compressionProgram.value = "cmtDvXumGCrqC1Age74AVPhSRVXJMd8PJS91L8KbNCK";
  }
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  if (!accounts.marketplaceProgram.value) {
    accounts.marketplaceProgram.value = "TCMPhJdwDryooaGtiocG1u3xcYbRpiJzb283XfCZsDp";
  }
  if (!accounts.tensorswapProgram.value) {
    accounts.tensorswapProgram.value = "TSWAPaqyCSx2KABk68Shruf4rp7CxcNi8hAsbdwmHbN";
  }
  if (!accounts.marginAccount.value) {
    accounts.marginAccount.value = expectSome(accounts.tensorswapProgram.value);
  }
  if (!accounts.rentDestination.value) {
    accounts.rentDestination.value = expectSome(accounts.owner.value);
  }
  if (!args.nonce) {
    args.nonce = expectSome(args.index);
  }
  if (!args.creators) {
    args.creators = [];
  }
  if (!args.proof) {
    args.proof = [];
  }
  if (!args.canopyDepth) {
    args.canopyDepth = 0;
  }
  const remainingAccounts = [
    ...resolveCreatorPath(resolverScope),
    ...resolveProofPath(resolverScope)
  ];
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.feeVault),
      getAccountMeta(accounts.treeAuthority),
      getAccountMeta(accounts.seller),
      getAccountMeta(accounts.delegate),
      getAccountMeta(accounts.merkleTree),
      getAccountMeta(accounts.logWrapper),
      getAccountMeta(accounts.compressionProgram),
      getAccountMeta(accounts.systemProgram),
      getAccountMeta(accounts.bubblegumProgram),
      getAccountMeta(accounts.marketplaceProgram),
      getAccountMeta(accounts.tensorswapProgram),
      getAccountMeta(accounts.bidState),
      getAccountMeta(accounts.owner),
      getAccountMeta(accounts.takerBroker),
      getAccountMeta(accounts.makerBroker),
      getAccountMeta(accounts.marginAccount),
      getAccountMeta(accounts.whitelist),
      getAccountMeta(accounts.cosigner),
      getAccountMeta(accounts.rentDestination),
      ...remainingAccounts
    ],
    programAddress,
    data: getTakeBidCompressedMetaHashInstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function getTakeBidCompressedMetaHashInstruction(input) {
  const programAddress = TENSOR_MARKETPLACE_PROGRAM_ADDRESS;
  const originalAccounts = {
    feeVault: { value: input.feeVault ?? null, isWritable: true },
    treeAuthority: { value: input.treeAuthority ?? null, isWritable: false },
    seller: { value: input.seller ?? null, isWritable: true },
    delegate: { value: input.delegate ?? null, isWritable: false },
    merkleTree: { value: input.merkleTree ?? null, isWritable: true },
    logWrapper: { value: input.logWrapper ?? null, isWritable: false },
    compressionProgram: {
      value: input.compressionProgram ?? null,
      isWritable: false
    },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false },
    bubblegumProgram: {
      value: input.bubblegumProgram ?? null,
      isWritable: false
    },
    marketplaceProgram: {
      value: input.marketplaceProgram ?? null,
      isWritable: false
    },
    tensorswapProgram: {
      value: input.tensorswapProgram ?? null,
      isWritable: false
    },
    bidState: { value: input.bidState ?? null, isWritable: true },
    owner: { value: input.owner ?? null, isWritable: true },
    takerBroker: { value: input.takerBroker ?? null, isWritable: true },
    makerBroker: { value: input.makerBroker ?? null, isWritable: true },
    marginAccount: { value: input.marginAccount ?? null, isWritable: true },
    whitelist: { value: input.whitelist ?? null, isWritable: false },
    cosigner: { value: input.cosigner ?? null, isWritable: false },
    rentDestination: { value: input.rentDestination ?? null, isWritable: true }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  const resolverScope = { programAddress, accounts, args };
  if (!accounts.bubblegumProgram.value) {
    accounts.bubblegumProgram.value = "BGUMAp9Gq7iTEuizy4pqaxsTyUCBK68MDfK752saRPUY";
  }
  if (!accounts.delegate.value) {
    accounts.delegate.value = expectSome(accounts.seller.value);
  }
  if (!accounts.logWrapper.value) {
    accounts.logWrapper.value = "noopb9bkMVfRPU8AsbpTUg8AQkHtKwMYZiFUjNRtMmV";
  }
  if (!accounts.compressionProgram.value) {
    accounts.compressionProgram.value = "cmtDvXumGCrqC1Age74AVPhSRVXJMd8PJS91L8KbNCK";
  }
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  if (!accounts.marketplaceProgram.value) {
    accounts.marketplaceProgram.value = "TCMPhJdwDryooaGtiocG1u3xcYbRpiJzb283XfCZsDp";
  }
  if (!accounts.tensorswapProgram.value) {
    accounts.tensorswapProgram.value = "TSWAPaqyCSx2KABk68Shruf4rp7CxcNi8hAsbdwmHbN";
  }
  if (!accounts.marginAccount.value) {
    accounts.marginAccount.value = expectSome(accounts.tensorswapProgram.value);
  }
  if (!accounts.rentDestination.value) {
    accounts.rentDestination.value = expectSome(accounts.owner.value);
  }
  if (!args.nonce) {
    args.nonce = expectSome(args.index);
  }
  if (!args.creators) {
    args.creators = [];
  }
  if (!args.proof) {
    args.proof = [];
  }
  if (!args.canopyDepth) {
    args.canopyDepth = 0;
  }
  const remainingAccounts = [
    ...resolveCreatorPath(resolverScope),
    ...resolveProofPath(resolverScope)
  ];
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.feeVault),
      getAccountMeta(accounts.treeAuthority),
      getAccountMeta(accounts.seller),
      getAccountMeta(accounts.delegate),
      getAccountMeta(accounts.merkleTree),
      getAccountMeta(accounts.logWrapper),
      getAccountMeta(accounts.compressionProgram),
      getAccountMeta(accounts.systemProgram),
      getAccountMeta(accounts.bubblegumProgram),
      getAccountMeta(accounts.marketplaceProgram),
      getAccountMeta(accounts.tensorswapProgram),
      getAccountMeta(accounts.bidState),
      getAccountMeta(accounts.owner),
      getAccountMeta(accounts.takerBroker),
      getAccountMeta(accounts.makerBroker),
      getAccountMeta(accounts.marginAccount),
      getAccountMeta(accounts.whitelist),
      getAccountMeta(accounts.cosigner),
      getAccountMeta(accounts.rentDestination),
      ...remainingAccounts
    ],
    programAddress,
    data: getTakeBidCompressedMetaHashInstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function parseTakeBidCompressedMetaHashInstruction(instruction) {
  if (instruction.accounts.length < 19) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  const getNextOptionalAccount = () => {
    const accountMeta = getNextAccount();
    return accountMeta.address === TENSOR_MARKETPLACE_PROGRAM_ADDRESS ? void 0 : accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      feeVault: getNextAccount(),
      treeAuthority: getNextAccount(),
      seller: getNextAccount(),
      delegate: getNextAccount(),
      merkleTree: getNextAccount(),
      logWrapper: getNextAccount(),
      compressionProgram: getNextAccount(),
      systemProgram: getNextAccount(),
      bubblegumProgram: getNextAccount(),
      marketplaceProgram: getNextAccount(),
      tensorswapProgram: getNextAccount(),
      bidState: getNextAccount(),
      owner: getNextAccount(),
      takerBroker: getNextOptionalAccount(),
      makerBroker: getNextOptionalAccount(),
      marginAccount: getNextAccount(),
      whitelist: getNextAccount(),
      cosigner: getNextOptionalAccount(),
      rentDestination: getNextAccount()
    },
    data: getTakeBidCompressedMetaHashInstructionDataDecoder().decode(
      instruction.data
    )
  };
}
function getTakeBidCoreInstructionDataEncoder() {
  return web3_js.transformEncoder(
    web3_js.getStructEncoder([
      ["discriminator", web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 8)],
      ["minAmount", web3_js.getU64Encoder()]
    ]),
    (value) => ({
      ...value,
      discriminator: new Uint8Array([250, 41, 248, 20, 61, 161, 27, 141])
    })
  );
}
function getTakeBidCoreInstructionDataDecoder() {
  return web3_js.getStructDecoder([
    ["discriminator", web3_js.fixDecoderSize(web3_js.getBytesDecoder(), 8)],
    ["minAmount", web3_js.getU64Decoder()]
  ]);
}
function getTakeBidCoreInstructionDataCodec() {
  return web3_js.combineCodec(
    getTakeBidCoreInstructionDataEncoder(),
    getTakeBidCoreInstructionDataDecoder()
  );
}
function getTakeBidCoreInstruction(input) {
  const programAddress = TENSOR_MARKETPLACE_PROGRAM_ADDRESS;
  const originalAccounts = {
    feeVault: { value: input.feeVault ?? null, isWritable: true },
    seller: { value: input.seller ?? null, isWritable: true },
    bidState: { value: input.bidState ?? null, isWritable: true },
    owner: { value: input.owner ?? null, isWritable: true },
    takerBroker: { value: input.takerBroker ?? null, isWritable: true },
    makerBroker: { value: input.makerBroker ?? null, isWritable: true },
    marginAccount: { value: input.marginAccount ?? null, isWritable: true },
    whitelist: { value: input.whitelist ?? null, isWritable: false },
    asset: { value: input.asset ?? null, isWritable: true },
    collection: { value: input.collection ?? null, isWritable: false },
    mplCoreProgram: { value: input.mplCoreProgram ?? null, isWritable: false },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false },
    marketplaceProgram: {
      value: input.marketplaceProgram ?? null,
      isWritable: false
    },
    escrowProgram: { value: input.escrowProgram ?? null, isWritable: false },
    cosigner: { value: input.cosigner ?? null, isWritable: false },
    mintProof: { value: input.mintProof ?? null, isWritable: false },
    rentDestination: { value: input.rentDestination ?? null, isWritable: true }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  if (!accounts.mplCoreProgram.value) {
    accounts.mplCoreProgram.value = "CoREENxT6tW1HoK8ypY1SxRMZTcVPm7R94rH4PZNhX7d";
  }
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  if (!accounts.marketplaceProgram.value) {
    accounts.marketplaceProgram.value = "TCMPhJdwDryooaGtiocG1u3xcYbRpiJzb283XfCZsDp";
  }
  if (!accounts.escrowProgram.value) {
    accounts.escrowProgram.value = "TSWAPaqyCSx2KABk68Shruf4rp7CxcNi8hAsbdwmHbN";
  }
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.feeVault),
      getAccountMeta(accounts.seller),
      getAccountMeta(accounts.bidState),
      getAccountMeta(accounts.owner),
      getAccountMeta(accounts.takerBroker),
      getAccountMeta(accounts.makerBroker),
      getAccountMeta(accounts.marginAccount),
      getAccountMeta(accounts.whitelist),
      getAccountMeta(accounts.asset),
      getAccountMeta(accounts.collection),
      getAccountMeta(accounts.mplCoreProgram),
      getAccountMeta(accounts.systemProgram),
      getAccountMeta(accounts.marketplaceProgram),
      getAccountMeta(accounts.escrowProgram),
      getAccountMeta(accounts.cosigner),
      getAccountMeta(accounts.mintProof),
      getAccountMeta(accounts.rentDestination)
    ],
    programAddress,
    data: getTakeBidCoreInstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function parseTakeBidCoreInstruction(instruction) {
  if (instruction.accounts.length < 17) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  const getNextOptionalAccount = () => {
    const accountMeta = getNextAccount();
    return accountMeta.address === TENSOR_MARKETPLACE_PROGRAM_ADDRESS ? void 0 : accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      feeVault: getNextAccount(),
      seller: getNextAccount(),
      bidState: getNextAccount(),
      owner: getNextAccount(),
      takerBroker: getNextOptionalAccount(),
      makerBroker: getNextOptionalAccount(),
      marginAccount: getNextAccount(),
      whitelist: getNextAccount(),
      asset: getNextAccount(),
      collection: getNextOptionalAccount(),
      mplCoreProgram: getNextAccount(),
      systemProgram: getNextAccount(),
      marketplaceProgram: getNextAccount(),
      escrowProgram: getNextAccount(),
      cosigner: getNextOptionalAccount(),
      mintProof: getNextAccount(),
      rentDestination: getNextAccount()
    },
    data: getTakeBidCoreInstructionDataDecoder().decode(instruction.data)
  };
}
function getTakeBidLegacyInstructionDataEncoder() {
  return web3_js.transformEncoder(
    web3_js.getStructEncoder([
      ["discriminator", web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 8)],
      ["minAmount", web3_js.getU64Encoder()],
      ["optionalRoyaltyPct", web3_js.getOptionEncoder(web3_js.getU16Encoder())],
      ["rulesAccPresent", web3_js.getBooleanEncoder()],
      [
        "authorizationData",
        web3_js.getOptionEncoder(getAuthorizationDataLocalEncoder())
      ]
    ]),
    (value) => ({
      ...value,
      discriminator: new Uint8Array([188, 35, 116, 108, 0, 233, 237, 201]),
      optionalRoyaltyPct: value.optionalRoyaltyPct ?? web3_js.none(),
      rulesAccPresent: value.rulesAccPresent ?? false,
      authorizationData: value.authorizationData ?? web3_js.none()
    })
  );
}
function getTakeBidLegacyInstructionDataDecoder() {
  return web3_js.getStructDecoder([
    ["discriminator", web3_js.fixDecoderSize(web3_js.getBytesDecoder(), 8)],
    ["minAmount", web3_js.getU64Decoder()],
    ["optionalRoyaltyPct", web3_js.getOptionDecoder(web3_js.getU16Decoder())],
    ["rulesAccPresent", web3_js.getBooleanDecoder()],
    ["authorizationData", web3_js.getOptionDecoder(getAuthorizationDataLocalDecoder())]
  ]);
}
function getTakeBidLegacyInstructionDataCodec() {
  return web3_js.combineCodec(
    getTakeBidLegacyInstructionDataEncoder(),
    getTakeBidLegacyInstructionDataDecoder()
  );
}
async function getTakeBidLegacyInstructionAsync(input) {
  const programAddress = TENSOR_MARKETPLACE_PROGRAM_ADDRESS;
  const originalAccounts = {
    feeVault: { value: input.feeVault ?? null, isWritable: true },
    seller: { value: input.seller ?? null, isWritable: true },
    bidState: { value: input.bidState ?? null, isWritable: true },
    owner: { value: input.owner ?? null, isWritable: true },
    takerBroker: { value: input.takerBroker ?? null, isWritable: true },
    makerBroker: { value: input.makerBroker ?? null, isWritable: true },
    sharedEscrow: { value: input.sharedEscrow ?? null, isWritable: true },
    whitelist: { value: input.whitelist ?? null, isWritable: false },
    sellerTa: { value: input.sellerTa ?? null, isWritable: true },
    mint: { value: input.mint ?? null, isWritable: false },
    metadata: { value: input.metadata ?? null, isWritable: true },
    ownerTa: { value: input.ownerTa ?? null, isWritable: true },
    edition: { value: input.edition ?? null, isWritable: false },
    sellerTokenRecord: {
      value: input.sellerTokenRecord ?? null,
      isWritable: true
    },
    ownerTokenRecord: {
      value: input.ownerTokenRecord ?? null,
      isWritable: true
    },
    tokenMetadataProgram: {
      value: input.tokenMetadataProgram ?? null,
      isWritable: false
    },
    sysvarInstructions: {
      value: input.sysvarInstructions ?? null,
      isWritable: false
    },
    authorizationRulesProgram: {
      value: input.authorizationRulesProgram ?? null,
      isWritable: false
    },
    bidTa: { value: input.bidTa ?? null, isWritable: true },
    bidTokenRecord: { value: input.bidTokenRecord ?? null, isWritable: true },
    authorizationRules: {
      value: input.authorizationRules ?? null,
      isWritable: false
    },
    tokenProgram: { value: input.tokenProgram ?? null, isWritable: false },
    associatedTokenProgram: {
      value: input.associatedTokenProgram ?? null,
      isWritable: false
    },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false },
    marketplaceProgram: {
      value: input.marketplaceProgram ?? null,
      isWritable: false
    },
    escrowProgram: { value: input.escrowProgram ?? null, isWritable: false },
    cosigner: { value: input.cosigner ?? null, isWritable: false },
    mintProof: { value: input.mintProof ?? null, isWritable: false },
    rentDestination: { value: input.rentDestination ?? null, isWritable: true }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  const resolverScope = { programAddress, accounts, args };
  if (!accounts.bidState.value) {
    accounts.bidState.value = await findBidStatePda({
      bidId: expectAddress(accounts.mint.value),
      owner: expectAddress(accounts.owner.value)
    });
  }
  if (!accounts.feeVault.value) {
    accounts.feeVault = {
      ...accounts.feeVault,
      ...await resolveFeeVaultPdaFromBidState(resolverScope)
    };
  }
  if (!accounts.sharedEscrow.value) {
    accounts.sharedEscrow.value = expectSome(accounts.owner.value);
  }
  if (!accounts.whitelist.value) {
    accounts.whitelist.value = "11111111111111111111111111111111";
  }
  if (!accounts.tokenProgram.value) {
    accounts.tokenProgram.value = "TokenkegQfeZyiNwAJbNbGKPFXCWuBvf9Ss623VQ5DA";
  }
  if (!accounts.sellerTa.value) {
    accounts.sellerTa = {
      ...accounts.sellerTa,
      ...await resolvers.resolveSellerAta(resolverScope)
    };
  }
  if (!accounts.metadata.value) {
    accounts.metadata = {
      ...accounts.metadata,
      ...await resolvers.resolveMetadata(resolverScope)
    };
  }
  if (!accounts.ownerTa.value) {
    accounts.ownerTa = {
      ...accounts.ownerTa,
      ...await resolvers.resolveOwnerAta(resolverScope)
    };
  }
  if (!args.tokenStandard) {
    args.tokenStandard = resolvers.TokenStandard.ProgrammableNonFungible;
  }
  if (!accounts.edition.value) {
    accounts.edition = {
      ...accounts.edition,
      ...await resolvers.resolveEditionFromTokenStandard(resolverScope)
    };
  }
  if (!accounts.sellerTokenRecord.value) {
    accounts.sellerTokenRecord = {
      ...accounts.sellerTokenRecord,
      ...await resolvers.resolveSellerTokenRecordFromTokenStandard(resolverScope)
    };
  }
  if (!accounts.ownerTokenRecord.value) {
    accounts.ownerTokenRecord = {
      ...accounts.ownerTokenRecord,
      ...await resolvers.resolveOwnerTokenRecordFromTokenStandard(resolverScope)
    };
  }
  if (!accounts.tokenMetadataProgram.value) {
    accounts.tokenMetadataProgram = {
      ...accounts.tokenMetadataProgram,
      ...resolvers.resolveTokenMetadataProgramFromTokenStandard(resolverScope)
    };
  }
  if (!accounts.sysvarInstructions.value) {
    accounts.sysvarInstructions = {
      ...accounts.sysvarInstructions,
      ...resolvers.resolveSysvarInstructionsFromTokenStandard(resolverScope)
    };
  }
  if (!accounts.authorizationRulesProgram.value) {
    accounts.authorizationRulesProgram = {
      ...accounts.authorizationRulesProgram,
      ...resolvers.resolveAuthorizationRulesProgramFromTokenStandard(resolverScope)
    };
  }
  if (!accounts.bidTa.value) {
    accounts.bidTa = {
      ...accounts.bidTa,
      ...await resolveBidTa(resolverScope)
    };
  }
  if (!accounts.bidTokenRecord.value) {
    accounts.bidTokenRecord = {
      ...accounts.bidTokenRecord,
      ...await resolvers.resolveBidTokenRecordFromTokenStandard(resolverScope)
    };
  }
  if (!accounts.associatedTokenProgram.value) {
    accounts.associatedTokenProgram.value = "ATokenGPvbdGVxr1b2hvZbsiqW5xWH25efTNsLJA8knL";
  }
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  if (!accounts.marketplaceProgram.value) {
    accounts.marketplaceProgram.value = "TCMPhJdwDryooaGtiocG1u3xcYbRpiJzb283XfCZsDp";
  }
  if (!accounts.escrowProgram.value) {
    accounts.escrowProgram.value = "TSWAPaqyCSx2KABk68Shruf4rp7CxcNi8hAsbdwmHbN";
  }
  if (!accounts.rentDestination.value) {
    accounts.rentDestination.value = expectSome(accounts.owner.value);
  }
  const remainingAccounts = (args.creators ?? []).map(
    (address3) => ({ address: address3, role: web3_js.AccountRole.WRITABLE })
  );
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.feeVault),
      getAccountMeta(accounts.seller),
      getAccountMeta(accounts.bidState),
      getAccountMeta(accounts.owner),
      getAccountMeta(accounts.takerBroker),
      getAccountMeta(accounts.makerBroker),
      getAccountMeta(accounts.sharedEscrow),
      getAccountMeta(accounts.whitelist),
      getAccountMeta(accounts.sellerTa),
      getAccountMeta(accounts.mint),
      getAccountMeta(accounts.metadata),
      getAccountMeta(accounts.ownerTa),
      getAccountMeta(accounts.edition),
      getAccountMeta(accounts.sellerTokenRecord),
      getAccountMeta(accounts.ownerTokenRecord),
      getAccountMeta(accounts.tokenMetadataProgram),
      getAccountMeta(accounts.sysvarInstructions),
      getAccountMeta(accounts.authorizationRulesProgram),
      getAccountMeta(accounts.bidTa),
      getAccountMeta(accounts.bidTokenRecord),
      getAccountMeta(accounts.authorizationRules),
      getAccountMeta(accounts.tokenProgram),
      getAccountMeta(accounts.associatedTokenProgram),
      getAccountMeta(accounts.systemProgram),
      getAccountMeta(accounts.marketplaceProgram),
      getAccountMeta(accounts.escrowProgram),
      getAccountMeta(accounts.cosigner),
      getAccountMeta(accounts.mintProof),
      getAccountMeta(accounts.rentDestination),
      ...remainingAccounts
    ],
    programAddress,
    data: getTakeBidLegacyInstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function getTakeBidLegacyInstruction(input) {
  const programAddress = TENSOR_MARKETPLACE_PROGRAM_ADDRESS;
  const originalAccounts = {
    feeVault: { value: input.feeVault ?? null, isWritable: true },
    seller: { value: input.seller ?? null, isWritable: true },
    bidState: { value: input.bidState ?? null, isWritable: true },
    owner: { value: input.owner ?? null, isWritable: true },
    takerBroker: { value: input.takerBroker ?? null, isWritable: true },
    makerBroker: { value: input.makerBroker ?? null, isWritable: true },
    sharedEscrow: { value: input.sharedEscrow ?? null, isWritable: true },
    whitelist: { value: input.whitelist ?? null, isWritable: false },
    sellerTa: { value: input.sellerTa ?? null, isWritable: true },
    mint: { value: input.mint ?? null, isWritable: false },
    metadata: { value: input.metadata ?? null, isWritable: true },
    ownerTa: { value: input.ownerTa ?? null, isWritable: true },
    edition: { value: input.edition ?? null, isWritable: false },
    sellerTokenRecord: {
      value: input.sellerTokenRecord ?? null,
      isWritable: true
    },
    ownerTokenRecord: {
      value: input.ownerTokenRecord ?? null,
      isWritable: true
    },
    tokenMetadataProgram: {
      value: input.tokenMetadataProgram ?? null,
      isWritable: false
    },
    sysvarInstructions: {
      value: input.sysvarInstructions ?? null,
      isWritable: false
    },
    authorizationRulesProgram: {
      value: input.authorizationRulesProgram ?? null,
      isWritable: false
    },
    bidTa: { value: input.bidTa ?? null, isWritable: true },
    bidTokenRecord: { value: input.bidTokenRecord ?? null, isWritable: true },
    authorizationRules: {
      value: input.authorizationRules ?? null,
      isWritable: false
    },
    tokenProgram: { value: input.tokenProgram ?? null, isWritable: false },
    associatedTokenProgram: {
      value: input.associatedTokenProgram ?? null,
      isWritable: false
    },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false },
    marketplaceProgram: {
      value: input.marketplaceProgram ?? null,
      isWritable: false
    },
    escrowProgram: { value: input.escrowProgram ?? null, isWritable: false },
    cosigner: { value: input.cosigner ?? null, isWritable: false },
    mintProof: { value: input.mintProof ?? null, isWritable: false },
    rentDestination: { value: input.rentDestination ?? null, isWritable: true }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  const resolverScope = { programAddress, accounts, args };
  if (!accounts.sharedEscrow.value) {
    accounts.sharedEscrow.value = expectSome(accounts.owner.value);
  }
  if (!accounts.whitelist.value) {
    accounts.whitelist.value = "11111111111111111111111111111111";
  }
  if (!accounts.tokenProgram.value) {
    accounts.tokenProgram.value = "TokenkegQfeZyiNwAJbNbGKPFXCWuBvf9Ss623VQ5DA";
  }
  if (!args.tokenStandard) {
    args.tokenStandard = resolvers.TokenStandard.ProgrammableNonFungible;
  }
  if (!accounts.tokenMetadataProgram.value) {
    accounts.tokenMetadataProgram = {
      ...accounts.tokenMetadataProgram,
      ...resolvers.resolveTokenMetadataProgramFromTokenStandard(resolverScope)
    };
  }
  if (!accounts.sysvarInstructions.value) {
    accounts.sysvarInstructions = {
      ...accounts.sysvarInstructions,
      ...resolvers.resolveSysvarInstructionsFromTokenStandard(resolverScope)
    };
  }
  if (!accounts.authorizationRulesProgram.value) {
    accounts.authorizationRulesProgram = {
      ...accounts.authorizationRulesProgram,
      ...resolvers.resolveAuthorizationRulesProgramFromTokenStandard(resolverScope)
    };
  }
  if (!accounts.associatedTokenProgram.value) {
    accounts.associatedTokenProgram.value = "ATokenGPvbdGVxr1b2hvZbsiqW5xWH25efTNsLJA8knL";
  }
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  if (!accounts.marketplaceProgram.value) {
    accounts.marketplaceProgram.value = "TCMPhJdwDryooaGtiocG1u3xcYbRpiJzb283XfCZsDp";
  }
  if (!accounts.escrowProgram.value) {
    accounts.escrowProgram.value = "TSWAPaqyCSx2KABk68Shruf4rp7CxcNi8hAsbdwmHbN";
  }
  if (!accounts.rentDestination.value) {
    accounts.rentDestination.value = expectSome(accounts.owner.value);
  }
  const remainingAccounts = (args.creators ?? []).map(
    (address3) => ({ address: address3, role: web3_js.AccountRole.WRITABLE })
  );
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.feeVault),
      getAccountMeta(accounts.seller),
      getAccountMeta(accounts.bidState),
      getAccountMeta(accounts.owner),
      getAccountMeta(accounts.takerBroker),
      getAccountMeta(accounts.makerBroker),
      getAccountMeta(accounts.sharedEscrow),
      getAccountMeta(accounts.whitelist),
      getAccountMeta(accounts.sellerTa),
      getAccountMeta(accounts.mint),
      getAccountMeta(accounts.metadata),
      getAccountMeta(accounts.ownerTa),
      getAccountMeta(accounts.edition),
      getAccountMeta(accounts.sellerTokenRecord),
      getAccountMeta(accounts.ownerTokenRecord),
      getAccountMeta(accounts.tokenMetadataProgram),
      getAccountMeta(accounts.sysvarInstructions),
      getAccountMeta(accounts.authorizationRulesProgram),
      getAccountMeta(accounts.bidTa),
      getAccountMeta(accounts.bidTokenRecord),
      getAccountMeta(accounts.authorizationRules),
      getAccountMeta(accounts.tokenProgram),
      getAccountMeta(accounts.associatedTokenProgram),
      getAccountMeta(accounts.systemProgram),
      getAccountMeta(accounts.marketplaceProgram),
      getAccountMeta(accounts.escrowProgram),
      getAccountMeta(accounts.cosigner),
      getAccountMeta(accounts.mintProof),
      getAccountMeta(accounts.rentDestination),
      ...remainingAccounts
    ],
    programAddress,
    data: getTakeBidLegacyInstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function parseTakeBidLegacyInstruction(instruction) {
  if (instruction.accounts.length < 29) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  const getNextOptionalAccount = () => {
    const accountMeta = getNextAccount();
    return accountMeta.address === TENSOR_MARKETPLACE_PROGRAM_ADDRESS ? void 0 : accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      feeVault: getNextAccount(),
      seller: getNextAccount(),
      bidState: getNextAccount(),
      owner: getNextAccount(),
      takerBroker: getNextOptionalAccount(),
      makerBroker: getNextOptionalAccount(),
      sharedEscrow: getNextAccount(),
      whitelist: getNextOptionalAccount(),
      sellerTa: getNextAccount(),
      mint: getNextAccount(),
      metadata: getNextAccount(),
      ownerTa: getNextAccount(),
      edition: getNextAccount(),
      sellerTokenRecord: getNextOptionalAccount(),
      ownerTokenRecord: getNextOptionalAccount(),
      tokenMetadataProgram: getNextOptionalAccount(),
      sysvarInstructions: getNextOptionalAccount(),
      authorizationRulesProgram: getNextOptionalAccount(),
      bidTa: getNextAccount(),
      bidTokenRecord: getNextOptionalAccount(),
      authorizationRules: getNextOptionalAccount(),
      tokenProgram: getNextAccount(),
      associatedTokenProgram: getNextAccount(),
      systemProgram: getNextAccount(),
      marketplaceProgram: getNextAccount(),
      escrowProgram: getNextAccount(),
      cosigner: getNextOptionalAccount(),
      mintProof: getNextOptionalAccount(),
      rentDestination: getNextAccount()
    },
    data: getTakeBidLegacyInstructionDataDecoder().decode(instruction.data)
  };
}
function getTakeBidT22InstructionDataEncoder() {
  return web3_js.transformEncoder(
    web3_js.getStructEncoder([
      ["discriminator", web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 8)],
      ["minAmount", web3_js.getU64Encoder()]
    ]),
    (value) => ({
      ...value,
      discriminator: new Uint8Array([18, 250, 113, 242, 31, 244, 19, 150])
    })
  );
}
function getTakeBidT22InstructionDataDecoder() {
  return web3_js.getStructDecoder([
    ["discriminator", web3_js.fixDecoderSize(web3_js.getBytesDecoder(), 8)],
    ["minAmount", web3_js.getU64Decoder()]
  ]);
}
function getTakeBidT22InstructionDataCodec() {
  return web3_js.combineCodec(
    getTakeBidT22InstructionDataEncoder(),
    getTakeBidT22InstructionDataDecoder()
  );
}
function getTakeBidT22Instruction(input) {
  const programAddress = TENSOR_MARKETPLACE_PROGRAM_ADDRESS;
  const originalAccounts = {
    feeVault: { value: input.feeVault ?? null, isWritable: true },
    seller: { value: input.seller ?? null, isWritable: true },
    bidState: { value: input.bidState ?? null, isWritable: true },
    owner: { value: input.owner ?? null, isWritable: true },
    takerBroker: { value: input.takerBroker ?? null, isWritable: true },
    makerBroker: { value: input.makerBroker ?? null, isWritable: true },
    marginAccount: { value: input.marginAccount ?? null, isWritable: true },
    whitelist: { value: input.whitelist ?? null, isWritable: false },
    sellerTa: { value: input.sellerTa ?? null, isWritable: true },
    mint: { value: input.mint ?? null, isWritable: false },
    ownerTa: { value: input.ownerTa ?? null, isWritable: true },
    tokenProgram: { value: input.tokenProgram ?? null, isWritable: false },
    associatedTokenProgram: {
      value: input.associatedTokenProgram ?? null,
      isWritable: false
    },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false },
    marketplaceProgram: {
      value: input.marketplaceProgram ?? null,
      isWritable: false
    },
    escrowProgram: { value: input.escrowProgram ?? null, isWritable: false },
    cosigner: { value: input.cosigner ?? null, isWritable: false },
    mintProof: { value: input.mintProof ?? null, isWritable: false },
    rentDestination: { value: input.rentDestination ?? null, isWritable: true }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  if (!accounts.tokenProgram.value) {
    accounts.tokenProgram.value = "TokenkegQfeZyiNwAJbNbGKPFXCWuBvf9Ss623VQ5DA";
  }
  if (!accounts.associatedTokenProgram.value) {
    accounts.associatedTokenProgram.value = "ATokenGPvbdGVxr1b2hvZbsiqW5xWH25efTNsLJA8knL";
  }
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  if (!accounts.marketplaceProgram.value) {
    accounts.marketplaceProgram.value = "TCMPhJdwDryooaGtiocG1u3xcYbRpiJzb283XfCZsDp";
  }
  if (!accounts.escrowProgram.value) {
    accounts.escrowProgram.value = "TSWAPaqyCSx2KABk68Shruf4rp7CxcNi8hAsbdwmHbN";
  }
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.feeVault),
      getAccountMeta(accounts.seller),
      getAccountMeta(accounts.bidState),
      getAccountMeta(accounts.owner),
      getAccountMeta(accounts.takerBroker),
      getAccountMeta(accounts.makerBroker),
      getAccountMeta(accounts.marginAccount),
      getAccountMeta(accounts.whitelist),
      getAccountMeta(accounts.sellerTa),
      getAccountMeta(accounts.mint),
      getAccountMeta(accounts.ownerTa),
      getAccountMeta(accounts.tokenProgram),
      getAccountMeta(accounts.associatedTokenProgram),
      getAccountMeta(accounts.systemProgram),
      getAccountMeta(accounts.marketplaceProgram),
      getAccountMeta(accounts.escrowProgram),
      getAccountMeta(accounts.cosigner),
      getAccountMeta(accounts.mintProof),
      getAccountMeta(accounts.rentDestination)
    ],
    programAddress,
    data: getTakeBidT22InstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function parseTakeBidT22Instruction(instruction) {
  if (instruction.accounts.length < 19) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  const getNextOptionalAccount = () => {
    const accountMeta = getNextAccount();
    return accountMeta.address === TENSOR_MARKETPLACE_PROGRAM_ADDRESS ? void 0 : accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      feeVault: getNextAccount(),
      seller: getNextAccount(),
      bidState: getNextAccount(),
      owner: getNextAccount(),
      takerBroker: getNextOptionalAccount(),
      makerBroker: getNextOptionalAccount(),
      marginAccount: getNextAccount(),
      whitelist: getNextAccount(),
      sellerTa: getNextAccount(),
      mint: getNextAccount(),
      ownerTa: getNextAccount(),
      tokenProgram: getNextAccount(),
      associatedTokenProgram: getNextAccount(),
      systemProgram: getNextAccount(),
      marketplaceProgram: getNextAccount(),
      escrowProgram: getNextAccount(),
      cosigner: getNextOptionalAccount(),
      mintProof: getNextAccount(),
      rentDestination: getNextAccount()
    },
    data: getTakeBidT22InstructionDataDecoder().decode(instruction.data)
  };
}
function getTakeBidWnsInstructionDataEncoder() {
  return web3_js.transformEncoder(
    web3_js.getStructEncoder([
      ["discriminator", web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 8)],
      ["minAmount", web3_js.getU64Encoder()]
    ]),
    (value) => ({
      ...value,
      discriminator: new Uint8Array([88, 5, 122, 88, 250, 139, 35, 216])
    })
  );
}
function getTakeBidWnsInstructionDataDecoder() {
  return web3_js.getStructDecoder([
    ["discriminator", web3_js.fixDecoderSize(web3_js.getBytesDecoder(), 8)],
    ["minAmount", web3_js.getU64Decoder()]
  ]);
}
function getTakeBidWnsInstructionDataCodec() {
  return web3_js.combineCodec(
    getTakeBidWnsInstructionDataEncoder(),
    getTakeBidWnsInstructionDataDecoder()
  );
}
function getTakeBidWnsInstruction(input) {
  const programAddress = TENSOR_MARKETPLACE_PROGRAM_ADDRESS;
  const originalAccounts = {
    feeVault: { value: input.feeVault ?? null, isWritable: true },
    seller: { value: input.seller ?? null, isWritable: true },
    bidState: { value: input.bidState ?? null, isWritable: true },
    owner: { value: input.owner ?? null, isWritable: true },
    takerBroker: { value: input.takerBroker ?? null, isWritable: true },
    makerBroker: { value: input.makerBroker ?? null, isWritable: true },
    marginAccount: { value: input.marginAccount ?? null, isWritable: true },
    whitelist: { value: input.whitelist ?? null, isWritable: false },
    sellerTa: { value: input.sellerTa ?? null, isWritable: true },
    mint: { value: input.mint ?? null, isWritable: false },
    ownerTa: { value: input.ownerTa ?? null, isWritable: true },
    tokenProgram: { value: input.tokenProgram ?? null, isWritable: false },
    associatedTokenProgram: {
      value: input.associatedTokenProgram ?? null,
      isWritable: false
    },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false },
    marketplaceProgram: {
      value: input.marketplaceProgram ?? null,
      isWritable: false
    },
    escrowProgram: { value: input.escrowProgram ?? null, isWritable: false },
    cosigner: { value: input.cosigner ?? null, isWritable: false },
    mintProof: { value: input.mintProof ?? null, isWritable: false },
    rentDestination: { value: input.rentDestination ?? null, isWritable: true },
    approveAccount: { value: input.approveAccount ?? null, isWritable: true },
    distribution: { value: input.distribution ?? null, isWritable: true },
    wnsProgram: { value: input.wnsProgram ?? null, isWritable: false },
    distributionProgram: {
      value: input.distributionProgram ?? null,
      isWritable: false
    },
    extraMetas: { value: input.extraMetas ?? null, isWritable: false }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  if (!accounts.tokenProgram.value) {
    accounts.tokenProgram.value = "TokenkegQfeZyiNwAJbNbGKPFXCWuBvf9Ss623VQ5DA";
  }
  if (!accounts.associatedTokenProgram.value) {
    accounts.associatedTokenProgram.value = "ATokenGPvbdGVxr1b2hvZbsiqW5xWH25efTNsLJA8knL";
  }
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  if (!accounts.marketplaceProgram.value) {
    accounts.marketplaceProgram.value = "TCMPhJdwDryooaGtiocG1u3xcYbRpiJzb283XfCZsDp";
  }
  if (!accounts.escrowProgram.value) {
    accounts.escrowProgram.value = "TSWAPaqyCSx2KABk68Shruf4rp7CxcNi8hAsbdwmHbN";
  }
  if (!accounts.wnsProgram.value) {
    accounts.wnsProgram.value = "wns1gDLt8fgLcGhWi5MqAqgXpwEP1JftKE9eZnXS1HM";
  }
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.feeVault),
      getAccountMeta(accounts.seller),
      getAccountMeta(accounts.bidState),
      getAccountMeta(accounts.owner),
      getAccountMeta(accounts.takerBroker),
      getAccountMeta(accounts.makerBroker),
      getAccountMeta(accounts.marginAccount),
      getAccountMeta(accounts.whitelist),
      getAccountMeta(accounts.sellerTa),
      getAccountMeta(accounts.mint),
      getAccountMeta(accounts.ownerTa),
      getAccountMeta(accounts.tokenProgram),
      getAccountMeta(accounts.associatedTokenProgram),
      getAccountMeta(accounts.systemProgram),
      getAccountMeta(accounts.marketplaceProgram),
      getAccountMeta(accounts.escrowProgram),
      getAccountMeta(accounts.cosigner),
      getAccountMeta(accounts.mintProof),
      getAccountMeta(accounts.rentDestination),
      getAccountMeta(accounts.approveAccount),
      getAccountMeta(accounts.distribution),
      getAccountMeta(accounts.wnsProgram),
      getAccountMeta(accounts.distributionProgram),
      getAccountMeta(accounts.extraMetas)
    ],
    programAddress,
    data: getTakeBidWnsInstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function parseTakeBidWnsInstruction(instruction) {
  if (instruction.accounts.length < 24) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  const getNextOptionalAccount = () => {
    const accountMeta = getNextAccount();
    return accountMeta.address === TENSOR_MARKETPLACE_PROGRAM_ADDRESS ? void 0 : accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      feeVault: getNextAccount(),
      seller: getNextAccount(),
      bidState: getNextAccount(),
      owner: getNextAccount(),
      takerBroker: getNextOptionalAccount(),
      makerBroker: getNextOptionalAccount(),
      marginAccount: getNextAccount(),
      whitelist: getNextAccount(),
      sellerTa: getNextAccount(),
      mint: getNextAccount(),
      ownerTa: getNextAccount(),
      tokenProgram: getNextAccount(),
      associatedTokenProgram: getNextAccount(),
      systemProgram: getNextAccount(),
      marketplaceProgram: getNextAccount(),
      escrowProgram: getNextAccount(),
      cosigner: getNextOptionalAccount(),
      mintProof: getNextAccount(),
      rentDestination: getNextAccount(),
      approveAccount: getNextAccount(),
      distribution: getNextAccount(),
      wnsProgram: getNextAccount(),
      distributionProgram: getNextAccount(),
      extraMetas: getNextAccount()
    },
    data: getTakeBidWnsInstructionDataDecoder().decode(instruction.data)
  };
}
function getTcompNoopInstructionDataEncoder() {
  return web3_js.transformEncoder(
    web3_js.getStructEncoder([
      ["discriminator", web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 8)],
      ["event", getTcompEventEncoder()]
    ]),
    (value) => ({
      ...value,
      discriminator: new Uint8Array([106, 162, 10, 226, 132, 68, 223, 21])
    })
  );
}
function getTcompNoopInstructionDataDecoder() {
  return web3_js.getStructDecoder([
    ["discriminator", web3_js.fixDecoderSize(web3_js.getBytesDecoder(), 8)],
    ["event", getTcompEventDecoder()]
  ]);
}
function getTcompNoopInstructionDataCodec() {
  return web3_js.combineCodec(
    getTcompNoopInstructionDataEncoder(),
    getTcompNoopInstructionDataDecoder()
  );
}
function getTcompNoopInstruction(input) {
  const programAddress = TENSOR_MARKETPLACE_PROGRAM_ADDRESS;
  const originalAccounts = {
    tcompSigner: { value: input.tcompSigner ?? null, isWritable: false }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [getAccountMeta(accounts.tcompSigner)],
    programAddress,
    data: getTcompNoopInstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function parseTcompNoopInstruction(instruction) {
  if (instruction.accounts.length < 1) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      tcompSigner: getNextAccount()
    },
    data: getTcompNoopInstructionDataDecoder().decode(instruction.data)
  };
}

exports.Field = Field;
exports.TENSOR_MARKETPLACE_ERROR__ARITHMETIC_ERROR = TENSOR_MARKETPLACE_ERROR__ARITHMETIC_ERROR;
exports.TENSOR_MARKETPLACE_ERROR__ASSET_ID_MISMATCH = TENSOR_MARKETPLACE_ERROR__ASSET_ID_MISMATCH;
exports.TENSOR_MARKETPLACE_ERROR__BAD_BID_FIELD = TENSOR_MARKETPLACE_ERROR__BAD_BID_FIELD;
exports.TENSOR_MARKETPLACE_ERROR__BAD_COSIGNER = TENSOR_MARKETPLACE_ERROR__BAD_COSIGNER;
exports.TENSOR_MARKETPLACE_ERROR__BAD_LIST_STATE = TENSOR_MARKETPLACE_ERROR__BAD_LIST_STATE;
exports.TENSOR_MARKETPLACE_ERROR__BAD_MARGIN = TENSOR_MARKETPLACE_ERROR__BAD_MARGIN;
exports.TENSOR_MARKETPLACE_ERROR__BAD_MINT_PROOF = TENSOR_MARKETPLACE_ERROR__BAD_MINT_PROOF;
exports.TENSOR_MARKETPLACE_ERROR__BAD_OWNER = TENSOR_MARKETPLACE_ERROR__BAD_OWNER;
exports.TENSOR_MARKETPLACE_ERROR__BAD_QUANTITY = TENSOR_MARKETPLACE_ERROR__BAD_QUANTITY;
exports.TENSOR_MARKETPLACE_ERROR__BAD_RENT_DEST = TENSOR_MARKETPLACE_ERROR__BAD_RENT_DEST;
exports.TENSOR_MARKETPLACE_ERROR__BAD_ROYALTIES_PCT = TENSOR_MARKETPLACE_ERROR__BAD_ROYALTIES_PCT;
exports.TENSOR_MARKETPLACE_ERROR__BAD_WHITELIST = TENSOR_MARKETPLACE_ERROR__BAD_WHITELIST;
exports.TENSOR_MARKETPLACE_ERROR__BID_BALANCE_NOT_EMPTIED = TENSOR_MARKETPLACE_ERROR__BID_BALANCE_NOT_EMPTIED;
exports.TENSOR_MARKETPLACE_ERROR__BID_EXPIRED = TENSOR_MARKETPLACE_ERROR__BID_EXPIRED;
exports.TENSOR_MARKETPLACE_ERROR__BID_FULLY_FILLED = TENSOR_MARKETPLACE_ERROR__BID_FULLY_FILLED;
exports.TENSOR_MARKETPLACE_ERROR__BID_NOT_YET_EXPIRED = TENSOR_MARKETPLACE_ERROR__BID_NOT_YET_EXPIRED;
exports.TENSOR_MARKETPLACE_ERROR__BROKER_MISMATCH = TENSOR_MARKETPLACE_ERROR__BROKER_MISMATCH;
exports.TENSOR_MARKETPLACE_ERROR__CANNOT_MODIFY_TARGET = TENSOR_MARKETPLACE_ERROR__CANNOT_MODIFY_TARGET;
exports.TENSOR_MARKETPLACE_ERROR__CREATOR_MISMATCH = TENSOR_MARKETPLACE_ERROR__CREATOR_MISMATCH;
exports.TENSOR_MARKETPLACE_ERROR__CURRENCY_MISMATCH = TENSOR_MARKETPLACE_ERROR__CURRENCY_MISMATCH;
exports.TENSOR_MARKETPLACE_ERROR__CURRENCY_NOT_YET_ENABLED = TENSOR_MARKETPLACE_ERROR__CURRENCY_NOT_YET_ENABLED;
exports.TENSOR_MARKETPLACE_ERROR__CURRENCY_NOT_YET_WHITELISTED = TENSOR_MARKETPLACE_ERROR__CURRENCY_NOT_YET_WHITELISTED;
exports.TENSOR_MARKETPLACE_ERROR__EXPIRY_TOO_LARGE = TENSOR_MARKETPLACE_ERROR__EXPIRY_TOO_LARGE;
exports.TENSOR_MARKETPLACE_ERROR__FORBIDDEN_COLLECTION = TENSOR_MARKETPLACE_ERROR__FORBIDDEN_COLLECTION;
exports.TENSOR_MARKETPLACE_ERROR__INSUFFICIENT_BALANCE = TENSOR_MARKETPLACE_ERROR__INSUFFICIENT_BALANCE;
exports.TENSOR_MARKETPLACE_ERROR__INSUFFICIENT_REMAINING_ACCOUNTS = TENSOR_MARKETPLACE_ERROR__INSUFFICIENT_REMAINING_ACCOUNTS;
exports.TENSOR_MARKETPLACE_ERROR__INVALID_FEE_ACCOUNT = TENSOR_MARKETPLACE_ERROR__INVALID_FEE_ACCOUNT;
exports.TENSOR_MARKETPLACE_ERROR__INVALID_TOKEN_ACCOUNT = TENSOR_MARKETPLACE_ERROR__INVALID_TOKEN_ACCOUNT;
exports.TENSOR_MARKETPLACE_ERROR__LISTING_EXPIRED = TENSOR_MARKETPLACE_ERROR__LISTING_EXPIRED;
exports.TENSOR_MARKETPLACE_ERROR__LISTING_NOT_YET_EXPIRED = TENSOR_MARKETPLACE_ERROR__LISTING_NOT_YET_EXPIRED;
exports.TENSOR_MARKETPLACE_ERROR__MAKER_BROKER_NOT_YET_ENABLED = TENSOR_MARKETPLACE_ERROR__MAKER_BROKER_NOT_YET_ENABLED;
exports.TENSOR_MARKETPLACE_ERROR__MAKER_BROKER_NOT_YET_WHITELISTED = TENSOR_MARKETPLACE_ERROR__MAKER_BROKER_NOT_YET_WHITELISTED;
exports.TENSOR_MARKETPLACE_ERROR__MISSING_BROKER = TENSOR_MARKETPLACE_ERROR__MISSING_BROKER;
exports.TENSOR_MARKETPLACE_ERROR__MISSING_BROKER_TOKEN_ACCOUNT = TENSOR_MARKETPLACE_ERROR__MISSING_BROKER_TOKEN_ACCOUNT;
exports.TENSOR_MARKETPLACE_ERROR__MISSING_COLLECTION = TENSOR_MARKETPLACE_ERROR__MISSING_COLLECTION;
exports.TENSOR_MARKETPLACE_ERROR__MISSING_FVC = TENSOR_MARKETPLACE_ERROR__MISSING_FVC;
exports.TENSOR_MARKETPLACE_ERROR__OPTIONAL_ROYALTIES_NOT_YET_ENABLED = TENSOR_MARKETPLACE_ERROR__OPTIONAL_ROYALTIES_NOT_YET_ENABLED;
exports.TENSOR_MARKETPLACE_ERROR__PRICE_MISMATCH = TENSOR_MARKETPLACE_ERROR__PRICE_MISMATCH;
exports.TENSOR_MARKETPLACE_ERROR__TAKER_NOT_ALLOWED = TENSOR_MARKETPLACE_ERROR__TAKER_NOT_ALLOWED;
exports.TENSOR_MARKETPLACE_ERROR__TARGET_ID_MUST_EQUAL_BID_ID = TENSOR_MARKETPLACE_ERROR__TARGET_ID_MUST_EQUAL_BID_ID;
exports.TENSOR_MARKETPLACE_ERROR__WRONG_BID_FIELD_ID = TENSOR_MARKETPLACE_ERROR__WRONG_BID_FIELD_ID;
exports.TENSOR_MARKETPLACE_ERROR__WRONG_IX_FOR_BID_TARGET = TENSOR_MARKETPLACE_ERROR__WRONG_IX_FOR_BID_TARGET;
exports.TENSOR_MARKETPLACE_ERROR__WRONG_STATE_VERSION = TENSOR_MARKETPLACE_ERROR__WRONG_STATE_VERSION;
exports.TENSOR_MARKETPLACE_ERROR__WRONG_TARGET_ID = TENSOR_MARKETPLACE_ERROR__WRONG_TARGET_ID;
exports.TENSOR_MARKETPLACE_ERROR__WRONG_TOKEN_RECORD_DERIVATION = TENSOR_MARKETPLACE_ERROR__WRONG_TOKEN_RECORD_DERIVATION;
exports.TENSOR_MARKETPLACE_PROGRAM_ADDRESS = TENSOR_MARKETPLACE_PROGRAM_ADDRESS;
exports.TTokenProgramVersion = TTokenProgramVersion;
exports.TTokenStandard = TTokenStandard;
exports.TUseMethod = TUseMethod;
exports.Target = Target;
exports.TensorMarketplaceAccount = TensorMarketplaceAccount;
exports.TensorMarketplaceInstruction = TensorMarketplaceInstruction;
exports.decodeBidState = decodeBidState;
exports.decodeBidTa = decodeBidTa;
exports.decodeListState = decodeListState;
exports.fetchAllBidState = fetchAllBidState;
exports.fetchAllBidTa = fetchAllBidTa;
exports.fetchAllListState = fetchAllListState;
exports.fetchAllMaybeBidState = fetchAllMaybeBidState;
exports.fetchAllMaybeBidTa = fetchAllMaybeBidTa;
exports.fetchAllMaybeListState = fetchAllMaybeListState;
exports.fetchBidState = fetchBidState;
exports.fetchBidStateFromSeeds = fetchBidStateFromSeeds;
exports.fetchBidTa = fetchBidTa;
exports.fetchBidTaFromSeeds = fetchBidTaFromSeeds;
exports.fetchListState = fetchListState;
exports.fetchListStateFromSeeds = fetchListStateFromSeeds;
exports.fetchMaybeBidState = fetchMaybeBidState;
exports.fetchMaybeBidStateFromSeeds = fetchMaybeBidStateFromSeeds;
exports.fetchMaybeBidTa = fetchMaybeBidTa;
exports.fetchMaybeBidTaFromSeeds = fetchMaybeBidTaFromSeeds;
exports.fetchMaybeListState = fetchMaybeListState;
exports.fetchMaybeListStateFromSeeds = fetchMaybeListStateFromSeeds;
exports.findBidStatePda = findBidStatePda;
exports.findBidTaPda = findBidTaPda;
exports.findFeeVaultPda = findFeeVaultPda;
exports.findListStatePda = findListStatePda;
exports.findTreeAuthorityPda = findTreeAuthorityPda;
exports.getAuthorizationDataLocalCodec = getAuthorizationDataLocalCodec;
exports.getAuthorizationDataLocalDecoder = getAuthorizationDataLocalDecoder;
exports.getAuthorizationDataLocalEncoder = getAuthorizationDataLocalEncoder;
exports.getBidInstruction = getBidInstruction;
exports.getBidInstructionAsync = getBidInstructionAsync;
exports.getBidInstructionDataCodec = getBidInstructionDataCodec;
exports.getBidInstructionDataDecoder = getBidInstructionDataDecoder;
exports.getBidInstructionDataEncoder = getBidInstructionDataEncoder;
exports.getBidStateCodec = getBidStateCodec;
exports.getBidStateDecoder = getBidStateDecoder;
exports.getBidStateEncoder = getBidStateEncoder;
exports.getBidTaCodec = getBidTaCodec;
exports.getBidTaDecoder = getBidTaDecoder;
exports.getBidTaEncoder = getBidTaEncoder;
exports.getBidTaSize = getBidTaSize;
exports.getBuyCompressedInstruction = getBuyCompressedInstruction;
exports.getBuyCompressedInstructionAsync = getBuyCompressedInstructionAsync;
exports.getBuyCompressedInstructionDataCodec = getBuyCompressedInstructionDataCodec;
exports.getBuyCompressedInstructionDataDecoder = getBuyCompressedInstructionDataDecoder;
exports.getBuyCompressedInstructionDataEncoder = getBuyCompressedInstructionDataEncoder;
exports.getBuyCoreInstruction = getBuyCoreInstruction;
exports.getBuyCoreInstructionDataCodec = getBuyCoreInstructionDataCodec;
exports.getBuyCoreInstructionDataDecoder = getBuyCoreInstructionDataDecoder;
exports.getBuyCoreInstructionDataEncoder = getBuyCoreInstructionDataEncoder;
exports.getBuyCoreSplInstruction = getBuyCoreSplInstruction;
exports.getBuyCoreSplInstructionDataCodec = getBuyCoreSplInstructionDataCodec;
exports.getBuyCoreSplInstructionDataDecoder = getBuyCoreSplInstructionDataDecoder;
exports.getBuyCoreSplInstructionDataEncoder = getBuyCoreSplInstructionDataEncoder;
exports.getBuyLegacyInstruction = getBuyLegacyInstruction;
exports.getBuyLegacyInstructionAsync = getBuyLegacyInstructionAsync;
exports.getBuyLegacyInstructionDataCodec = getBuyLegacyInstructionDataCodec;
exports.getBuyLegacyInstructionDataDecoder = getBuyLegacyInstructionDataDecoder;
exports.getBuyLegacyInstructionDataEncoder = getBuyLegacyInstructionDataEncoder;
exports.getBuyLegacySplInstruction = getBuyLegacySplInstruction;
exports.getBuyLegacySplInstructionAsync = getBuyLegacySplInstructionAsync;
exports.getBuyLegacySplInstructionDataCodec = getBuyLegacySplInstructionDataCodec;
exports.getBuyLegacySplInstructionDataDecoder = getBuyLegacySplInstructionDataDecoder;
exports.getBuyLegacySplInstructionDataEncoder = getBuyLegacySplInstructionDataEncoder;
exports.getBuySplInstruction = getBuySplInstruction;
exports.getBuySplInstructionAsync = getBuySplInstructionAsync;
exports.getBuySplInstructionDataCodec = getBuySplInstructionDataCodec;
exports.getBuySplInstructionDataDecoder = getBuySplInstructionDataDecoder;
exports.getBuySplInstructionDataEncoder = getBuySplInstructionDataEncoder;
exports.getBuyT22Instruction = getBuyT22Instruction;
exports.getBuyT22InstructionAsync = getBuyT22InstructionAsync;
exports.getBuyT22InstructionDataCodec = getBuyT22InstructionDataCodec;
exports.getBuyT22InstructionDataDecoder = getBuyT22InstructionDataDecoder;
exports.getBuyT22InstructionDataEncoder = getBuyT22InstructionDataEncoder;
exports.getBuyT22SplInstruction = getBuyT22SplInstruction;
exports.getBuyT22SplInstructionAsync = getBuyT22SplInstructionAsync;
exports.getBuyT22SplInstructionDataCodec = getBuyT22SplInstructionDataCodec;
exports.getBuyT22SplInstructionDataDecoder = getBuyT22SplInstructionDataDecoder;
exports.getBuyT22SplInstructionDataEncoder = getBuyT22SplInstructionDataEncoder;
exports.getBuyWnsInstruction = getBuyWnsInstruction;
exports.getBuyWnsInstructionAsync = getBuyWnsInstructionAsync;
exports.getBuyWnsInstructionDataCodec = getBuyWnsInstructionDataCodec;
exports.getBuyWnsInstructionDataDecoder = getBuyWnsInstructionDataDecoder;
exports.getBuyWnsInstructionDataEncoder = getBuyWnsInstructionDataEncoder;
exports.getBuyWnsSplInstruction = getBuyWnsSplInstruction;
exports.getBuyWnsSplInstructionDataCodec = getBuyWnsSplInstructionDataCodec;
exports.getBuyWnsSplInstructionDataDecoder = getBuyWnsSplInstructionDataDecoder;
exports.getBuyWnsSplInstructionDataEncoder = getBuyWnsSplInstructionDataEncoder;
exports.getCancelBidInstruction = getCancelBidInstruction;
exports.getCancelBidInstructionAsync = getCancelBidInstructionAsync;
exports.getCancelBidInstructionDataCodec = getCancelBidInstructionDataCodec;
exports.getCancelBidInstructionDataDecoder = getCancelBidInstructionDataDecoder;
exports.getCancelBidInstructionDataEncoder = getCancelBidInstructionDataEncoder;
exports.getCloseExpiredBidInstruction = getCloseExpiredBidInstruction;
exports.getCloseExpiredBidInstructionAsync = getCloseExpiredBidInstructionAsync;
exports.getCloseExpiredBidInstructionDataCodec = getCloseExpiredBidInstructionDataCodec;
exports.getCloseExpiredBidInstructionDataDecoder = getCloseExpiredBidInstructionDataDecoder;
exports.getCloseExpiredBidInstructionDataEncoder = getCloseExpiredBidInstructionDataEncoder;
exports.getCloseExpiredListingCompressedInstruction = getCloseExpiredListingCompressedInstruction;
exports.getCloseExpiredListingCompressedInstructionAsync = getCloseExpiredListingCompressedInstructionAsync;
exports.getCloseExpiredListingCompressedInstructionDataCodec = getCloseExpiredListingCompressedInstructionDataCodec;
exports.getCloseExpiredListingCompressedInstructionDataDecoder = getCloseExpiredListingCompressedInstructionDataDecoder;
exports.getCloseExpiredListingCompressedInstructionDataEncoder = getCloseExpiredListingCompressedInstructionDataEncoder;
exports.getCloseExpiredListingCoreInstruction = getCloseExpiredListingCoreInstruction;
exports.getCloseExpiredListingCoreInstructionDataCodec = getCloseExpiredListingCoreInstructionDataCodec;
exports.getCloseExpiredListingCoreInstructionDataDecoder = getCloseExpiredListingCoreInstructionDataDecoder;
exports.getCloseExpiredListingCoreInstructionDataEncoder = getCloseExpiredListingCoreInstructionDataEncoder;
exports.getCloseExpiredListingLegacyInstruction = getCloseExpiredListingLegacyInstruction;
exports.getCloseExpiredListingLegacyInstructionAsync = getCloseExpiredListingLegacyInstructionAsync;
exports.getCloseExpiredListingLegacyInstructionDataCodec = getCloseExpiredListingLegacyInstructionDataCodec;
exports.getCloseExpiredListingLegacyInstructionDataDecoder = getCloseExpiredListingLegacyInstructionDataDecoder;
exports.getCloseExpiredListingLegacyInstructionDataEncoder = getCloseExpiredListingLegacyInstructionDataEncoder;
exports.getCloseExpiredListingT22Instruction = getCloseExpiredListingT22Instruction;
exports.getCloseExpiredListingT22InstructionAsync = getCloseExpiredListingT22InstructionAsync;
exports.getCloseExpiredListingT22InstructionDataCodec = getCloseExpiredListingT22InstructionDataCodec;
exports.getCloseExpiredListingT22InstructionDataDecoder = getCloseExpiredListingT22InstructionDataDecoder;
exports.getCloseExpiredListingT22InstructionDataEncoder = getCloseExpiredListingT22InstructionDataEncoder;
exports.getCloseExpiredListingWnsInstruction = getCloseExpiredListingWnsInstruction;
exports.getCloseExpiredListingWnsInstructionAsync = getCloseExpiredListingWnsInstructionAsync;
exports.getCloseExpiredListingWnsInstructionDataCodec = getCloseExpiredListingWnsInstructionDataCodec;
exports.getCloseExpiredListingWnsInstructionDataDecoder = getCloseExpiredListingWnsInstructionDataDecoder;
exports.getCloseExpiredListingWnsInstructionDataEncoder = getCloseExpiredListingWnsInstructionDataEncoder;
exports.getDelistCompressedInstruction = getDelistCompressedInstruction;
exports.getDelistCompressedInstructionAsync = getDelistCompressedInstructionAsync;
exports.getDelistCompressedInstructionDataCodec = getDelistCompressedInstructionDataCodec;
exports.getDelistCompressedInstructionDataDecoder = getDelistCompressedInstructionDataDecoder;
exports.getDelistCompressedInstructionDataEncoder = getDelistCompressedInstructionDataEncoder;
exports.getDelistCoreInstruction = getDelistCoreInstruction;
exports.getDelistCoreInstructionDataCodec = getDelistCoreInstructionDataCodec;
exports.getDelistCoreInstructionDataDecoder = getDelistCoreInstructionDataDecoder;
exports.getDelistCoreInstructionDataEncoder = getDelistCoreInstructionDataEncoder;
exports.getDelistLegacyInstruction = getDelistLegacyInstruction;
exports.getDelistLegacyInstructionAsync = getDelistLegacyInstructionAsync;
exports.getDelistLegacyInstructionDataCodec = getDelistLegacyInstructionDataCodec;
exports.getDelistLegacyInstructionDataDecoder = getDelistLegacyInstructionDataDecoder;
exports.getDelistLegacyInstructionDataEncoder = getDelistLegacyInstructionDataEncoder;
exports.getDelistT22Instruction = getDelistT22Instruction;
exports.getDelistT22InstructionAsync = getDelistT22InstructionAsync;
exports.getDelistT22InstructionDataCodec = getDelistT22InstructionDataCodec;
exports.getDelistT22InstructionDataDecoder = getDelistT22InstructionDataDecoder;
exports.getDelistT22InstructionDataEncoder = getDelistT22InstructionDataEncoder;
exports.getDelistWnsInstruction = getDelistWnsInstruction;
exports.getDelistWnsInstructionAsync = getDelistWnsInstructionAsync;
exports.getDelistWnsInstructionDataCodec = getDelistWnsInstructionDataCodec;
exports.getDelistWnsInstructionDataDecoder = getDelistWnsInstructionDataDecoder;
exports.getDelistWnsInstructionDataEncoder = getDelistWnsInstructionDataEncoder;
exports.getEditInstruction = getEditInstruction;
exports.getEditInstructionDataCodec = getEditInstructionDataCodec;
exports.getEditInstructionDataDecoder = getEditInstructionDataDecoder;
exports.getEditInstructionDataEncoder = getEditInstructionDataEncoder;
exports.getFieldCodec = getFieldCodec;
exports.getFieldDecoder = getFieldDecoder;
exports.getFieldEncoder = getFieldEncoder;
exports.getListCompressedInstruction = getListCompressedInstruction;
exports.getListCompressedInstructionAsync = getListCompressedInstructionAsync;
exports.getListCompressedInstructionDataCodec = getListCompressedInstructionDataCodec;
exports.getListCompressedInstructionDataDecoder = getListCompressedInstructionDataDecoder;
exports.getListCompressedInstructionDataEncoder = getListCompressedInstructionDataEncoder;
exports.getListCoreInstruction = getListCoreInstruction;
exports.getListCoreInstructionDataCodec = getListCoreInstructionDataCodec;
exports.getListCoreInstructionDataDecoder = getListCoreInstructionDataDecoder;
exports.getListCoreInstructionDataEncoder = getListCoreInstructionDataEncoder;
exports.getListLegacyInstruction = getListLegacyInstruction;
exports.getListLegacyInstructionAsync = getListLegacyInstructionAsync;
exports.getListLegacyInstructionDataCodec = getListLegacyInstructionDataCodec;
exports.getListLegacyInstructionDataDecoder = getListLegacyInstructionDataDecoder;
exports.getListLegacyInstructionDataEncoder = getListLegacyInstructionDataEncoder;
exports.getListStateCodec = getListStateCodec;
exports.getListStateDecoder = getListStateDecoder;
exports.getListStateEncoder = getListStateEncoder;
exports.getListT22Instruction = getListT22Instruction;
exports.getListT22InstructionAsync = getListT22InstructionAsync;
exports.getListT22InstructionDataCodec = getListT22InstructionDataCodec;
exports.getListT22InstructionDataDecoder = getListT22InstructionDataDecoder;
exports.getListT22InstructionDataEncoder = getListT22InstructionDataEncoder;
exports.getListWnsInstruction = getListWnsInstruction;
exports.getListWnsInstructionAsync = getListWnsInstructionAsync;
exports.getListWnsInstructionDataCodec = getListWnsInstructionDataCodec;
exports.getListWnsInstructionDataDecoder = getListWnsInstructionDataDecoder;
exports.getListWnsInstructionDataEncoder = getListWnsInstructionDataEncoder;
exports.getMakeEventCodec = getMakeEventCodec;
exports.getMakeEventDecoder = getMakeEventDecoder;
exports.getMakeEventEncoder = getMakeEventEncoder;
exports.getNullableAddressCodec = getNullableAddressCodec;
exports.getNullableAddressDecoder = getNullableAddressDecoder;
exports.getNullableAddressEncoder = getNullableAddressEncoder;
exports.getPayloadTypeLocalCodec = getPayloadTypeLocalCodec;
exports.getPayloadTypeLocalDecoder = getPayloadTypeLocalDecoder;
exports.getPayloadTypeLocalEncoder = getPayloadTypeLocalEncoder;
exports.getProofInfoLocalCodec = getProofInfoLocalCodec;
exports.getProofInfoLocalDecoder = getProofInfoLocalDecoder;
exports.getProofInfoLocalEncoder = getProofInfoLocalEncoder;
exports.getSeedsVecLocalCodec = getSeedsVecLocalCodec;
exports.getSeedsVecLocalDecoder = getSeedsVecLocalDecoder;
exports.getSeedsVecLocalEncoder = getSeedsVecLocalEncoder;
exports.getTCollectionCodec = getTCollectionCodec;
exports.getTCollectionDecoder = getTCollectionDecoder;
exports.getTCollectionEncoder = getTCollectionEncoder;
exports.getTTokenProgramVersionCodec = getTTokenProgramVersionCodec;
exports.getTTokenProgramVersionDecoder = getTTokenProgramVersionDecoder;
exports.getTTokenProgramVersionEncoder = getTTokenProgramVersionEncoder;
exports.getTTokenStandardCodec = getTTokenStandardCodec;
exports.getTTokenStandardDecoder = getTTokenStandardDecoder;
exports.getTTokenStandardEncoder = getTTokenStandardEncoder;
exports.getTUseMethodCodec = getTUseMethodCodec;
exports.getTUseMethodDecoder = getTUseMethodDecoder;
exports.getTUseMethodEncoder = getTUseMethodEncoder;
exports.getTUsesCodec = getTUsesCodec;
exports.getTUsesDecoder = getTUsesDecoder;
exports.getTUsesEncoder = getTUsesEncoder;
exports.getTaggedPayloadCodec = getTaggedPayloadCodec;
exports.getTaggedPayloadDecoder = getTaggedPayloadDecoder;
exports.getTaggedPayloadEncoder = getTaggedPayloadEncoder;
exports.getTakeBidCompressedFullMetaInstruction = getTakeBidCompressedFullMetaInstruction;
exports.getTakeBidCompressedFullMetaInstructionAsync = getTakeBidCompressedFullMetaInstructionAsync;
exports.getTakeBidCompressedFullMetaInstructionDataCodec = getTakeBidCompressedFullMetaInstructionDataCodec;
exports.getTakeBidCompressedFullMetaInstructionDataDecoder = getTakeBidCompressedFullMetaInstructionDataDecoder;
exports.getTakeBidCompressedFullMetaInstructionDataEncoder = getTakeBidCompressedFullMetaInstructionDataEncoder;
exports.getTakeBidCompressedMetaHashInstruction = getTakeBidCompressedMetaHashInstruction;
exports.getTakeBidCompressedMetaHashInstructionAsync = getTakeBidCompressedMetaHashInstructionAsync;
exports.getTakeBidCompressedMetaHashInstructionDataCodec = getTakeBidCompressedMetaHashInstructionDataCodec;
exports.getTakeBidCompressedMetaHashInstructionDataDecoder = getTakeBidCompressedMetaHashInstructionDataDecoder;
exports.getTakeBidCompressedMetaHashInstructionDataEncoder = getTakeBidCompressedMetaHashInstructionDataEncoder;
exports.getTakeBidCoreInstruction = getTakeBidCoreInstruction;
exports.getTakeBidCoreInstructionDataCodec = getTakeBidCoreInstructionDataCodec;
exports.getTakeBidCoreInstructionDataDecoder = getTakeBidCoreInstructionDataDecoder;
exports.getTakeBidCoreInstructionDataEncoder = getTakeBidCoreInstructionDataEncoder;
exports.getTakeBidLegacyInstruction = getTakeBidLegacyInstruction;
exports.getTakeBidLegacyInstructionAsync = getTakeBidLegacyInstructionAsync;
exports.getTakeBidLegacyInstructionDataCodec = getTakeBidLegacyInstructionDataCodec;
exports.getTakeBidLegacyInstructionDataDecoder = getTakeBidLegacyInstructionDataDecoder;
exports.getTakeBidLegacyInstructionDataEncoder = getTakeBidLegacyInstructionDataEncoder;
exports.getTakeBidT22Instruction = getTakeBidT22Instruction;
exports.getTakeBidT22InstructionDataCodec = getTakeBidT22InstructionDataCodec;
exports.getTakeBidT22InstructionDataDecoder = getTakeBidT22InstructionDataDecoder;
exports.getTakeBidT22InstructionDataEncoder = getTakeBidT22InstructionDataEncoder;
exports.getTakeBidWnsInstruction = getTakeBidWnsInstruction;
exports.getTakeBidWnsInstructionDataCodec = getTakeBidWnsInstructionDataCodec;
exports.getTakeBidWnsInstructionDataDecoder = getTakeBidWnsInstructionDataDecoder;
exports.getTakeBidWnsInstructionDataEncoder = getTakeBidWnsInstructionDataEncoder;
exports.getTakeEventCodec = getTakeEventCodec;
exports.getTakeEventDecoder = getTakeEventDecoder;
exports.getTakeEventEncoder = getTakeEventEncoder;
exports.getTargetCodec = getTargetCodec;
exports.getTargetDecoder = getTargetDecoder;
exports.getTargetEncoder = getTargetEncoder;
exports.getTcompEventCodec = getTcompEventCodec;
exports.getTcompEventDecoder = getTcompEventDecoder;
exports.getTcompEventEncoder = getTcompEventEncoder;
exports.getTcompNoopInstruction = getTcompNoopInstruction;
exports.getTcompNoopInstructionDataCodec = getTcompNoopInstructionDataCodec;
exports.getTcompNoopInstructionDataDecoder = getTcompNoopInstructionDataDecoder;
exports.getTcompNoopInstructionDataEncoder = getTcompNoopInstructionDataEncoder;
exports.getTensorMarketplaceErrorMessage = getTensorMarketplaceErrorMessage;
exports.identifyTensorMarketplaceAccount = identifyTensorMarketplaceAccount;
exports.identifyTensorMarketplaceInstruction = identifyTensorMarketplaceInstruction;
exports.isPayloadTypeLocal = isPayloadTypeLocal;
exports.isTcompEvent = isTcompEvent;
exports.parseBidInstruction = parseBidInstruction;
exports.parseBuyCompressedInstruction = parseBuyCompressedInstruction;
exports.parseBuyCoreInstruction = parseBuyCoreInstruction;
exports.parseBuyCoreSplInstruction = parseBuyCoreSplInstruction;
exports.parseBuyLegacyInstruction = parseBuyLegacyInstruction;
exports.parseBuyLegacySplInstruction = parseBuyLegacySplInstruction;
exports.parseBuySplInstruction = parseBuySplInstruction;
exports.parseBuyT22Instruction = parseBuyT22Instruction;
exports.parseBuyT22SplInstruction = parseBuyT22SplInstruction;
exports.parseBuyWnsInstruction = parseBuyWnsInstruction;
exports.parseBuyWnsSplInstruction = parseBuyWnsSplInstruction;
exports.parseCancelBidInstruction = parseCancelBidInstruction;
exports.parseCloseExpiredBidInstruction = parseCloseExpiredBidInstruction;
exports.parseCloseExpiredListingCompressedInstruction = parseCloseExpiredListingCompressedInstruction;
exports.parseCloseExpiredListingCoreInstruction = parseCloseExpiredListingCoreInstruction;
exports.parseCloseExpiredListingLegacyInstruction = parseCloseExpiredListingLegacyInstruction;
exports.parseCloseExpiredListingT22Instruction = parseCloseExpiredListingT22Instruction;
exports.parseCloseExpiredListingWnsInstruction = parseCloseExpiredListingWnsInstruction;
exports.parseDelistCompressedInstruction = parseDelistCompressedInstruction;
exports.parseDelistCoreInstruction = parseDelistCoreInstruction;
exports.parseDelistLegacyInstruction = parseDelistLegacyInstruction;
exports.parseDelistT22Instruction = parseDelistT22Instruction;
exports.parseDelistWnsInstruction = parseDelistWnsInstruction;
exports.parseEditInstruction = parseEditInstruction;
exports.parseListCompressedInstruction = parseListCompressedInstruction;
exports.parseListCoreInstruction = parseListCoreInstruction;
exports.parseListLegacyInstruction = parseListLegacyInstruction;
exports.parseListT22Instruction = parseListT22Instruction;
exports.parseListWnsInstruction = parseListWnsInstruction;
exports.parseTakeBidCompressedFullMetaInstruction = parseTakeBidCompressedFullMetaInstruction;
exports.parseTakeBidCompressedMetaHashInstruction = parseTakeBidCompressedMetaHashInstruction;
exports.parseTakeBidCoreInstruction = parseTakeBidCoreInstruction;
exports.parseTakeBidLegacyInstruction = parseTakeBidLegacyInstruction;
exports.parseTakeBidT22Instruction = parseTakeBidT22Instruction;
exports.parseTakeBidWnsInstruction = parseTakeBidWnsInstruction;
exports.parseTcompNoopInstruction = parseTcompNoopInstruction;
exports.payloadTypeLocal = payloadTypeLocal;
exports.resolveBidIdOnCreate = resolveBidIdOnCreate;
exports.resolveBidTa = resolveBidTa;
exports.resolveCreatorPath = resolveCreatorPath;
exports.resolveFeeVaultPdaFromBidState = resolveFeeVaultPdaFromBidState;
exports.resolveFeeVaultPdaFromListState = resolveFeeVaultPdaFromListState;
exports.resolveProofPath = resolveProofPath;
exports.resolveRemainingSignerWithOwnerOrDelegate = resolveRemainingSignerWithOwnerOrDelegate;
exports.resolveRemainingSignerWithSellerOrDelegate = resolveRemainingSignerWithSellerOrDelegate;
exports.resolveTreeAuthorityPda = resolveTreeAuthorityPda;
exports.tcompEvent = tcompEvent;
//# sourceMappingURL=index.js.map
//# sourceMappingURL=index.js.map